@@ -14,6 +14,7 @@
 # else. See astropy.sphinx.conf for which values are set there.
 
 from configparser import ConfigParser
+from datetime import datetime
 import os
 import sys
 
@@ -62,7 +63,7 @@ rst_epilog = """
 # -- Project information ------------------------------------------------------
 project = setup_cfg['name']
 author = setup_cfg['author']
-copyright = '2011, {0}'.format(author)
+copyright = f'2011-{datetime.utcnow().year}, {author}'
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
@@ -119,7 +120,7 @@ html_favicon = os.path.join('_static', 'favicon.ico')
 
 # The name for this set of Sphinx documents. If None, it defaults to
 # "<project> v<release>".
-html_title = '{0} {1}'.format(project, release)
+html_title = f'{project} {release}'
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = project + 'doc'
@@ -179,6 +180,7 @@ if os.path.isfile(nitpick_filename):
 # -- Options for linkcheck output ---------------------------------------------
 linkcheck_retry = 5
 linkcheck_ignore = ['http://data.astropy.org',
+                    r'https://iraf.net/*',
                     r'https://github\.com/astropy/photutils/(?:issues|pull)/\d+']
 linkcheck_timeout = 180
 linkcheck_anchors = False
