@@ -15,10 +15,20 @@ __all__ = ['ApertureAttribute', 'PixelPositions', 'SkyCoordPositions',
 class ApertureAttribute:
     """
     Base descriptor class for aperture attribute validation.
+
+    Parameters
+    ----------
+    name : str
+        The name of the attribute.
+
+    description : str, optional
+        The description of the attribute, which will be used as the
+        attribute documentation.
     """
 
-    def __init__(self, name):
+    def __init__(self, name, description=''):
         self.name = name
+        self.__doc__ = description
 
     def __get__(self, instance, owner):
         if instance is None:
@@ -40,7 +50,6 @@ class ApertureAttribute:
 
         An exception is raised if the value is invalid.
         """
-
         raise NotImplementedError
 
 
@@ -74,17 +83,16 @@ class PixelPositions(ApertureAttribute):
 
     def _validate(self, value):
         if isinstance(value, u.Quantity) and value.unit != u.pixel:
-            raise u.UnitsError('{} must be in pixel units'.format(self.name))
+            raise u.UnitsError(f'{self.name} must be in pixel units')
 
         if np.any(~np.isfinite(value)):
-            raise ValueError('{} must not contain any non-finite (e.g., NaN '
-                             'or inf) positions'.format(self.name))
+            raise ValueError(f'{self.name} must not contain any non-finite '
+                             '(e.g., NaN or inf) positions')
 
         value = np.atleast_2d(value)
         if (value.shape[1] != 2 and value.shape[0] != 2) or value.ndim > 2:
-            raise TypeError('{} must be an (x, y) pixel position or a list '
-                            'or array of (x, y) pixel positions.'
-                            .format(self.name))
+            raise TypeError(f'{self.name} must be a (x, y) pixel position '
+                            'or a list or array of (x, y) pixel positions.')
 
 
 class SkyCoordPositions(ApertureAttribute):
@@ -94,8 +102,7 @@ class SkyCoordPositions(ApertureAttribute):
 
     def _validate(self, value):
         if not isinstance(value, SkyCoord):
-            raise ValueError('{} must be a SkyCoord instance'
-                             .format(self.name))
+            raise ValueError(f'{self.name} must be a SkyCoord instance')
 
 
 class Scalar(ApertureAttribute):
@@ -105,7 +112,7 @@ class Scalar(ApertureAttribute):
 
     def _validate(self, value):
         if not np.isscalar(value):
-            raise ValueError('{} must be a scalar'.format(self.name))
+            raise ValueError(f'{self.name} must be a scalar')
 
 
 class PositiveScalar(ApertureAttribute):
@@ -115,7 +122,7 @@ class PositiveScalar(ApertureAttribute):
 
     def _validate(self, value):
         if not np.isscalar(value) or value <= 0:
-            raise ValueError('{} must be a positive scalar'.format(self.name))
+            raise ValueError(f'{self.name} must be a positive scalar')
 
 
 class AngleScalarQuantity(ApertureAttribute):
@@ -127,14 +134,13 @@ class AngleScalarQuantity(ApertureAttribute):
     def _validate(self, value):
         if isinstance(value, u.Quantity):
             if not value.isscalar:
-                raise ValueError('{} must be a scalar'.format(self.name))
+                raise ValueError(f'{self.name} must be a scalar')
 
             if not value.unit.physical_type == 'angle':
-                raise ValueError('{} must have angular units'
-                                 .format(self.name))
+                raise ValueError(f'{self.name} must have angular units')
         else:
-            raise TypeError('{} must be an astropy Quantity instance'.
-                            format(self.name))
+            raise TypeError(f'{self.name} must be an astropy Quantity '
+                            'instance')
 
 
 class AngleOrPixelScalarQuantity(ApertureAttribute):
@@ -146,12 +152,12 @@ class AngleOrPixelScalarQuantity(ApertureAttribute):
     def _validate(self, value):
         if isinstance(value, u.Quantity):
             if not value.isscalar:
-                raise ValueError('{} must be a scalar'.format(self.name))
+                raise ValueError(f'{self.name} must be a scalar')
 
             if not (value.unit.physical_type == 'angle' or
                     value.unit == u.pixel):
-                raise ValueError('{} must have angular or pixel units'
-                                 .format(self.name))
+                raise ValueError(f'{self.name} must have angular or pixel '
+                                 'units')
         else:
-            raise TypeError('{} must be an astropy Quantity instance'
-                            .format(self.name))
+            raise TypeError(f'{self.name} must be an astropy Quantity '
+                            'instance')
