@@ -5,22 +5,15 @@ This module defines the base aperture classes.
 
 import abc
 import copy
-import warnings
 
 import numpy as np
 from astropy.coordinates import SkyCoord
 import astropy.units as u
-from astropy.utils import deprecated
-from astropy.utils.decorators import deprecated_renamed_argument
-from astropy.utils.exceptions import AstropyUserWarning
-from astropy.wcs.utils import wcs_to_celestial_frame
 
 from .bounding_box import BoundingBox
 from ._photometry_utils import (_handle_units, _prepare_photometry_data,
                                 _validate_inputs)
-from ..utils._wcs_helpers import (_pixel_to_world,
-                                  _pixel_scale_angle_at_skycoord,
-                                  _world_to_pixel)
+from ..utils._wcs_helpers import _pixel_scale_angle_at_skycoord
 
 __all__ = ['Aperture', 'SkyAperture', 'PixelAperture']
 
@@ -36,11 +29,15 @@ class Aperture(metaclass=abc.ABCMeta):
 
     def __len__(self):
         if self.isscalar:
-            raise TypeError('Scalar {0!r} object has no len()'
-                            .format(self.__class__.__name__))
+            raise TypeError(f'A scalar {self.__class__.__name__!r} object '
+                            'has no len()')
         return self.shape[0]
 
     def __getitem__(self, index):
+        if self.isscalar:
+            raise TypeError(f'A scalar {self.__class__.__name__!r} object '
+                            'cannot be indexed')
+
         kwargs = dict()
         for param in self._shape_params:
             kwargs[param] = getattr(self, param)
@@ -61,13 +58,14 @@ class Aperture(metaclass=abc.ABCMeta):
                             'or SkyAperture')
 
     def __repr__(self):
-        prefix = '<{0}('.format(self.__class__.__name__)
+        prefix = f'{self.__class__.__name__}'
         cls_info = [self._positions_str(prefix)]
-        for param in self._shape_params:
-            cls_info.append('{0}={1}'.format(param, getattr(self, param)))
+        if self._shape_params is not None:
+            for param in self._shape_params:
+                cls_info.append(f'{param}={getattr(self, param)}')
         cls_info = ', '.join(cls_info)
 
-        return '{0}{1})>'.format(prefix, cls_info)
+        return f'<{prefix}({cls_info})>'
 
     def __str__(self):
         prefix = 'positions'
@@ -77,7 +75,7 @@ class Aperture(metaclass=abc.ABCMeta):
         if self._shape_params is not None:
             for param in self._shape_params:
                 cls_info.append((param, getattr(self, param)))
-        fmt = ['{0}: {1}'.format(key, val) for key, val in cls_info]
+        fmt = [f'{key}: {val}' for key, val in cls_info]
 
         return '\n'.join(fmt)
 
@@ -86,7 +84,6 @@ class Aperture(metaclass=abc.ABCMeta):
         """
         The shape of the instance.
         """
-
         if isinstance(self.positions, SkyCoord):
             return self.positions.shape
         else:
@@ -95,9 +92,8 @@ class Aperture(metaclass=abc.ABCMeta):
     @property
     def isscalar(self):
         """
-        Whether the instance is scalar (i.e. a single position).
+        Whether the instance is scalar (i.e., a single position).
         """
-
         return self.shape == ()
 
 
@@ -111,7 +107,6 @@ class PixelAperture(Aperture):
         """
         A dictionary of default matplotlib.patches.Patch properties.
         """
-
         mpl_params = dict()
 
         # matplotlib.patches.Patch default is ``fill=True``
@@ -122,12 +117,9 @@ class PixelAperture(Aperture):
     @staticmethod
     def _translate_mask_mode(mode, subpixels, rectangle=False):
         if mode not in ('center', 'subpixel', 'exact'):
-            raise ValueError('Invalid mask mode: {0}'.format(mode))
+            raise ValueError(f'Invalid mask mode: {mode}')
 
         if rectangle and mode == 'exact':
-            warnings.warn('The "exact" method is not yet implemented for '
-                          'rectangular apertures -- using "subpixel" method '
-                          'with "subpixels=32"', AstropyUserWarning)
             mode = 'subpixel'
             subpixels = 32
 
@@ -157,14 +149,8 @@ class PixelAperture(Aperture):
         In other words, the (x, y) extents are half of the aperture
         minimal bounding box size in each dimension.
         """
-
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
-    @property
-    @deprecated('0.7', alternative='bbox')
-    def bounding_boxes(self):
-        return self.bbox
-
     @property
     def bbox(self):
         """
@@ -174,7 +160,6 @@ class PixelAperture(Aperture):
         `~photutils.aperture.BoundingBox` is returned, otherwise a list
         of `~photutils.aperture.BoundingBox` is returned.
         """
-
         positions = np.atleast_2d(self.positions)
         x_delta, y_delta = self._xy_extents
         xmin = positions[:, 0] - x_delta
@@ -200,7 +185,6 @@ class PixelAperture(Aperture):
         These pixel edges are used by the low-level `photutils.geometry`
         functions.
         """
-
         edges = []
         for position, bbox in zip(np.atleast_2d(self.positions),
                                   np.atleast_1d(self.bbox)):
@@ -215,71 +199,15 @@ class PixelAperture(Aperture):
     @property
     def area(self):
         """
-        Return the exact area of the aperture shape.
+        The exact area of the aperture shape.
 
         Returns
         -------
         area : float
             The aperture area.
         """
-
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
-    @deprecated('0.7', alternative=('e.g. np.sum(aper.to_mask().data) for a '
-                                    'scalar aperture'))
-    def mask_area(self, method='exact', subpixels=5):
-        """
-        Return the area of the aperture mask.
-
-        For ``method`` other than ``'exact'``, this area will be less
-        than the exact analytical area (e.g. the ``area`` method).  Note
-        that for these methods, the values can also differ because of
-        fractional pixel positions.
-
-        Parameters
-        ----------
-        method : {'exact', 'center', 'subpixel'}, optional
-            The method used to determine the overlap of the aperture on
-            the pixel grid.  Not all options are available for all
-            aperture types.  Note that the more precise methods are
-            generally slower.  The following methods are available:
-
-                * ``'exact'`` (default):
-                  The the exact fractional overlap of the aperture and
-                  each pixel is calculated.  The returned mask will
-                  contain values between 0 and 1.
-
-                * ``'center'``:
-                  A pixel is considered to be entirely in or out of the
-                  aperture depending on whether its center is in or out
-                  of the aperture.  The returned mask will contain
-                  values only of 0 (out) and 1 (in).
-
-                * ``'subpixel'``:
-                  A pixel is divided into subpixels (see the
-                  ``subpixels`` keyword), each of which are considered
-                  to be entirely in or out of the aperture depending on
-                  whether its center is in or out of the aperture.  If
-                  ``subpixels=1``, this method is equivalent to
-                  ``'center'``.  The returned mask will contain values
-                  between 0 and 1.
-
-        subpixels : int, optional
-            For the ``'subpixel'`` method, resample pixels by this factor
-            in each dimension.  That is, each pixel is divided into
-            ``subpixels ** 2`` subpixels.
-
-        Returns
-        -------
-        area : float
-            A list of the mask area (one per position) of the aperture.
-        """
-
-        masks = self.to_mask(method=method, subpixels=subpixels)
-        if self.isscalar:
-            masks = (masks,)
-        return [np.sum(mask.data) for mask in masks]
-
     @abc.abstractmethod
     def to_mask(self, method='exact', subpixels=5):
         """
@@ -294,7 +222,7 @@ class PixelAperture(Aperture):
             generally slower.  The following methods are available:
 
                 * ``'exact'`` (default):
-                  The the exact fractional overlap of the aperture and
+                  The exact fractional overlap of the aperture and
                   each pixel is calculated.  The returned mask will
                   contain values between 0 and 1.
 
@@ -326,9 +254,78 @@ class PixelAperture(Aperture):
             otherwise a list of `~photutils.aperture.ApertureMask` is
             returned.
         """
-
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
+    def area_overlap(self, data, *, mask=None, method='exact', subpixels=5):
+        """
+        Return the areas of the aperture masks that overlap with the
+        data, i.e., how many pixels are actually used to calculate each
+        sum.
+
+        Parameters
+        ----------
+        data : array_like or `~astropy.units.Quantity`
+            The 2D array to multiply with the aperture mask.
+
+        mask : array_like (bool), optional
+            A boolean mask with the same shape as ``data`` where a
+            `True` value indicates the corresponding element of ``data``
+            is masked. Masked data are excluded from the area overlap.
+
+        method : {'exact', 'center', 'subpixel'}, optional
+            The method used to determine the overlap of the aperture on
+            the pixel grid.  Not all options are available for all
+            aperture types.  Note that the more precise methods are
+            generally slower.  The following methods are available:
+
+                * ``'exact'`` (default):
+                  The the exact fractional overlap of the aperture and
+                  each pixel is calculated.  The returned mask will
+                  contain values between 0 and 1.
+
+                * ``'center'``:
+                  A pixel is considered to be entirely in or out of the
+                  aperture depending on whether its center is in or out
+                  of the aperture.  The returned mask will contain
+                  values only of 0 (out) and 1 (in).
+
+                * ``'subpixel'``:
+                  A pixel is divided into subpixels (see the
+                  ``subpixels`` keyword), each of which are considered
+                  to be entirely in or out of the aperture depending on
+                  whether its center is in or out of the aperture.  If
+                  ``subpixels=1``, this method is equivalent to
+                  ``'center'``.  The returned mask will contain values
+                  between 0 and 1.
+
+        subpixels : int, optional
+            For the ``'subpixel'`` method, resample pixels by this factor
+            in each dimension.  That is, each pixel is divided into
+            ``subpixels ** 2`` subpixels.
+
+        Returns
+        -------
+        areas : float or array_like
+            The overlapping areas between the aperture masks and the data.
+        """
+        apermasks = self.to_mask(method=method, subpixels=subpixels)
+        if self.isscalar:
+            apermasks = (apermasks,)
+
+        if mask is not None:
+            mask = np.asarray(mask)
+            if mask.shape != data.shape:
+                raise ValueError('mask and data must have the same shape')
+
+        data = np.ones_like(data)
+        vals = [apermask.get_values(data, mask=mask) for apermask in apermasks]
+        # if the aperture does not overlap the data return np.nan
+        areas = [val.sum() if val.shape != (0,) else np.nan for val in vals]
+        if self.isscalar:
+            return areas[0]
+        else:
+            return areas
+
     def _do_photometry(self, data, variance, method='exact', subpixels=5,
                        unit=None):
 
@@ -340,19 +337,16 @@ class PixelAperture(Aperture):
             masks = (masks,)
 
         for apermask in masks:
-            data_weighted = apermask.multiply(data)
-            if data_weighted is None:
-                aperture_sums.append(np.nan)
-            else:
-                aperture_sums.append(np.sum(data_weighted))
+            values = apermask.get_values(data)
+            # if the aperture does not overlap the data return np.nan
+            aper_sum = values.sum() if values.shape != (0,) else np.nan
+            aperture_sums.append(aper_sum)
 
             if variance is not None:
-                variance_weighted = apermask.multiply(variance)
-                if variance_weighted is None:
-                    aperture_sum_errs.append(np.nan)
-                else:
-                    aperture_sum_errs.append(
-                        np.sqrt(np.sum(variance_weighted)))
+                values = apermask.get_values(variance)
+                # if the aperture does not overlap the data return np.nan
+                aper_var = values.sum() if values.shape != (0,) else np.nan
+                aperture_sum_errs.append(np.sqrt(aper_var))
 
         aperture_sums = np.array(aperture_sums)
         aperture_sum_errs = np.array(aperture_sum_errs)
@@ -364,9 +358,8 @@ class PixelAperture(Aperture):
 
         return aperture_sums, aperture_sum_errs
 
-    @deprecated_renamed_argument('unit', None, '0.7')
     def do_photometry(self, data, error=None, mask=None, method='exact',
-                      subpixels=5, unit=None):
+                      subpixels=5):
         """
         Perform aperture photometry on the input data.
 
@@ -419,15 +412,6 @@ class PixelAperture(Aperture):
             in each dimension.  That is, each pixel is divided into
             ``subpixels ** 2`` subpixels.
 
-        unit : `~astropy.units.UnitBase` object or str, optional
-            Deprecated in v0.7.
-            An object that represents the unit associated with the input
-            ``data`` and ``error`` arrays.  Must be a
-            `~astropy.units.UnitBase` object or a string parseable by
-            the :mod:`~astropy.units` package.  If ``data`` or ``error``
-            already have a different unit, the input ``unit`` will not
-            be used and a warning will be raised.
-
         Returns
         -------
         aperture_sums : `~numpy.ndarray` or `~astropy.units.Quantity`
@@ -435,14 +419,26 @@ class PixelAperture(Aperture):
 
         aperture_sum_errs : `~numpy.ndarray` or `~astropy.units.Quantity`
             The errors on the sums within each aperture.
-        """
 
+        Notes
+        -----
+        `RectangularAperture` and `RectangularAnnulus` photometry with
+        the "exact" method uses a subpixel approximation by subdividing
+        each data pixel by a factor of 1024 (``subpixels = 32``). For
+        rectangular aperture widths and heights in the range from
+        2 to 100 pixels, this subpixel approximation gives results
+        typically within 0.001 percent or better of the exact value.
+        The differences can be larger for smaller apertures (e.g.,
+        aperture sizes of one pixel or smaller). For such small sizes,
+        it is recommend to set ``method='subpixel'`` with a larger
+        ``subpixels`` size.
+        """
         # validate inputs
         data, error = _validate_inputs(data, error)
 
         # handle data, error, and unit inputs
         # output data and error are ndarray without units
-        data, error, unit = _handle_units(data, error, unit)
+        data, error, unit = _handle_units(data, error)
 
         # compute variance and apply input mask
         data, variance = _prepare_photometry_data(data, error, mask)
@@ -458,7 +454,6 @@ class PixelAperture(Aperture):
         This preserves the cubic Bezier curves (CURVE4) of the aperture
         paths.
         """
-
         import matplotlib.path as mpath
 
         path_inner = patch_inner.get_path()
@@ -477,10 +472,10 @@ class PixelAperture(Aperture):
 
         return mpath.Path(verts, codes)
 
-    def _define_patch_params(self, origin=(0, 0), indices=None, **kwargs):
+    def _define_patch_params(self, origin=(0, 0), **kwargs):
         """
         Define the aperture patch position and set any default
-        matplotlib patch keywords (e.g. ``fill=False``).
+        matplotlib patch keywords (e.g., ``fill=False``).
 
         Parameters
         ----------
@@ -488,10 +483,7 @@ class PixelAperture(Aperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        indices : int or array of int, optional
-            The indices of the aperture positions to plot.
-
-        kwargs : `dict`
+        **kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
 
@@ -504,11 +496,7 @@ class PixelAperture(Aperture):
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
         """
-
         xy_positions = copy.deepcopy(np.atleast_2d(self.positions))
-        if indices is not None:
-            xy_positions = xy_positions[np.atleast_1d(indices)]
-
         xy_positions[:, 0] -= origin[0]
         xy_positions[:, 1] -= origin[1]
 
@@ -518,7 +506,7 @@ class PixelAperture(Aperture):
         return xy_positions, patch_params
 
     @abc.abstractmethod
-    def _to_patch(self, origin=(0, 0), indices=None, **kwargs):
+    def _to_patch(self, origin=(0, 0), **kwargs):
         """
         Return a `~matplotlib.patches.patch` for the aperture.
 
@@ -528,10 +516,7 @@ class PixelAperture(Aperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        indices : int or array of int, optional
-            The indices of the aperture positions to plot.
-
-        kwargs : `dict`
+        **kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
 
@@ -542,15 +527,9 @@ class PixelAperture(Aperture):
             single `~matplotlib.patches.patch` is returned, otherwise a
             list of `~matplotlib.patches.patch` is returned.
         """
-
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
-    @deprecated_renamed_argument('ax', 'axes', '0.7')
-    @deprecated_renamed_argument('indices', None, '0.7',
-                                 alternative=('indices directly on the '
-                                              'aperture object '
-                                              '(e.g. aper[idx].plot())'))
-    def plot(self, axes=None, origin=(0, 0), indices=None, **kwargs):
+    def plot(self, axes=None, origin=(0, 0), **kwargs):
         """
         Plot the aperture on a matplotlib `~matplotlib.axes.Axes`
         instance.
@@ -565,27 +544,30 @@ class PixelAperture(Aperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        indices : int, array of int, or `None`, optional
-            The indices of the aperture position(s) to plot.  If `None`
-            (default) then all aperture positions will be plotted.
-
-        kwargs : `dict`
+        **kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
-        """
 
+        Returns
+        -------
+        patch : list of `~matplotlib.patches.Patch`
+            A list of matplotlib patches for the plotted aperture. The
+            patches can be used, for example, when adding a plot legend.
+        """
         import matplotlib.pyplot as plt
 
         if axes is None:
             axes = plt.gca()
 
-        patches = self._to_patch(origin=origin, indices=indices, **kwargs)
+        patches = self._to_patch(origin=origin, **kwargs)
         if self.isscalar:
             patches = (patches,)
 
         for patch in patches:
             axes.add_patch(patch)
 
+        return patches
+
     def _to_sky_params(self, wcs):
         """
         Convert the pixel aperture parameters to those for a sky
@@ -594,27 +576,34 @@ class PixelAperture(Aperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         sky_params : `dict`
             A dictionary of parameters for an equivalent sky aperture.
         """
-
         sky_params = {}
         xpos, ypos = np.transpose(self.positions)
-        sky_params['positions'] = _pixel_to_world(xpos, ypos, wcs)
+        sky_params['positions'] = wcs.pixel_to_world(xpos, ypos)
 
-        # The aperture object must have a single value for each shape
-        # parameter so we must use a single pixel scale for all positions.
-        # Here, we define the scale at the WCS CRVAL position.
-        crval = SkyCoord(*wcs.wcs.crval, frame=wcs_to_celestial_frame(wcs),
-                         unit=wcs.wcs.cunit)
-        pixscale, angle = _pixel_scale_angle_at_skycoord(crval, wcs)
+        # Aperture objects require scalar shape parameters (e.g.,
+        # radius, a, b, theta, etc.), therefore we must calculate the
+        # pixel scale and angle at only a single sky position, which
+        # we take as the first aperture position. For apertures with
+        # multiple positions used with a WCS that contains distortions
+        # (e.g., a spatially-dependent pixel scale), this may lead to
+        # unexpected results (e.g., results that are dependent of the
+        # order of the positions). There is no good way to fix this with
+        # the current Aperture API allowing multiple positions.
+        skypos = sky_params['positions']
+        if not self.isscalar:
+            skypos = skypos[0]
+
+        _, pixscale, angle = _pixel_scale_angle_at_skycoord(skypos, wcs)
 
         shape_params = list(self._shape_params)
 
@@ -638,17 +627,16 @@ class PixelAperture(Aperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         aperture : `SkyAperture` object
             A `SkyAperture` object.
         """
-
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
 
@@ -666,28 +654,35 @@ class SkyAperture(Aperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         pixel_params : `dict`
             A dictionary of parameters for an equivalent pixel aperture.
         """
-
         pixel_params = {}
 
-        xpos, ypos = _world_to_pixel(self.positions, wcs)
-        pixel_params['positions'] = np.array([xpos, ypos]).transpose()
+        xpos, ypos = wcs.world_to_pixel(self.positions)
+        pixel_params['positions'] = np.transpose((xpos, ypos))
 
-        # The aperture object must have a single value for each shape
-        # parameter so we must use a single pixel scale for all positions.
-        # Here, we define the scale at the WCS CRVAL position.
-        crval = SkyCoord(*wcs.wcs.crval, frame=wcs_to_celestial_frame(wcs),
-                         unit=wcs.wcs.cunit)
-        pixscale, angle = _pixel_scale_angle_at_skycoord(crval, wcs)
+        # Aperture objects require scalar shape parameters (e.g.,
+        # radius, a, b, theta, etc.), therefore we must calculate the
+        # pixel scale and angle at only a single sky position, which
+        # we take as the first aperture position. For apertures with
+        # multiple positions used with a WCS that contains distortions
+        # (e.g., a spatially-dependent pixel scale), this may lead to
+        # unexpected results (e.g., results that are dependent of the
+        # order of the positions). There is no good way to fix this with
+        # the current Aperture API allowing multiple positions.
+        if self.isscalar:
+            skypos = self.positions
+        else:
+            skypos = self.positions[0]
+        _, pixscale, angle = _pixel_scale_angle_at_skycoord(skypos, wcs)
 
         shape_params = list(self._shape_params)
 
@@ -715,15 +710,14 @@ class SkyAperture(Aperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         aperture : `PixelAperture` object
             A `PixelAperture` object.
         """
-
         raise NotImplementedError('Needs to be implemented in a subclass.')
