@@ -71,7 +71,6 @@ class EllipticalMaskMixin:
             otherwise a list of `~photutils.aperture.ApertureMask` is
             returned.
         """
-
         use_exact, subpixels = self._translate_mask_mode(method, subpixels)
 
         if hasattr(self, 'a'):
@@ -110,7 +109,6 @@ class EllipticalMaskMixin:
         """
         Calculate half of the bounding box extents of an ellipse.
         """
-
         cos_theta = np.cos(theta)
         sin_theta = np.sin(theta)
         semimajor_x = semimajor_axis * cos_theta
@@ -159,7 +157,7 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
 
     Examples
     --------
-    >>> from photutils import EllipticalAperture
+    >>> from photutils.aperture import EllipticalAperture
     >>> aper = EllipticalAperture([10., 20.], 5., 3.)
     >>> aper = EllipticalAperture((10., 20.), 5., 3., theta=np.pi)
 
@@ -171,10 +169,14 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
     """
 
     _shape_params = ('a', 'b', 'theta')
-    positions = PixelPositions('positions')
-    a = PositiveScalar('a')
-    b = PositiveScalar('b')
-    theta = Scalar('theta')
+    positions = PixelPositions('positions',
+                               description='The center pixel position(s).')
+    a = PositiveScalar('a', description='The semimajor axis in pixels.')
+    b = PositiveScalar('b', description='The semiminor axis in pixels.')
+    theta = Scalar('theta',
+                   description=('The counterclockwise rotation angle in '
+                                'radians of the ellipse semimajor axis from '
+                                'the positive x axis.'))
 
     def __init__(self, positions, a, b, theta=0.):
         self.positions = positions
@@ -200,7 +202,7 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        kwargs : `dict`
+        **kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
 
@@ -211,7 +213,6 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
             single `~matplotlib.patches.patch` is returned, otherwise a
             list of `~matplotlib.patches.patch` is returned.
         """
-
         import matplotlib.patches as mpatches
 
         xy_positions, patch_kwargs = self._define_patch_params(origin=origin,
@@ -246,12 +247,11 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
         aperture : `SkyEllipticalAperture` object
             A `SkyEllipticalAperture` object.
         """
-
         return SkyEllipticalAperture(**self._to_sky_params(wcs))
 
 
 class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
-    """
+    r"""
     An elliptical annulus aperture defined in pixel coordinates.
 
     The aperture has a single fixed size/shape, but it can have multiple
@@ -282,7 +282,7 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
         If `None`, then the the inner semiminor axis is calculated as:
 
             .. math:: b_{in} = b_{out}
-                \\left(\\frac{a_{in}}{a_{out}}\\right)
+                \left(\frac{a_{in}}{a_{out}}\right)
 
     theta : float, optional
         The rotation angle in radians of the ellipse semimajor axis from
@@ -301,7 +301,7 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
 
     Examples
     --------
-    >>> from photutils import EllipticalAnnulus
+    >>> from photutils.aperture import EllipticalAnnulus
     >>> aper = EllipticalAnnulus([10., 20.], 3., 8., 5.)
     >>> aper = EllipticalAnnulus((10., 20.), 3., 8., 5., theta=np.pi)
 
@@ -313,12 +313,20 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
     """
 
     _shape_params = ('a_in', 'a_out', 'b_in', 'b_out', 'theta')
-    positions = PixelPositions('positions')
-    a_in = PositiveScalar('a_in')
-    a_out = PositiveScalar('a_out')
-    b_in = PositiveScalar('b_in')
-    b_out = PositiveScalar('b_out')
-    theta = Scalar('theta')
+    positions = PixelPositions('positions',
+                               description='The center pixel position(s).')
+    a_in = PositiveScalar('a_in',
+                          description='The inner semimajor axis in pixels.')
+    a_out = PositiveScalar('a_out',
+                           description='The outer semimajor axis in pixels.')
+    b_in = PositiveScalar('b_in',
+                          description='The inner semiminor axis in pixels.')
+    b_out = PositiveScalar('b_out',
+                           description='The outer semiminor axis in pixels.')
+    theta = Scalar('theta',
+                   description=('The counterclockwise rotation angle in '
+                                'radians of the ellipse semimajor axis from '
+                                'the positive x axis.'))
 
     def __init__(self, positions, a_in, a_out, b_out, b_in=None, theta=0.):
         if not a_out > a_in:
@@ -356,7 +364,7 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        kwargs : `dict`
+        **kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
 
@@ -367,7 +375,6 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
             single `~matplotlib.patches.patch` is returned, otherwise a
             list of `~matplotlib.patches.patch` is returned.
         """
-
         import matplotlib.patches as mpatches
 
         xy_positions, patch_kwargs = self._define_patch_params(origin=origin,
@@ -406,7 +413,6 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
         aperture : `SkyEllipticalAnnulus` object
             A `SkyEllipticalAnnulus` object.
         """
-
         return SkyEllipticalAnnulus(**self._to_sky_params(wcs))
 
 
@@ -441,16 +447,25 @@ class SkyEllipticalAperture(SkyAperture):
     --------
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
-    >>> from photutils import SkyEllipticalAperture
+    >>> from photutils.aperture import SkyEllipticalAperture
     >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
     >>> aper = SkyEllipticalAperture(positions, 1.0*u.arcsec, 0.5*u.arcsec)
     """
 
     _shape_params = ('a', 'b', 'theta')
-    positions = SkyCoordPositions('positions')
-    a = AngleOrPixelScalarQuantity('a')
-    b = AngleOrPixelScalarQuantity('b')
-    theta = AngleScalarQuantity('theta')
+    positions = SkyCoordPositions(
+        'positions',
+        description='The center position(s) in sky coordinates.')
+    a = AngleOrPixelScalarQuantity(
+        'a',
+        description='The semimajor axis, in angular or pixel units.')
+    b = AngleOrPixelScalarQuantity(
+        'b',
+        description='The semiminor axis, in angular or pixel units.')
+    theta = AngleScalarQuantity(
+        'theta',
+        description=('The position angle in angular units of the ellipse '
+                     'semimajor axis.'))
 
     def __init__(self, positions, a, b, theta=0.*u.deg):
         if a.unit.physical_type != b.unit.physical_type:
@@ -480,12 +495,11 @@ class SkyEllipticalAperture(SkyAperture):
         aperture : `EllipticalAperture` object
             An `EllipticalAperture` object.
         """
-
         return EllipticalAperture(**self._to_pixel_params(wcs))
 
 
 class SkyEllipticalAnnulus(SkyAperture):
-    """
+    r"""
     An elliptical annulus aperture defined in sky coordinates.
 
     The aperture has a single fixed size/shape, but it can have multiple
@@ -511,7 +525,7 @@ class SkyEllipticalAnnulus(SkyAperture):
         If `None`, then the inner semiminor axis is calculated as:
 
             .. math:: b_{in} = b_{out}
-                \\left(\\frac{a_{in}}{a_{out}}\\right)
+                \left(\frac{a_{in}}{a_{out}}\right)
 
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the ellipse semimajor
@@ -523,19 +537,32 @@ class SkyEllipticalAnnulus(SkyAperture):
     --------
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
-    >>> from photutils import SkyEllipticalAnnulus
+    >>> from photutils.aperture import SkyEllipticalAnnulus
     >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
     >>> aper = SkyEllipticalAnnulus(positions, 0.5*u.arcsec, 2.0*u.arcsec,
     ...                             1.0*u.arcsec)
     """
 
     _shape_params = ('a_in', 'a_out', 'b_in', 'b_out', 'theta')
-    positions = SkyCoordPositions('positions')
-    a_in = AngleOrPixelScalarQuantity('a_in')
-    a_out = AngleOrPixelScalarQuantity('a_out')
-    b_in = AngleOrPixelScalarQuantity('b_in')
-    b_out = AngleOrPixelScalarQuantity('b_out')
-    theta = AngleScalarQuantity('theta')
+    positions = SkyCoordPositions(
+        'positions',
+        description='The center position(s) in sky coordinates.')
+    a_in = AngleOrPixelScalarQuantity(
+        'a_in',
+        description='The inner semimajor axis, in angular or pixel units.')
+    a_out = AngleOrPixelScalarQuantity(
+        'a_out',
+        description='The outer semimajor axis, in angular or pixel units.')
+    b_in = AngleOrPixelScalarQuantity(
+        'b_in',
+        description='The inner semiminor axis, in angular or pixel units.')
+    b_out = AngleOrPixelScalarQuantity(
+        'b_out',
+        description='The outer semiminor axis, in angular or pixel units.')
+    theta = AngleScalarQuantity(
+        'theta',
+        description=('The position angle in angular units of the ellipse '
+                     'semimajor axis.'))
 
     def __init__(self, positions, a_in, a_out, b_out, b_in=None,
                  theta=0.*u.deg):
@@ -583,5 +610,4 @@ class SkyEllipticalAnnulus(SkyAperture):
         aperture : `EllipticalAnnulus` object
             An `EllipticalAnnulus` object.
         """
-
         return EllipticalAnnulus(**self._to_pixel_params(wcs))
