@@ -4,7 +4,6 @@ This module defines tools to perform aperture photometry.
 """
 
 import warnings
-from collections import OrderedDict
 
 import numpy as np
 from astropy.nddata import NDData, StdDevUncertainty
@@ -122,14 +121,23 @@ def aperture_photometry(data, apertures, error=None, mask=None,
 
     Notes
     -----
-    If the input ``data`` is a `~astropy.nddata.NDData` instance, then
-    the ``error``, ``mask``, and ``wcs`` keyword inputs are ignored.
-    Instead, these values should be defined as attributes in the
-    `~astropy.nddata.NDData` object.  In the case of ``error``, it must
-    be defined in the ``uncertainty`` attribute with a
+    `RectangularAperture` and `RectangularAnnulus` photometry with the
+    "exact" method uses a subpixel approximation by subdividing each
+    data pixel by a factor of 1024 (``subpixels = 32``). For rectangular
+    aperture widths and heights in the range from 2 to 100 pixels, this
+    subpixel approximation gives results typically within 0.001 percent
+    or better of the exact value. The differences can be larger for
+    smaller apertures (e.g., aperture sizes of one pixel or smaller).
+    For such small sizes, it is recommend to set ``method='subpixel'``
+    with a larger ``subpixels`` size.
+
+    If the input ``data`` is a `~astropy.nddata.NDData` instance,
+    then the ``error``, ``mask``, and ``wcs`` keyword inputs are
+    ignored. Instead, these values should be defined as attributes in
+    the `~astropy.nddata.NDData` object. In the case of ``error``,
+    it must be defined in the ``uncertainty`` attribute with a
     `~astropy.nddata.StdDevUncertainty` instance.
     """
-
     if isinstance(data, NDData):
         nddata_attr = {'error': error, 'mask': mask, 'wcs': wcs}
         for key, value in nddata_attr.items():
@@ -193,10 +201,10 @@ def aperture_photometry(data, apertures, error=None, mask=None,
                              'positions.')
 
     # define output table meta data
-    meta = OrderedDict()
+    meta = {}
     meta['name'] = 'Aperture photometry results'
     meta['version'] = _get_version_info()
-    calling_args = "method='{0}', subpixels={1}".format(method, subpixels)
+    calling_args = f"method='{method}', subpixels={subpixels}"
     meta['aperture_photometry_args'] = calling_args
 
     tbl = QTable(meta=meta)
@@ -226,8 +234,8 @@ def aperture_photometry(data, apertures, error=None, mask=None,
         sum_key = sum_key_main
         sum_err_key = sum_err_key_main
         if not single_aperture:
-            sum_key += '_{}'.format(i)
-            sum_err_key += '_{}'.format(i)
+            sum_key += f'_{i}'
+            sum_err_key += f'_{i}'
 
         tbl[sum_key] = aper_sum
         if error is not None:
