@@ -72,7 +72,6 @@ class RectangularMaskMixin:
             otherwise a list of `~photutils.aperture.ApertureMask` is
             returned.
         """
-
         _, subpixels = self._translate_mask_mode(method, subpixels,
                                                  rectangle=True)
 
@@ -82,7 +81,6 @@ class RectangularMaskMixin:
         elif hasattr(self, 'w_out'):  # annulus
             w = self.w_out
             h = self.h_out
-            h_in = self.w_in * self.h_out / self.w_out
         else:
             raise ValueError('Cannot determine the aperture radius.')
 
@@ -98,7 +96,7 @@ class RectangularMaskMixin:
             if hasattr(self, 'w_in'):
                 mask -= rectangular_overlap_grid(edges[0], edges[1], edges[2],
                                                  edges[3], nx, ny, self.w_in,
-                                                 h_in, self.theta, 0,
+                                                 self.h_in, self.theta, 0,
                                                  subpixels)
 
             masks.append(ApertureMask(mask, bbox))
@@ -113,7 +111,6 @@ class RectangularMaskMixin:
         """
         Calculate half of the bounding box extents of an ellipse.
         """
-
         half_width = width / 2.
         half_height = height / 2.
         sin_theta = math.sin(theta)
@@ -135,7 +132,6 @@ class RectangularMaskMixin:
         Used for creating `~matplotlib.patches.Rectangle` patch for the
         aperture.
         """
-
         half_width = width / 2.
         half_height = height / 2.
         sin_theta = math.sin(theta)
@@ -184,7 +180,7 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
 
     Examples
     --------
-    >>> from photutils import RectangularAperture
+    >>> from photutils.aperture import RectangularAperture
     >>> aper = RectangularAperture([10., 20.], 5., 3.)
     >>> aper = RectangularAperture((10., 20.), 5., 3., theta=np.pi)
 
@@ -196,10 +192,14 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
     """
 
     _shape_params = ('w', 'h', 'theta')
-    positions = PixelPositions('positions')
-    w = PositiveScalar('w')
-    h = PositiveScalar('h')
-    theta = Scalar('theta')
+    positions = PixelPositions('positions',
+                               description='The center pixel position(s).')
+    w = PositiveScalar('w', description='The full width in pixels.')
+    h = PositiveScalar('h', description='The full height in pixels.')
+    theta = Scalar('theta',
+                   description=('The counterclockwise rotation angle in '
+                                'radians of the rectangle "width" side from '
+                                'the positive x axis.'))
 
     def __init__(self, positions, w, h, theta=0.):
         self.positions = positions
@@ -215,7 +215,7 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
     def area(self):
         return self.w * self.h
 
-    def _to_patch(self, origin=(0, 0), indices=None, **kwargs):
+    def _to_patch(self, origin=(0, 0), **kwargs):
         """
         Return a `~matplotlib.patches.patch` for the aperture.
 
@@ -225,10 +225,7 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        indices : int or array of int, optional
-            The indices of the aperture positions to plot.
-
-        kwargs : `dict`
+        **kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
 
@@ -239,11 +236,10 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
             single `~matplotlib.patches.patch` is returned, otherwise a
             list of `~matplotlib.patches.patch` is returned.
         """
-
         import matplotlib.patches as mpatches
 
-        xy_positions, patch_kwargs = self._define_patch_params(
-            origin=origin, indices=indices, **kwargs)
+        xy_positions, patch_kwargs = self._define_patch_params(origin=origin,
+                                                               **kwargs)
         xy_positions = self._lower_left_positions(xy_positions, self.w,
                                                   self.h, self.theta)
 
@@ -266,22 +262,21 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         aperture : `SkyRectangularAperture` object
             A `SkyRectangularAperture` object.
         """
-
         return SkyRectangularAperture(**self._to_sky_params(wcs))
 
 
 class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
-    """
+    r"""
     A rectangular annulus aperture defined in pixel coordinates.
 
     The aperture has a single fixed size/shape, but it can have multiple
@@ -307,11 +302,14 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
         ``theta=0`` the width side is along the ``x`` axis.
 
     h_out : float
-        The outer full height of the rectangular annulus in pixels.  The
-        inner full height is calculated as:
+        The outer full height of the rectangular annulus in pixels.
+
+    h_in : `None` or float
+        The inner full height of the rectangular annulus in pixels.
+        If `None`, then the inner full height is calculated as:
 
             .. math:: h_{in} = h_{out}
-                \\left(\\frac{w_{in}}{w_{out}}\\right)
+                \left(\frac{w_{in}}{w_{out}}\right)
 
         For ``theta=0`` the height side is along the ``y`` axis.
 
@@ -332,7 +330,7 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
 
     Examples
     --------
-    >>> from photutils import RectangularAnnulus
+    >>> from photutils.aperture import RectangularAnnulus
     >>> aper = RectangularAnnulus([10., 20.], 3., 8., 5.)
     >>> aper = RectangularAnnulus((10., 20.), 3., 8., 5., theta=np.pi)
 
@@ -343,22 +341,38 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
     >>> aper = RectangularAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=np.pi)
     """
 
-    _shape_params = ('w_in', 'w_out', 'h_out', 'theta')
-    positions = PixelPositions('positions')
-    w_in = PositiveScalar('w_in')
-    w_out = PositiveScalar('w_out')
-    h_out = PositiveScalar('h_out')
-    theta = Scalar('theta')
+    _shape_params = ('w_in', 'w_out', 'h_in', 'h_out', 'theta')
+    positions = PixelPositions('positions',
+                               description='The center pixel position(s).')
+    w_in = PositiveScalar('w_in',
+                          description='The inner full width in pixels.')
+    w_out = PositiveScalar('w_out',
+                           description='The outer full width in pixels.')
+    h_in = PositiveScalar('h_in',
+                          description='The inner full height in pixels.')
+    h_out = PositiveScalar('h_out',
+                           description='The outer full height in pixels.')
+    theta = Scalar('theta',
+                   description=('The counterclockwise rotation angle in '
+                                'radians of the rectangle "width" side from '
+                                'the positive x axis.'))
 
-    def __init__(self, positions, w_in, w_out, h_out, theta=0.):
+    def __init__(self, positions, w_in, w_out, h_out, h_in=None, theta=0.):
         if not w_out > w_in:
-            raise ValueError("'w_out' must be greater than 'w_in'")
+            raise ValueError('"w_out" must be greater than "w_in"')
 
         self.positions = positions
         self.w_in = w_in
         self.w_out = w_out
         self.h_out = h_out
-        self.h_in = self.w_in * self.h_out / self.w_out
+
+        if h_in is None:
+            h_in = self.w_in * self.h_out / self.w_out
+        else:
+            if not h_out > h_in:
+                raise ValueError('"h_out" must be greater than "h_in"')
+        self.h_in = h_in
+
         self.theta = theta
 
     @property
@@ -369,7 +383,7 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
     def area(self):
         return self.w_out * self.h_out - self.w_in * self.h_in
 
-    def _to_patch(self, origin=(0, 0), indices=None, **kwargs):
+    def _to_patch(self, origin=(0, 0), **kwargs):
         """
         Return a `~matplotlib.patches.patch` for the aperture.
 
@@ -379,10 +393,7 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
             The ``(x, y)`` position of the origin of the displayed
             image.
 
-        indices : int or array of int, optional
-            The indices of the aperture positions to plot.
-
-        kwargs : `dict`
+        **kwargs : `dict`
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
 
@@ -393,11 +404,10 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
             single `~matplotlib.patches.patch` is returned, otherwise a
             list of `~matplotlib.patches.patch` is returned.
         """
-
         import matplotlib.patches as mpatches
 
-        xy_positions, patch_kwargs = self._define_patch_params(
-            origin=origin, indices=indices, **kwargs)
+        xy_positions, patch_kwargs = self._define_patch_params(origin=origin,
+                                                               **kwargs)
         inner_xy_positions = self._lower_left_positions(xy_positions,
                                                         self.w_in, self.h_in,
                                                         self.theta)
@@ -429,17 +439,16 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         aperture : `SkyRectangularAnnulus` object
             A `SkyRectangularAnnulus` object.
         """
-
         return SkyRectangularAnnulus(**self._to_sky_params(wcs))
 
 
@@ -476,21 +485,30 @@ class SkyRectangularAperture(SkyAperture):
     --------
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
-    >>> from photutils import SkyRectangularAperture
+    >>> from photutils.aperture import SkyRectangularAperture
     >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
     >>> aper = SkyRectangularAperture(positions, 1.0*u.arcsec, 0.5*u.arcsec)
     """
 
     _shape_params = ('w', 'h', 'theta')
-    positions = SkyCoordPositions('positions')
-    w = AngleOrPixelScalarQuantity('w')
-    h = AngleOrPixelScalarQuantity('h')
-    theta = AngleScalarQuantity('theta')
+    positions = SkyCoordPositions(
+        'positions',
+        description='The center position(s) in sky coordinates.')
+    w = AngleOrPixelScalarQuantity(
+        'w',
+        description='The full width, in angular or pixel units.')
+    h = AngleOrPixelScalarQuantity(
+        'h',
+        description='The full height, in angular or pixel units.')
+    theta = AngleScalarQuantity(
+        'theta',
+        description=('The position angle (in angular units) of the '
+                     'rectangle "width" side.'))
 
     def __init__(self, positions, w, h, theta=0.*u.deg):
         if w.unit.physical_type != h.unit.physical_type:
-            raise ValueError("'w' and 'h' should either both be angles or "
-                             "in pixels")
+            raise ValueError('"w" and "h" should either both be angles or '
+                             'in pixels')
 
         self.positions = positions
         self.w = w
@@ -505,22 +523,21 @@ class SkyRectangularAperture(SkyAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         aperture : `RectangularAperture` object
             A `RectangularAperture` object.
         """
-
         return RectangularAperture(**self._to_pixel_params(wcs))
 
 
 class SkyRectangularAnnulus(SkyAperture):
-    """
+    r"""
     A rectangular annulus aperture defined in sky coordinates.
 
     The aperture has a single fixed size/shape, but it can have multiple
@@ -544,10 +561,15 @@ class SkyRectangularAnnulus(SkyAperture):
 
     h_out : scalar `~astropy.units.Quantity`
         The outer full height of the rectangular annulus, either in
-        angular or pixel units.  The inner full height is calculated as:
+        angular or pixel units.
+
+    h_in : `None` or scalar `~astropy.units.Quantity`
+        The outer full height of the rectangular annulus, either in
+        angular or pixel units.  If `None`, then the inner full height
+        is calculated as:
 
             .. math:: h_{in} = h_{out}
-                \\left(\\frac{w_{in}}{w_{out}}\\right)
+                \left(\frac{w_{in}}{w_{out}}\right)
 
         For ``theta=0`` the height side is along the East-West axis.
 
@@ -561,33 +583,59 @@ class SkyRectangularAnnulus(SkyAperture):
     --------
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
-    >>> from photutils import SkyRectangularAnnulus
+    >>> from photutils.aperture import SkyRectangularAnnulus
     >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
     >>> aper = SkyRectangularAnnulus(positions, 3.0*u.arcsec, 8.0*u.arcsec,
     ...                              5.0*u.arcsec)
     """
 
-    _shape_params = ('w_in', 'w_out', 'h_out', 'theta')
-    positions = SkyCoordPositions('positions')
-    w_in = AngleOrPixelScalarQuantity('w_in')
-    w_out = AngleOrPixelScalarQuantity('w_out')
-    h_out = AngleOrPixelScalarQuantity('h_out')
-    theta = AngleScalarQuantity('theta')
+    _shape_params = ('w_in', 'w_out', 'h_in', 'h_out', 'theta')
+    positions = SkyCoordPositions(
+        'positions',
+        description='The center position(s) in sky coordinates.')
+    w_in = AngleOrPixelScalarQuantity(
+        'w_in',
+        description='The inner full width, in angular or pixel units.')
+    w_out = AngleOrPixelScalarQuantity(
+        'w_out',
+        description='The outer full width, in angular or pixel units.')
+    h_in = AngleOrPixelScalarQuantity(
+        'h_in',
+        description='The inner full height, in angular or pixel units.')
+    h_out = AngleOrPixelScalarQuantity(
+        'h_out',
+        description='The outer full height, in angular or pixel units.')
+    theta = AngleScalarQuantity(
+        'theta',
+        description=('The position angle (in angular units) of the '
+                     'rectangle "width" side.'))
 
-    def __init__(self, positions, w_in, w_out, h_out, theta=0.*u.deg):
+    def __init__(self, positions, w_in, w_out, h_out, h_in=None,
+                 theta=0.*u.deg):
         if w_in.unit.physical_type != w_out.unit.physical_type:
-            raise ValueError("w_in and w_out should either both be angles or "
-                             "in pixels")
-
+            raise ValueError('w_in and w_out should either both be angles or '
+                             'in pixels')
         if w_out.unit.physical_type != h_out.unit.physical_type:
-            raise ValueError("w_out and h_out should either both be angles "
-                             "or in pixels")
+            raise ValueError('w_out and h_out should either both be angles '
+                             'or in pixels')
+        if not w_out > w_in:
+            raise ValueError('"w_out" must be greater than "w_in".')
 
         self.positions = positions
         self.w_in = w_in
         self.w_out = w_out
         self.h_out = h_out
-        self.h_in = self.w_in * self.h_out / self.w_out
+
+        if h_in is None:
+            h_in = self.w_in * self.h_out / self.w_out
+        else:
+            if h_in.unit.physical_type != h_out.unit.physical_type:
+                raise ValueError('h_in and h_out should either both be '
+                                 'angles or in pixels')
+            if not h_out > h_in:
+                raise ValueError('"h_out" must be greater than "h_in".')
+        self.h_in = h_in
+
         self.theta = theta
 
     def to_pixel(self, wcs):
@@ -598,15 +646,14 @@ class SkyRectangularAnnulus(SkyAperture):
         Parameters
         ----------
         wcs : WCS object
-            A world coordinate system (WCS) transformation that supports
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            A world coordinate system (WCS) transformation that
+            supports the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
 
         Returns
         -------
         aperture : `RectangularAnnulus` object
             A `RectangularAnnulus` object.
         """
-
         return RectangularAnnulus(**self._to_pixel_params(wcs))
