@@ -7,6 +7,7 @@ import inspect
 import warnings
 
 from astropy.nddata.utils import overlap_slices
+from astropy.utils.decorators import deprecated
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
@@ -88,19 +89,25 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
     are `None`, then the box will be centered at the position of the
     maximum value in the input ``data``.
 
-    If ``xmax`` and ``ymax`` are specified, the ``search_boxsize``
+    If ``xpeak`` and ``ypeak`` are specified, the ``search_boxsize``
     optional keyword can be used to further refine the initial center of
     the fitting box by searching for the position of the maximum pixel
     within a box of size ``search_boxsize``.
 
+    `Vakili & Hogg (2016) <https://arxiv.org/abs/1610.05873>`_
+    demonstrate that 2D quadratic centroiding comes very
+    close to saturating the `Cramér-Rao lower bound
+    <https://en.wikipedia.org/wiki/Cram%C3%A9r%E2%80%93Rao_bound>`_ in a
+    wide range of conditions.
+
     Parameters
     ----------
-    image_data : numpy.ndarray
+    data : numpy.ndarray
         Image data.
 
     xpeak, ypeak : float or `None`, optional
-        The initial guess of the position of the centroid. When both
-        ``xpeak`` and ``ypeak`` are `None` then the position of the
+        The initial guess of the position of the centroid. If either
+        ``xpeak`` or ``ypeak`` is `None` then the position of the
         maximum value in the input ``data`` will be used as the initial
         guess.
 
@@ -110,14 +117,14 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
         ``(ny, nx)`` order. If ``fit_boxsize`` is a scalar then a square
         box of size ``fit_boxsize`` will be used.
 
-    search_boxsize: int or tuple of int, optional
+    search_boxsize : int or tuple of int, optional
         The size (in pixels) of the box used to search for the maximum
-        pixel value if ``xpeak`` and ``ypeak`` are both `None`. If
-        ``fit_boxsize`` has two elements, they should be in ``(ny, nx)``
-        order. If ``fit_boxsize`` is a scalar then a square box of size
-        ``fit_boxsize`` will be used.  This parameter is ignored when
-        ``xmax`` and ``ymax`` are both `None`.  In that case, the entire
-        array is search for the maximum value.
+        pixel value if ``xpeak`` and ``ypeak`` are both specified. If
+        ``fit_boxsize`` has two elements, they should be in ``(ny,
+        nx)`` order. If ``fit_boxsize`` is a scalar then a square box
+        of size ``fit_boxsize`` will be used. This parameter is ignored
+        if either ``xpeak`` or ``ypeak`` is `None`. In that case, the
+        entire array is search for the maximum value.
 
     mask : bool `~numpy.ndarray`, optional
         A boolean mask, with the same shape as ``data``, where a `True`
@@ -128,11 +135,27 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
     -------
     centroid : `~numpy.ndarray`
         The ``x, y`` coordinates of the centroid.
+
+    Notes
+    -----
+    Use ``fit_boxsize = (3, 3)`` to match the work of `Vakili &
+    Hogg (2016) <https://arxiv.org/abs/1610.05873>`_ for their 2D
+    second-order polynomial centroiding method.
+
+    References
+    ----------
+    .. [1] Vakili and Hogg 2016; arXiv:1610.05873
+        (https://arxiv.org/abs/1610.05873)
     """
     if ((xpeak is None and ypeak is not None)
             or (xpeak is not None and ypeak is None)):
         raise ValueError('xpeak and ypeak must both be input or "None"')
 
+    if xpeak is not None and ((xpeak < 0) or (xpeak > data.shape[1] - 1)):
+        raise ValueError('xpeak is outside of the input data')
+    if ypeak is not None and ((ypeak < 0) or (ypeak > data.shape[0] - 1)):
+        raise ValueError('ypeak is outside of the input data')
+
     data = np.asanyarray(data, dtype=float)
     ny, nx = data.shape
 
@@ -154,7 +177,7 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
         raise ValueError('fit_boxsize is too small.  6 values are required '
                          'to fit a 2D quadratic polynomial.')
 
-    if xpeak is None:  # and ypeak too
+    if xpeak is None or ypeak is None:
         yidx, xidx = np.unravel_index(np.nanargmax(data), data.shape)
     else:
         xidx = _py2intround(xpeak)
@@ -163,8 +186,8 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
         if search_boxsize is not None:
             search_boxsize = _process_boxsize(search_boxsize, data.shape)
 
-            slc_data, slc_cutout = overlap_slices(data.shape, search_boxsize,
-                                                  (yidx, xidx), mode='trim')
+            slc_data, _ = overlap_slices(data.shape, search_boxsize,
+                                         (yidx, xidx), mode='trim')
             cutout = data[slc_data]
             yidx, xidx = np.unravel_index(np.nanargmax(cutout), cutout.shape)
             xidx += slc_data[1].start
@@ -178,8 +201,8 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
         return np.array((xidx, yidx), dtype=float)
 
     # extract the fitting region
-    slc_data, slc_cutout = overlap_slices(data.shape, fit_boxsize,
-                                          (yidx, xidx), mode='trim')
+    slc_data, _ = overlap_slices(data.shape, fit_boxsize, (yidx, xidx),
+                                 mode='trim')
     xidx0, xidx1 = (slc_data[1].start, slc_data[1].stop)
     yidx0, yidx1 = (slc_data[0].start, slc_data[0].stop)
 
@@ -226,7 +249,7 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
 
     xm = (c01 * c11 - 2.0 * c02 * c10) / det
     ym = (c10 * c11 - 2.0 * c20 * c01) / det
-    if xm > 0.0 and xm < (nx - 1.0) and ym > 0.0 and ym < (ny - 1.0):
+    if 0.0 < xm < (nx - 1.0) and 0.0 < ym < (ny - 1.0):
         xycen = np.array((xm, ym), dtype=float)
     else:
         warnings.warn('quadratic polynomial maximum value falls outside '
@@ -250,8 +273,8 @@ def _process_boxsize(box_size, data_shape):
     return box_size
 
 
-def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
-                     error=None, mask=None, centroid_func=centroid_com):
+def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
+                     centroid_func=centroid_com, **kwargs):
     """
     Calculate the centroid of sources at the defined positions.
 
@@ -306,10 +329,18 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
         a tuple of two 1D `~numpy.ndarray`, representing the x and y
         centroids. The default is `~photutils.centroids.centroid_com`.
 
+    **kwargs : `dict`
+        Any additional keyword arguments accepted by the
+        ``centroid_func``.
+
     Returns
     -------
     xcentroid, ycentroid : `~numpy.ndarray`
-        The ``x`` and ``y`` pixel position(s) of the centroids.
+        The ``x`` and ``y`` pixel position(s) of the centroids. NaNs
+        will be returned where the centroid failed. This is usually due
+        a ``box_size`` that is too small when using a fitting-based
+        centroid function (e.g., `centroid_1dg`, `centroid_2dg`, or
+        `centroid_quadratic`.
     """
     xpos = np.atleast_1d(xpos)
     ypos = np.atleast_1d(ypos)
@@ -318,6 +349,12 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
     if ypos.ndim != 1:
         raise ValueError('ypos must be a 1D array.')
 
+    if (np.any(np.min(xpos) < 0) or np.any(np.min(ypos) < 0)
+            or np.any(np.max(xpos) > data.shape[1] - 1)
+            or np.any(np.max(ypos) > data.shape[0] - 1)):
+        raise ValueError('xpos, ypos values contains point(s) outside of '
+                         'input data')
+
     if footprint is None:
         if box_size is None:
             raise ValueError('box_size or footprint must be defined.')
@@ -334,13 +371,16 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
         if footprint.ndim != 2:
             raise ValueError('footprint must be a 2D array.')
 
-    use_error = False
     spec = inspect.getfullargspec(centroid_func)
     if 'mask' not in spec.args:
         raise ValueError('The input "centroid_func" must have a "mask" '
                          'keyword.')
-    if 'error' in spec.args:
-        use_error = True
+
+    # drop any **kwargs not supported by the centroid_func
+    centroid_kwargs = {}
+    for key, val in kwargs.items():
+        if key in spec.args:
+            centroid_kwargs[key] = val
 
     xcentroids = []
     ycentroids = []
@@ -349,26 +389,30 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
                                                     footprint.shape, (yp, xp))
         data_cutout = data[slices_large]
 
-        mask_cutout = None
-        if mask is not None:
-            mask_cutout = mask[slices_large]
-
-        footprint_mask = ~footprint
+        footprint_mask = np.logical_not(footprint)
         # trim footprint mask if it has only partial overlap on the data
         footprint_mask = footprint_mask[slices_small]
 
-        if mask_cutout is None:
+        if mask is not None:
+            # combine the input mask cutout and footprint mask
+            mask_cutout = np.logical_or(mask[slices_large], footprint_mask)
+        else:
             mask_cutout = footprint_mask
-        else:
-            # combine the input mask and footprint mask
-            mask_cutout = np.logical_or(mask_cutout, footprint_mask)
 
-        if error is not None and use_error:
-            error_cutout = error[slices_large]
-            xcen, ycen = centroid_func(data_cutout, mask=mask_cutout,
-                                       error=error_cutout)
-        else:
-            xcen, ycen = centroid_func(data_cutout, mask=mask_cutout)
+        centroid_kwargs.update({'mask': mask_cutout})
+
+        if 'error' in centroid_kwargs:
+            error_cutout = centroid_kwargs['error'][slices_large]
+            centroid_kwargs['error'] = error_cutout
+
+        if 'xpeak' in centroid_kwargs and 'ypeak' in centroid_kwargs:
+            centroid_kwargs['xpeak'] -= slices_large[1].start
+            centroid_kwargs['ypeak'] -= slices_large[0].start
+
+        try:
+            xcen, ycen = centroid_func(data_cutout, **centroid_kwargs)
+        except (ValueError, TypeError):
+            xcen, ycen = np.nan, np.nan
 
         xcentroids.append(xcen + slices_large[1].start)
         ycentroids.append(ycen + slices_large[0].start)
@@ -376,6 +420,7 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None,
     return np.array(xcentroids), np.array(ycentroids)
 
 
+@deprecated('1.2')
 def centroid_epsf(data, mask=None, oversampling=4, shift_val=0.5):
     """
     Calculate centering shift of data using pixel symmetry, as described
@@ -391,14 +436,17 @@ def centroid_epsf(data, mask=None, oversampling=4, shift_val=0.5):
     ----------
     data : array_like
         The input n-dimensional array.
+
     mask : array_like (bool), optional
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
+
     oversampling : int or tuple of two int, optional
         Oversampling factors of pixel indices. If ``oversampling`` is a
         scalar this is treated as both x and y directions having the
         same oversampling factor.  Otherwise it is treated as
         ``(x_oversamp, y_oversamp)``.
+
     shift_val : float, optional
         The undersampled value at which to compute the shifts. Default
         is half a pixel. It must be a strictly positive number.
