@@ -23,15 +23,18 @@ def get_path(filename, location='local', cache=True, show_progress=False):
     ----------
     filename : str
         File name in the local or remote data folder.
+
     location : {'local', 'remote', 'photutils-datasets'}
         File location.  ``'local'`` means bundled with ``photutils``.
         ``'remote'`` means the astropy data server (or the
         photutils-datasets repo as a backup) or the Astropy cache on
         your machine. ``'photutils-datasets'`` means the
         photutils-datasets repo or the Astropy cache on your machine.
+
     cache : bool, optional
         Whether to cache the contents of remote URLs.  Default is
         `True`.
+
     show_progress : bool, optional
         Whether to display a progress bar during the download (default
         is `False`).
@@ -44,18 +47,17 @@ def get_path(filename, location='local', cache=True, show_progress=False):
     Examples
     --------
     >>> from astropy.io import fits
-    >>> from photutils import datasets
-    >>> hdulist = fits.open(datasets.get_path('fermi_counts.fits.gz'))
+    >>> from photutils.datasets import get_path
+    >>> hdulist = fits.open(get_path('fermi_counts.fits.gz'))
     """
-
     datasets_url = ('https://github.com/astropy/photutils-datasets/raw/'
-                    'master/data/{0}'.format(filename))
+                    f'main/data/{filename}')
 
     if location == 'local':
         path = get_pkg_data_filename('data/' + filename)
     elif location == 'remote':  # pragma: no cover
         try:
-            url = 'https://data.astropy.org/photometry/{0}'.format(filename)
+            url = f'https://data.astropy.org/photometry/{filename}'
             path = download_file(url, cache=cache,
                                  show_progress=show_progress)
         except (URLError, HTTPError):  # timeout or not found
@@ -65,7 +67,7 @@ def get_path(filename, location='local', cache=True, show_progress=False):
         path = download_file(datasets_url, cache=cache,
                              show_progress=show_progress)
     else:
-        raise ValueError('Invalid location: {0}'.format(location))
+        raise ValueError(f'Invalid location: {location}')
 
     return path
 
@@ -97,11 +99,10 @@ def load_spitzer_image(show_progress=False):  # pragma: no cover
     .. plot::
         :include-source:
 
-        from photutils import datasets
-        hdu = datasets.load_spitzer_image()
+        from photutils.datasets import load_spitzer_image
+        hdu = load_spitzer_image()
         plt.imshow(hdu.data, origin='lower', vmax=50)
     """
-
     path = get_path('spitzer_example_image.fits', location='remote',
                     show_progress=show_progress)
     hdu = fits.open(path)[0]
@@ -136,15 +137,14 @@ def load_spitzer_catalog(show_progress=False):  # pragma: no cover
     .. plot::
         :include-source:
 
-        from photutils import datasets
-        catalog = datasets.load_spitzer_catalog()
+        from photutils.datasets import load_spitzer_catalog
+        catalog = load_spitzer_catalog()
         plt.scatter(catalog['l'], catalog['b'])
         plt.xlabel('Galactic l')
         plt.ylabel('Galactic b')
         plt.xlim(18.39, 18.05)
         plt.ylim(0.13, 0.30)
     """
-
     path = get_path('spitzer_example_catalog.xml', location='remote',
                     show_progress=show_progress)
     table = Table.read(path)
@@ -205,12 +205,11 @@ def load_irac_psf(channel, show_progress=False):  # pragma: no cover
         plt.tight_layout()
         plt.show()
     """
-
     channel = int(channel)
     if channel < 1 or channel > 4:
         raise ValueError('channel must be 1, 2, 3, or 4')
 
-    filepath = 'irac_ch{0}_flight.fits'.format(channel)
+    filepath = f'irac_ch{channel}_flight.fits'
     path = get_path(filepath, location='remote', show_progress=show_progress)
     hdu = fits.open(path)[0]
 
@@ -237,11 +236,10 @@ def load_fermi_image(show_progress=False):
     .. plot::
         :include-source:
 
-        from photutils import datasets
-        hdu = datasets.load_fermi_image()
+        from photutils.datasets import load_fermi_image
+        hdu = load_fermi_image()
         plt.imshow(hdu.data, vmax=10, origin='lower', interpolation='nearest')
     """
-
     path = get_path('fermi_counts.fits.gz', location='local',
                     show_progress=show_progress)
     hdu = fits.open(path)[1]
@@ -275,11 +273,10 @@ def load_star_image(show_progress=False):  # pragma: no cover
     .. plot::
         :include-source:
 
-        from photutils import datasets
-        hdu = datasets.load_star_image()
+        from photutils.datasets import load_star_image
+        hdu = load_star_image()
         plt.imshow(hdu.data, origin='lower', interpolation='nearest')
     """
-
     path = get_path('M6707HH.fits', location='remote',
                     show_progress=show_progress)
     hdu = fits.open(path)[0]
@@ -309,11 +306,10 @@ def load_simulated_hst_star_image(show_progress=False):  # pragma: no cover
     .. plot::
         :include-source:
 
-        from photutils import datasets
-        hdu = datasets.load_simulated_hst_star_image()
+        from photutils.datasets import load_simulated_hst_star_image
+        hdu = load_simulated_hst_star_image()
         plt.imshow(hdu.data, origin='lower', interpolation='nearest')
     """
-
     path = get_path('hst_wfc3ir_f160w_simulated_starfield.fits',
                     location='photutils-datasets',
                     show_progress=show_progress)
