@@ -20,7 +20,7 @@ __all__ = ['Ellipse']
 
 
 class Ellipse:
-    """
+    r"""
     Class to fit elliptical isophotes to a galaxy image.
 
     The isophotes in the image are measured using an iterative method
@@ -66,8 +66,8 @@ class Ellipse:
     fitting to the function:
 
     .. math::
-        y  =  y0 + (A1 * \\sin(E)) + (B1 * \\cos(E)) + (A2 * \\sin(2 * E))
-        + (B2 * \\cos(2 * E))
+        y  =  y0 + (A1 * \sin(E)) + (B1 * \cos(E)) + (A2 * \sin(2 * E))
+        + (B2 * \cos(2 * E))
 
     Each one of the harmonic amplitudes (A1, B1, A2, and B2) is related
     to a specific ellipse geometric parameter in the sense that it
@@ -196,7 +196,6 @@ class Ellipse:
         threshold : float
             The new threshold value to use.
         """
-
         self._geometry.centerer_threshold = threshold
 
     def fit_image(self, sma0=None, minsma=0., maxsma=None, step=0.1,
@@ -221,10 +220,10 @@ class Ellipse:
         of them is set via this call, the others will assume their default
         (False) values. This effectively overrides any settings that are
         present in the internal `~photutils.isophote.EllipseGeometry`
-        instance that is carried along as a property of this class. If an
-        instance of `~photutils.isophote.EllipseGeometry` was passed to this
-        class' constructor, that instance will be effectively overriden by
-        the fix_XXX parameters in this call.
+        instance that is carried along as a property of this class. If
+        an instance of `~photutils.isophote.EllipseGeometry` was passed
+        to this class' constructor, that instance will be effectively
+        overridden by the fix_XXX parameters in this call.
 
         Parameters
         ----------
@@ -245,25 +244,30 @@ class Ellipse:
             the `~photutils.isophote.Ellipse` constructor, its ``sma``
             value will be used.  Otherwise, a default value of 10. will
             be used.
+
         minsma : float, optional
             The minimum value for the semimajor axis length (pixels).
             The default is 0.
+
         maxsma : float or `None`, optional
             The maximum value for the semimajor axis length (pixels).
             When set to `None` (default), the algorithm will increase
             the semimajor axis until one of several conditions will
             cause it to stop and revert to fit ellipses with sma <
             ``sma0``.
+
         step : float, optional
             The step value used to grow/shrink the semimajor axis length
             (pixels if ``linear=True``, or a relative value if
             ``linear=False``). See the ``linear`` parameter.  The
             default is 0.1.
+
         conver : float, optional
             The main convergence criterion. Iterations stop when the
             largest harmonic amplitude becomes smaller (in absolute
             value) than ``conver`` times the harmonic fit rms.  The
             default is 0.05.
+
         minit : int, optional
             The minimum number of iterations to perform. A minimum of 10
             (the default) iterations guarantees that, on average, 2
@@ -273,9 +277,11 @@ class Ellipse:
             iterations is 2 * ``minit`` to ensure that, even departing
             from not-so-good initial values, the algorithm has a better
             chance to converge to a sensible solution.
+
         maxit : int, optional
             The maximum number of iterations to perform.  The default is
             50.
+
         fflag : float, optional
             The acceptable fraction of flagged data points in the
             sample.  If the actual fraction of valid data points is
@@ -284,6 +290,7 @@ class Ellipse:
             data points are points that either lie outside the image
             frame, are masked, or were rejected by sigma-clipping.  The
             default is 0.7.
+
         maxgerr : float, optional
             The maximum acceptable relative error in the local radial
             intensity gradient. This is the main control for preventing
@@ -310,13 +317,17 @@ class Ellipse:
             value is larger than the current semimajor axis length, the
             algorithm enters non-iterative mode and proceeds outwards
             until reaching ``maxsma``.  The default is 0.5.
+
         sclip : float, optional
             The sigma-clip sigma value.  The default is 3.0.
+
         nclip : int, optional
-            The number of sigma-clip interations.  The default is 0,
-            which means sigma-clipping is skipped.
+            The number of sigma-clip iterations. The default is 0, which
+            means sigma-clipping is skipped.
+
         integrmode : {'bilinear', 'nearest_neighbor', 'mean', 'median'}, optional
             The area integration mode.  The default is 'bilinear'.
+
         linear : bool, optional
             The semimajor axis growing/shrinking mode. If `False`
             (default), the geometric growing mode is chosen, thus the
@@ -332,6 +343,7 @@ class Ellipse:
             given directly by ``step`` in pixels.  If ``maxsma`` is set
             to `None`, the semimajor axis will grow until a low
             signal-to-noise criterion is met. See ``maxgerr``.
+
         maxrit : float or `None`, optional
             The maximum value of semimajor axis to perform an actual
             fit.  Whenever the current semimajor axis length is larger
@@ -344,11 +356,14 @@ class Ellipse:
             whenever the ellipticity exceeds 1.0 or the ellipse center
             crosses the image boundaries.  If `None` (default), then no
             maximum value is used.
+
         fix_center : bool, optional
             Keep center of ellipse fixed during fit? The default is False.
+
         fix_pa : bool, optional
             Keep position angle of semi-major axis of ellipse fixed during fit?
             The default is False.
+
         fix_eps : bool, optional
             Keep ellipticity of ellipse fixed during fit? The default is False.
 
@@ -358,7 +373,6 @@ class Ellipse:
             A list-like object of `~photutils.isophote.Isophote`
             instances, sorted by increasing semimajor axis length.
         """
-
         # multiple fitted isophotes will be stored here
         isophote_list = []
 
@@ -507,16 +521,19 @@ class Ellipse:
         ----------
         sma : float
             The semimajor axis length (pixels).
+
         step : float, optional
             The step value used to grow/shrink the semimajor axis length
             (pixels if ``linear=True``, or a relative value if
             ``linear=False``). See the ``linear`` parameter.  The
             default is 0.1.
+
         conver : float, optional
             The main convergence criterion. Iterations stop when the
             largest harmonic amplitude becomes smaller (in absolute
             value) than ``conver`` times the harmonic fit rms.  The
             default is 0.05.
+
         minit : int, optional
             The minimum number of iterations to perform. A minimum of 10
             (the default) iterations guarantees that, on average, 2
@@ -526,9 +543,11 @@ class Ellipse:
             iterations is 2 * ``minit`` to ensure that, even departing
             from not-so-good initial values, the algorithm has a better
             chance to converge to a sensible solution.
+
         maxit : int, optional
             The maximum number of iterations to perform.  The default is
             50.
+
         fflag : float, optional
             The acceptable fraction of flagged data points in the
             sample.  If the actual fraction of valid data points is
@@ -537,23 +556,29 @@ class Ellipse:
             data points are points that either lie outside the image
             frame, are masked, or were rejected by sigma-clipping.  The
             default is 0.7.
+
         maxgerr : float, optional
             The maximum acceptable relative error in the local radial
-            intensity gradient.  When fitting a single isophote by
-            itself this paramter doesn't have any effect on the outcome.
+            intensity gradient. When fitting a single isophote by itself
+            this parameter doesn't have any effect on the outcome.
+
         sclip : float, optional
             The sigma-clip sigma value.  The default is 3.0.
+
         nclip : int, optional
-            The number of sigma-clip interations.  The default is 0,
-            which means sigma-clipping is skipped.
+            The number of sigma-clip iterations. The default is 0, which
+            means sigma-clipping is skipped.
+
         integrmode : {'bilinear', 'nearest_neighbor', 'mean', 'median'}, optional
             The area integration mode.  The default is 'bilinear'.
+
         linear : bool, optional
             The semimajor axis growing/shrinking mode.  When fitting
             just one isophote, this parameter is used only by the code
             that define the details of how elliptical arc segments
             ("sectors") are extracted from the image when using area
             extraction modes (see the ``integrmode`` parameter).
+
         maxrit : float or `None`, optional
             The maximum value of semimajor axis to perform an actual
             fit.  Whenever the current semimajor axis length is larger
@@ -566,6 +591,7 @@ class Ellipse:
             whenever the ellipticity exceeds 1.0 or the ellipse center
             crosses the image boundaries.  If `None` (default), then no
             maximum value is used.
+
         noniterate : bool, optional
             Whether the fitting algorithm should be bypassed and an
             isophote should be extracted with the geometry taken
@@ -577,6 +603,7 @@ class Ellipse:
             along the sequence of isophotes. When set to `True`, this
             parameter overrides the behavior associated with parameter
             ``maxrit``.  The default is `False`.
+
         going_inwards : bool, optional
             Parameter to define the sense of SMA growth. When fitting
             just one isophote, this parameter is used only by the code
@@ -584,6 +611,7 @@ class Ellipse:
             ("sectors") are extracted from the image, when using area
             extraction modes (see the ``integrmode`` parameter).  The
             default is `False`.
+
         isophote_list : list or `None`, optional
             If not `None` (the default), the fitted
             `~photutils.isophote.Isophote` instance is appended to this
@@ -595,7 +623,6 @@ class Ellipse:
             The fitted isophote. The fitted isophote is also appended to
             the input list input to the ``isophote_list`` parameter.
         """
-
         geometry = self._geometry
 
         # if available, geometry from last fitted isophote will be
