@@ -55,7 +55,6 @@ def _area(sma, eps, phi, r):
     """
     Compute elliptical sector area.
     """
-
     aux = r * math.cos(phi) / sma
     signal = aux / abs(aux)
     if abs(aux) >= 1.:
@@ -64,7 +63,7 @@ def _area(sma, eps, phi, r):
 
 
 class EllipseGeometry:
-    """
+    r"""
     Container class to store parameters for the geometry of an ellipse.
 
     Parameters that describe the relationship of a given ellipse with
@@ -90,11 +89,11 @@ class EllipseGeometry:
         The ellipticity of the ellipse.
     pa : float
         The position angle (in radians) of the semimajor axis in
-        relation to the postive x axis of the image array (rotating
+        relation to the positive x axis of the image array (rotating
         towards the positive y axis). Position angles are defined in the
-        range :math:`0 < PA <= \\pi`. Avoid using as starting position
-        angle of 0., since the fit algorithm may not work properly. When
-        the ellipses are such that position angles are near either
+        range :math:`0 < PA <= \pi`. Avoid using as starting position
+        angle of 0., since the fit algorithm may not work properly.
+        When the ellipses are such that position angles are near either
         extreme of the range, noise can make the solution jump back and
         forth between successive isophotes, by amounts close to 180
         degrees.
@@ -152,7 +151,7 @@ class EllipseGeometry:
         Find the center of a galaxy.
 
         If the algorithm is successful the (x, y) coordinates in this
-        `~photutils.isophote.EllipseGeometry` (i.e. the ``x0`` and
+        `~photutils.isophote.EllipseGeometry` (i.e., the ``x0`` and
         ``y0`` attributes) instance will be modified.
 
         The isophote fit algorithm requires an initial guess for the
@@ -167,9 +166,11 @@ class EllipseGeometry:
         image : 2D `~numpy.ndarray`
             The image array.  Masked arrays are not recognized here. This
             assumes that centering should always be done on valid pixels.
+
         threshold : float, optional
             The centerer threshold.  To turn off the centerer, set this
-            to a large value (i.e. >> 1).  The default is 0.1.
+            to a large value (i.e., >> 1).  The default is 0.1.
+
         verbose : bool, optional
             Whether to print object centering information.  The default is
             `True`.
@@ -187,17 +188,16 @@ class EllipseGeometry:
         place to reflect the solution of the object centerer algorithm.
 
         In some cases the object centerer algorithm may fail even though
-        there is enough signal-to-noise to start a fit (e.g. objects
-        with very high ellipticity).  In those cases the sensitivity of
-        the algorithm can be decreased by decreasing the value of the
-        object centerer threshold parameter.  The centerer works by
+        there is enough signal-to-noise to start a fit (e.g., objects
+        with very high ellipticity). In those cases the sensitivity
+        of the algorithm can be decreased by decreasing the value of
+        the object centerer threshold parameter. The centerer works by
         looking where a quantity akin to a signal-to-noise ratio is
-        maximized within the 10x10 window.  The centerer can thus be
-        shut off entirely by setting the threshold to a large value
-        (i.e. >> 1; meaning no location inside the search window will
-        achieve that signal-to-noise ratio).
+        maximized within the 10x10 window. The centerer can thus be shut
+        off entirely by setting the threshold to a large value (i.e.,
+        >> 1; meaning no location inside the search window will achieve
+        that signal-to-noise ratio).
         """
-
         self._centerer_mask_half_size = len(IN_MASK) / 2
         self.centerer_threshold = threshold
 
@@ -263,8 +263,8 @@ class EllipseGeometry:
             self.y0 = float(max_j)
 
             if verbose:
-                log.info("Found center at x0 = {0:5.1f}, y0 = {1:5.1f}"
-                         .format(self.x0, self.y0))
+                log.info(f'Found center at x0 = {self.x0:5.1f}, '
+                         f'y0 = {self.y0:5.1f}')
         else:
             if verbose:
                 log.info('Result is below the threshold -- keeping the '
@@ -284,7 +284,6 @@ class EllipseGeometry:
         radius : float
             The polar radius (pixels).
         """
-
         return (self.sma * (1. - self.eps) /
                 np.sqrt(((1. - self.eps) * np.cos(angle))**2 +
                         (np.sin(angle))**2))
@@ -312,7 +311,6 @@ class EllipseGeometry:
         x, y : 1D `~numpy.ndarray`
             The x and y coordinates of each vertex as 1D arrays.
         """
-
         # These polar radii bound the region between the inner
         # and outer ellipses that define the sector.
         sma1, sma2 = self.bounding_ellipses()
@@ -371,7 +369,6 @@ class EllipseGeometry:
             The smaller and larger values of semimajor axis length that
             define the annulus bounding ellipses.
         """
-
         if self.linear_growth:
             a1 = self.sma - self.astep / 2.
             a2 = self.sma + self.astep / 2.
@@ -396,11 +393,10 @@ class EllipseGeometry:
             The smaller and larger values of polar angle that bound the
             current sector.
         """
-
         return self._phi1, self._phi2
 
     def to_polar(self, x, y):
-        """
+        r"""
         Return the radius and polar angle in the ellipse coordinate
         system given (x, y) pixel image coordinates.
 
@@ -408,9 +404,9 @@ class EllipseGeometry:
         position angle (PA) and polar angle (phi):
 
         .. math::
-            -\\pi < PA < \\pi
+            -\pi < PA < \pi
 
-            0 < phi < 2 \\pi
+            0 < phi < 2 \pi
 
         Note that radius can be anything.  The solution is not tied to
         the semimajor axis length, but to the center position and tilt
@@ -441,7 +437,6 @@ class EllipseGeometry:
             return self._to_polar_vectorized(x, y)
 
     def _to_polar_scalar(self, x, y):
-
         x1 = x - self.x0
         y1 = y - self.y0
 
@@ -470,7 +465,6 @@ class EllipseGeometry:
         return radius, angle
 
     def _to_polar_vectorized(self, x, y):
-
         x1 = np.atleast_2d(x) - self.x0
         y1 = np.atleast_2d(y) - self.y0
 
@@ -516,7 +510,6 @@ class EllipseGeometry:
         sma : float
             The new semimajor axis length.
         """
-
         if self.linear_growth:
             sma = self.sma + step
         else:
@@ -542,7 +535,6 @@ class EllipseGeometry:
             :meth:`~photutils.isophote.EllipseGeometry.update_sma`
             method.
         """
-
         if self.linear_growth:
             sma = self.sma - step
             step = -step
