@@ -25,15 +25,22 @@ class _Integrator:
     ----------
     image : 2D `~numpy.ndarray`
          The image array.
+
     geometry : `~photutils.isophote.EllipseGeometry` instance
-        object that encapsulates geometry information about current ellipse
+        Object that encapsulates geometry information about current
+        ellipse.
+
     angles : list
-        output list; contains the angle values along the elliptical path
+        Output list; contains the angle values along the elliptical
+        path.
+
     radii : list
-        output list; contains the radius values along the elliptical path
+        Output list; contains the radius values along the elliptical
+        path.
+
     intensities : list
-        output list; contains the extracted intensity values along the
-        elliptical path
+        Output list; contains the extracted intensity values along the
+        elliptical path.
     """
 
     def __init__(self, image, geometry, angles, radii, intensities):
@@ -59,21 +66,20 @@ class _Integrator:
         Parameters
         ----------
         radius : float
-            length of radius vector in pixels
-        phi : float
-            polar angle of radius vector
-        """
+            The length of the radius vector in pixels.
 
+        phi : float
+            The polar angle of radius vector.
+        """
         raise NotImplementedError
 
     def _reset(self):
         """
-        Starts the results lists anew.
+        Reset the lists containing results.
 
         This method is for internal use and shouldn't
         be used by external callers.
         """
-
         self._angles = []
         self._radii = []
         self._intensities = []
@@ -85,23 +91,22 @@ class _Integrator:
 
     def get_polar_angle_step(self):
         """
-        Returns the polar angle step used to walk over the
-        elliptical path.
+        Return the polar angle step used to walk over the elliptical
+        path.
 
         The polar angle step is defined by the actual integrator
         subclass.
 
         Returns
         -------
-        float
-           the polar angle step
+        result : float
+            The polar angle step.
         """
-
         raise NotImplementedError
 
     def get_sector_area(self):
         """
-        Returns the area of elliptical sectors where the integration
+        Return the area of elliptical sectors where the integration
         takes place.
 
         This area is defined and managed by the actual integrator
@@ -111,15 +116,14 @@ class _Integrator:
 
         Returns
         -------
-        float
-           the sector area
+        result : float
+            The sector area.
         """
-
         raise NotImplementedError
 
     def is_area(self):
         """
-        Returns the type of the integrator.
+        Return the type of the integrator.
 
         An area integrator gets it's value from operating over a (generally
         variable) number of pixels that define a finite area that  lays
@@ -132,10 +136,9 @@ class _Integrator:
 
         Returns
         -------
-        boolean
-           True if this is an area integrator, False otherwise
+        result : boolean
+            True if this is an area integrator, False otherwise.
         """
-
         raise NotImplementedError
 
 
