@@ -3,14 +3,13 @@
 This module provides classes to store the results of isophote fits.
 """
 
-from collections import OrderedDict
-
 from astropy.table import QTable
 import astropy.units as u
 import numpy as np
 
 from .harmonics import (first_and_second_harmonic_function,
                         fit_first_and_second_harmonics, fit_upper_harmonic)
+from ..utils._misc import _get_version_info
 
 __all__ = ['Isophote', 'IsophoteList']
 
@@ -186,7 +185,6 @@ class Isophote:
         ellipse radius vector, and integrals are updated if the pixel
         distance is smaller.
         """
-
         # Compute limits of square array that encloses circle.
         sma = self.sample.geometry.sma
         x0 = self.sample.geometry.x0
@@ -267,7 +265,6 @@ class Isophote:
         matrix of the four harmonic coefficients for harmonics n=1 and
         n=2.
         """
-
         try:
             coeffs, covariance = fit_first_and_second_harmonics(
                 self.sample.values[0], self.sample.values[2])
@@ -315,7 +312,6 @@ class Isophote:
         isophote : `~photutils.isophote.Isophote` instance
             The isophote from which to take the geometry information.
         """
-
         self.sample.geometry.eps = isophote.sample.geometry.eps
         self.sample.geometry.pa = isophote.sample.geometry.pa
         self.sample.geometry.x0 = isophote.sample.geometry.x0
@@ -331,7 +327,6 @@ class Isophote:
         x, y : 1D `~numpy.ndarray`
             The x and y coordinates as 1D arrays.
         """
-
         return self.sample.coordinates()
 
     def to_table(self):
@@ -343,9 +338,8 @@ class Isophote:
         -------
         result : `~astropy.table.QTable`
             An astropy `~astropy.table.QTable` containing the main
-            isophote paramters.
+            isophote parameters.
         """
-
         return _isophote_list_to_table([self])
 
 
@@ -484,7 +478,6 @@ class IsophoteList:
         isophote : `~photutils.isophote.Isophote` instance
             The isophote with the closest semimajor axis value.
         """
-
         index = (np.abs(self.sma - sma)).argmin()
         return self._list[index]
 
@@ -615,7 +608,6 @@ class IsophoteList:
     @property
     def niter(self):
         """The number of iterations used to fit the isophote."""
-
         return self._collect_as_array('niter')
 
     @property
@@ -657,7 +649,7 @@ class IsophoteList:
     @property
     def a3(self):
         """
-        A third-order harmonic coefficent.  See the
+        A third-order harmonic coefficient.  See the
         :func:`~photutils.isophote.fit_upper_harmonic` function for
         details.
         """
@@ -666,7 +658,7 @@ class IsophoteList:
     @property
     def b3(self):
         """
-        A third-order harmonic coefficent.  See the
+        A third-order harmonic coefficient.  See the
         :func:`~photutils.isophote.fit_upper_harmonic` function for
         details.
         """
@@ -675,7 +667,7 @@ class IsophoteList:
     @property
     def a4(self):
         """
-        A fourth-order harmonic coefficent.  See the
+        A fourth-order harmonic coefficient.  See the
         :func:`~photutils.isophote.fit_upper_harmonic` function for
         details.
         """
@@ -684,7 +676,7 @@ class IsophoteList:
     @property
     def b4(self):
         """
-        A fourth-order harmonic coefficent.  See the
+        A fourth-order harmonic coefficient.  See the
         :func:`~photutils.isophote.fit_upper_harmonic` function for
         details.
         """
@@ -718,7 +710,7 @@ class IsophoteList:
         """
         return self._collect_as_array('b4_err')
 
-    def to_table(self):
+    def to_table(self, columns='main'):
         """
         Convert an `~photutils.isophote.IsophoteList` instance to a
         `~astropy.table.QTable` with the main isophote parameters.
@@ -728,10 +720,42 @@ class IsophoteList:
         result : `~astropy.table.QTable`
             An astropy QTable with the main isophote parameters.
         """
-        return _isophote_list_to_table(self)
+        return _isophote_list_to_table(self, columns)
+
+    def get_names(self):
+        """
+        Print the names of the properties of an
+        `~photutils.isophote.IsophoteList` instance.
+        """
+        list_names = list(_get_properties(self).keys())
+        return list_names
 
 
-def _isophote_list_to_table(isophote_list):
+def _get_properties(isophote_list):
+    """
+    Return the properties of an `~photutils.isophote.IsophoteList`
+    instance.
+
+    Parameters
+    ----------
+    isophote_list : `~photutils.isophote.IsophoteList` instance
+        A list of isophotes.
+
+    Returns
+    -------
+    result : `dict`
+        An OrderedDict with the list of the isophote_list properties.
+    """
+    properties = dict()
+    for an_item in isophote_list.__class__.__dict__:
+        p_type = isophote_list.__class__.__dict__[an_item]
+        # Exclude the sample property
+        if type(p_type) == property and 'sample' not in an_item:
+            properties[str(an_item)] = str(an_item)
+    return properties
+
+
+def _isophote_list_to_table(isophote_list, columns='main'):
     """
     Convert an `~photutils.isophote.IsophoteList` instance to
     a `~astropy.table.QTable`.
@@ -742,33 +766,72 @@ def _isophote_list_to_table(isophote_list):
             `~photutils.isophote.IsophoteList` instance
         A list of isophotes.
 
+    columns : list of str
+        A list of properties to export from the isophote_list. If
+        ``columns`` is 'all' or 'main', it will pick all or few of the
+        main properties.
+
     Returns
     -------
     result : `~astropy.table.QTable`
-        An astropy QTable with the main isophote parameters.
+        An astropy QTable with the selected or all isophote parameters.
     """
+    properties = {}
+    meta = {'version': _get_version_info()}
+    isotable = QTable(meta=meta)
 
-    properties = OrderedDict()
-    properties['sma'] = 'sma'
-    properties['intens'] = 'intens'
-    properties['int_err'] = 'intens_err'
-    properties['eps'] = 'ellipticity'
-    properties['ellip_err'] = 'ellipticity_err'
-    properties['pa'] = 'pa'
-    properties['pa_err'] = 'pa_err'
-    properties['grad'] = 'grad'
-    properties['grad_error'] = 'grad_err'
-    properties['grad_r_error'] = 'grad_rerr'
-    properties['x0'] = 'x0'
-    properties['x0_err'] = 'x0_err'
-    properties['y0'] = 'y0'
-    properties['y0_err'] = 'y0_err'
-    properties['ndata'] = 'ndata'
-    properties['nflag'] = 'flag'
-    properties['niter'] = 'niter'
-    properties['stop_code'] = 'stop_code'
+    # main_properties: `List`
+    # A list of main parameters matching the original names of
+    # the isophote_list parameters
 
-    isotable = QTable()
+    def __rename_properties(properties,
+                            orig_names=['int_err', 'eps', 'ellip_err',
+                                        'grad_r_error', 'nflag'],
+                            new_names=['intens_err', 'ellipticity',
+                                       'ellipticity_err', 'grad_rerror',
+                                       'nflag']):
+        """
+        Simple renaming for some of the isophote_list parameters.
+
+        Parameters
+        ----------
+        properties : `dict`
+            A dictionary with the list of the isophote_list parameters.
+
+        orig_names : list
+            A list of original names in the isophote_list parameters to
+            be renamed.
+
+        new_names : list
+            A list of new names matching in length of the orig_names.
+
+        Returns
+        -------
+        properties: `dict`
+            A dictionary with the list of the renamed isophote_list
+            parameters.
+        """
+        main_properties = ['sma', 'intens', 'int_err', 'eps', 'ellip_err',
+                           'pa', 'pa_err', 'grad', 'grad_error',
+                           'grad_r_error', 'x0', 'x0_err', 'y0', 'y0_err',
+                           'ndata', 'nflag', 'niter', 'stop_code']
+
+        for an_item in main_properties:
+            if an_item in orig_names:
+                properties[an_item] = new_names[orig_names.index(an_item)]
+            else:
+                properties[an_item] = an_item
+        return properties
+
+    if columns == 'all':
+        properties = _get_properties(isophote_list)
+        properties = __rename_properties(properties)
+
+    elif columns == 'main':
+        properties = __rename_properties(properties)
+    else:
+        for an_item in columns:
+            properties[an_item] = an_item
 
     for k, v in properties.items():
         isotable[v] = np.array([getattr(iso, k) for iso in isophote_list])
