@@ -45,8 +45,8 @@ class EllipseSample:
     sclip : float, optional
         The sigma-clip sigma value.  The default is 3.0.
     nclip : int, optional
-        The number of sigma-clip interations.  Set to zero to skip
-        sigma-clipping.  The default is 0.
+        The number of sigma-clip iterations. Set to zero to skip
+        sigma-clipping. The default is 0.
     linear_growth : bool, optional
         The semimajor axis growing/shrinking mode.  The default is
         `False`.
@@ -143,7 +143,6 @@ class EllipseSample:
             The rows of the array contain the angles, radii, and
             extracted intensity values, respectively.
         """
-
         # the sample values themselves are kept cached to prevent
         # multiple calls to the integrator code.
         if self.values is not None:
@@ -288,7 +287,6 @@ class EllipseSample:
         then computes the the mean intensity, local gradient, and other
         associated quantities.
         """
-
         if fixed_parameters is None:
             fixed_parameters = np.array([False, False, False, False])
         self.geometry.fix = fixed_parameters
@@ -331,7 +329,7 @@ class EllipseSample:
 
         self.gradient = gradient
         self.gradient_error = gradient_error
-        if gradient_error:
+        if gradient_error and gradient < 0.:
             self.gradient_relative_error = gradient_error / np.abs(gradient)
         else:
             self.gradient_relative_error = None
@@ -371,7 +369,6 @@ class EllipseSample:
         x, y : 1D `~numpy.ndarray`
             The x and y coordinate arrays.
         """
-
         angles = self.values[0]
         radii = self.values[1]
         x = np.zeros(len(angles))
@@ -401,7 +398,6 @@ class CentralEllipseSample(EllipseSample):
 
         'fixed_parameters' is ignored in this subclass.
         """
-
         s = self.extract()
         self.mean = s[2][0]
 
