@@ -16,15 +16,10 @@ from ..integrator import MEAN
 from ..isophote import Isophote
 from ..sample import CentralEllipseSample, EllipseSample
 from ...datasets import get_path
-
-try:
-    import scipy  # noqa
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+from ...utils._optional_deps import HAS_SCIPY  # noqa
 
 
-DATA = make_test_image(random_state=123)
+DATA = make_test_image(seed=0)
 DEFAULT_POS = 256
 
 DEFAULT_FIX = np.array([False, False, False, False])
@@ -95,7 +90,7 @@ def test_fitting_eps():
 
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_fitting_pa():
-    data = make_test_image(pa=np.pi/4, noise=0.01, random_state=123)
+    data = make_test_image(pa=np.pi/4, noise=0.01, seed=0)
 
     # initial guess is off in the pa parameter
     sample = EllipseSample(data, 40)
@@ -110,7 +105,7 @@ def test_fitting_pa():
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_fitting_xy():
     pos = DEFAULT_POS - 5
-    data = make_test_image(x0=pos, y0=pos, random_state=123)
+    data = make_test_image(x0=pos, y0=pos, seed=0)
 
     # initial guess is off in the x0 and y0 parameters
     sample = EllipseSample(data, 40)
@@ -131,8 +126,7 @@ def test_fitting_all():
     pos = DEFAULT_POS - 5
     angle = np.pi / 4
     eps = 2 * 0.2
-    data = make_test_image(x0=pos, y0=pos, eps=eps, pa=angle,
-                           random_state=123)
+    data = make_test_image(x0=pos, y0=pos, eps=eps, pa=angle, seed=0)
     sma = 60.
 
     # initial guess is off in all parameters. We find that the initial
@@ -201,7 +195,7 @@ class TestM51:
         isophote = fitter.fit()
 
         assert isophote.ndata == 382
-        assert_allclose(isophote.intens, 156.3, atol=0.1)
+        assert_allclose(isophote.intens, 155.0, atol=0.1)
 
     def test_m51_outer(self):
         # sample taken at the outskirts of the image, so many
