@@ -12,24 +12,21 @@ from ..harmonics import (first_and_second_harmonic_function,
                          fit_first_and_second_harmonics, fit_upper_harmonic)
 from ..sample import EllipseSample
 from ..fitter import EllipseFitter
-
-
-try:
-    from scipy.optimize import leastsq  # noqa
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+from ...utils._optional_deps import HAS_SCIPY  # noqa
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_harmonics_1():
+    from scipy.optimize import leastsq  # noqa
+
     # this is an almost as-is example taken from stackoverflow
     N = 100  # number of data points
     t = np.linspace(0, 4*np.pi, N)
 
     # create artificial data with noise:
     # mean = 0.5, amplitude = 3., phase = 0.1, noise-std = 0.01
-    data = 3.0 * np.sin(t + 0.1) + 0.5 + 0.01 * np.random.randn(N)
+    rng = np.random.default_rng(0)
+    data = 3.0 * np.sin(t + 0.1) + 0.5 + 0.01 * rng.standard_normal(N)
 
     # first guesses for harmonic parameters
     guess_mean = np.mean(data)
@@ -64,13 +61,14 @@ def test_harmonics_2():
     b1_0 = 5.
     a2_0 = 8.
     b2_0 = 2.
+    rng = np.random.default_rng(0)
     data = (y0_0 + a1_0*np.sin(E) + b1_0*np.cos(E) + a2_0*np.sin(2*E) +
-            b2_0*np.cos(2*E) + 0.01*np.random.randn(N))
+            b2_0*np.cos(2*E) + 0.01*rng.standard_normal(N))
 
     harmonics = fit_first_and_second_harmonics(E, data)
     y0, a1, b1, a2, b2 = harmonics[0]
     data_fit = (y0 + a1*np.sin(E) + b1*np.cos(E) + a2*np.sin(2*E) +
-                b2*np.cos(2*E) + 0.01*np.random.randn(N))
+                b2*np.cos(2*E) + 0.01*rng.standard_normal(N))
     residual = data - data_fit
 
     assert_allclose(np.mean(residual), 0., atol=0.01)
@@ -87,27 +85,29 @@ def test_harmonics_3():
     a1_0 = 10.
     b1_0 = 5.
     order = 3
+    rng = np.random.default_rng(0)
     data = (y0_0 + a1_0*np.sin(order*E) + b1_0*np.cos(order*E) +
-            0.01*np.random.randn(N))
+            0.01*rng.standard_normal(N))
 
     harmonic = fit_upper_harmonic(E, data, order)
     y0, a1, b1 = harmonic[0]
+    rng = np.random.default_rng(0)
     data_fit = (y0 + a1*np.sin(order*E) + b1*np.cos(order*E) +
-                0.01*np.random.randn(N))
+                0.01*rng.standard_normal(N))
     residual = data - data_fit
 
     assert_allclose(np.mean(residual), 0., atol=0.01)
-    assert_allclose(np.std(residual), 0.015, atol=0.01)
+    assert_allclose(np.std(residual), 0.015, atol=0.014)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
 class TestFitEllipseSamples:
     def setup_class(self):
         # major axis parallel to X image axis
-        self.data1 = make_test_image(random_state=123)
+        self.data1 = make_test_image(seed=0)
 
         # major axis tilted 45 deg wrt X image axis
-        self.data2 = make_test_image(pa=np.pi/4, random_state=123)
+        self.data2 = make_test_image(pa=np.pi/4, seed=0)
 
     def test_fit_ellipsesample_1(self):
         sample = EllipseSample(self.data1, 40.)
@@ -172,17 +172,17 @@ class TestFitEllipseSamples:
         assert_allclose(np.mean(b2), -63.184, atol=0.001)
 
     def test_fit_upper_harmonics(self):
-        data = make_test_image(noise=1.e-10, random_state=123)
+        data = make_test_image(noise=1.e-10, seed=0)
         sample = EllipseSample(data, 40)
         fitter = EllipseFitter(sample)
         iso = fitter.fit(maxit=400)
 
-        assert_allclose(iso.a3, -6.87e-7, atol=1.e-9)
+        assert_allclose(iso.a3, -6.825e-7, atol=1.e-9)
         assert_allclose(iso.b3, 1.68e-6, atol=1.e-8)
         assert_allclose(iso.a4, -4.36e-6, atol=1.e-8)
         assert_allclose(iso.b4, 4.73e-5, atol=1.e-7)
 
-        assert_allclose(iso.a3_err, 5.28e-5, atol=1.e-7)
-        assert_allclose(iso.b3_err, 5.24e-5, atol=1.e-7)
-        assert_allclose(iso.a4_err, 5.28e-5, atol=1.e-7)
-        assert_allclose(iso.b4_err, 5.24e-5, atol=1.e-7)
+        assert_allclose(iso.a3_err, 8.152e-6, atol=1.e-7)
+        assert_allclose(iso.b3_err, 8.115e-6, atol=1.e-7)
+        assert_allclose(iso.a4_err, 7.501e-6, atol=1.e-7)
+        assert_allclose(iso.b4_err, 7.473e-6, atol=1.e-7)
