@@ -19,13 +19,9 @@ import numpy as np
 from .epsf_stars import EPSFStar, EPSFStars, LinkedEPSFStar
 from .models import EPSFModel
 from ..centroids import centroid_com, centroid_epsf
+from ..utils._optional_deps import HAS_BOTTLENECK  # noqa
 from ..utils._round import _py2intround
 
-try:
-    import bottleneck  # pylint: disable=W0611
-    HAS_BOTTLENECK = True
-except ImportError:
-    HAS_BOTTLENECK = False
 
 __all__ = ['EPSFFitter', 'EPSFBuilder']
 
@@ -68,8 +64,7 @@ class EPSFFitter:
 
             min_size = 3
             if any([size < min_size for size in fit_boxsize]):
-                raise ValueError('size must be >= {} for x and y'
-                                 .format(min_size))
+                raise ValueError(f'size must be >= {min_size} for x and y')
 
         self.fit_boxsize = fit_boxsize
 
@@ -103,7 +98,6 @@ class EPSFFitter:
             are stored in the ``center`` (and ``cutout_center``) and
             ``flux`` attributes.
         """
-
         if len(stars) == 0:
             return stars
 
@@ -151,7 +145,6 @@ class EPSFFitter:
         routine in this function.  Make a copy before calling this
         function if the original is needed.
         """
-
         if fit_boxsize is not None:
             try:
                 xcenter, ycenter = star.cutout_center
@@ -159,11 +152,10 @@ class EPSFFitter:
                                               (ycenter, xcenter),
                                               mode='strict')
             except (PartialOverlapError, NoOverlapError):
-                warnings.warn('The star at ({0}, {1}) cannot be fit because '
+                warnings.warn('The star at ({star.center[0]}, '
+                              '{star.center[1]}) cannot be fit because '
                               'its fitting region extends beyond the star '
-                              'cutout image.'.format(star.center[0],
-                                                     star.center[1]),
-                              AstropyUserWarning)
+                              'cutout image.', AstropyUserWarning)
 
                 star = copy.deepcopy(star)
                 star._fit_error_status = 1
@@ -313,6 +305,13 @@ class EPSFBuilder:
         are ignored based on the star sampling flux residuals, when
         computing the average residual of ePSF grid points in each iteration
         step.
+
+    Notes
+    -----
+    If your image image contains NaN values, you may see better
+    performance if you have the `bottleneck`_ package installed.
+
+    .. _bottleneck:  https://github.com/pydata/bottleneck
     """
 
     def __init__(self, oversampling=4., shape=None,
@@ -376,7 +375,6 @@ class EPSFBuilder:
         Initialize 2D image-type parameters that can accept either a
         single or two values.
         """
-
         if param is not None:
             param = np.atleast_1d(param)
             if len(param) == 1:
@@ -406,7 +404,6 @@ class EPSFBuilder:
         epsf : `EPSFModel`
             The initial ePSF model.
         """
-
         norm_radius = self._norm_radius
         shift_val = self._shift_val
         oversampling = self.oversampling
@@ -472,7 +469,6 @@ class EPSFBuilder:
             A 2D image containing the resampled residual image.  The
             image contains NaNs where there is no data.
         """
-
         # Compute the normalized residual by subtracting the ePSF model
         # from the normalized star at the location of the star in the
         # undersampled grid.
@@ -523,7 +519,6 @@ class EPSFBuilder:
         epsf_resid : 3D `~numpy.ndarray`
             A 3D cube containing the resampled residual images.
         """
-
         shape = (stars.n_good_stars, epsf.shape[0], epsf.shape[1])
         epsf_resid = np.zeros(shape)
         for i, star in enumerate(stars.all_good_stars):
@@ -545,12 +540,15 @@ class EPSFBuilder:
         result : 2D `~numpy.ndarray`
             The smoothed (convolved) ePSF data.
         """
-
         from scipy.ndimage import convolve
 
         if self.smoothing_kernel is None:
             return epsf_data
 
+        # do this check first as comparing a ndarray to string causes a warning
+        elif isinstance(self.smoothing_kernel, np.ndarray):
+            kernel = self.smoothing_kernel
+
         elif self.smoothing_kernel == 'quartic':
             # from Polynomial2D fit with degree=4 to 5x5 array of
             # zeros with 1. at the center
@@ -585,9 +583,6 @@ class EPSFBuilder:
                  [-0.07428311, 0.01142786, 0.03999952, 0.01142786,
                   -0.07428311]])
 
-        elif isinstance(self.smoothing_kernel, np.ndarray):
-            kernel = self.smoothing_kernel
-
         else:
             raise TypeError('Unsupported kernel.')
 
@@ -611,14 +606,17 @@ class EPSFBuilder:
             and optionally an ``error`` keyword. The callable object
             must return a tuple of two 1D `~numpy.ndarray` variables,
             representing the x and y centroids.
+
         box_size : float or tuple of two floats, optional
             The size (in pixels) of the box used to calculate the
             centroid of the ePSF during each build iteration.  If a
             single integer number is provided, then a square box will be
             used.  If two values are provided, then they should be in
             ``(ny, nx)`` order.
+
         maxiters : int, optional
             The maximum number of recentering iterations to perform.
+
         center_accuracy : float, optional
             The desired accuracy for the centers of stars.  The building
             iterations will stop if the center of the ePSF changes by
@@ -629,7 +627,6 @@ class EPSFBuilder:
         result : 2D `~numpy.ndarray`
             The recentered ePSF data.
         """
-
         epsf_data = epsf._data
 
         epsf = EPSFModel(data=epsf._data, origin=epsf.origin,
@@ -726,7 +723,6 @@ class EPSFBuilder:
         epsf : `EPSFModel` object
             The updated ePSF.
         """
-
         if len(stars) < 1:
             raise ValueError('stars must contain at least one EPSFStar or '
                              'LinkedEPSFStar object.')
@@ -749,6 +745,7 @@ class EPSFBuilder:
                                                    masked=False,
                                                    return_bounds=False)
             if HAS_BOTTLENECK:
+                import bottleneck
                 residuals = bottleneck.nanmedian(residuals, axis=0)
             else:
                 residuals = np.nanmedian(residuals, axis=0)
@@ -790,7 +787,7 @@ class EPSFBuilder:
 
     def build_epsf(self, stars, init_epsf=None):
         """
-        Iteratively build an ePSF from star cutouts.
+        Build iteratively an ePSF from star cutouts.
 
         Parameters
         ----------
@@ -810,7 +807,6 @@ class EPSFBuilder:
             The input stars with updated centers and fluxes derived
             from fitting the output ``epsf``.
         """
-
         iter_num = 0
         n_stars = stars.n_stars
         fit_failed = np.zeros(n_stars, dtype=bool)
@@ -829,10 +825,9 @@ class EPSFBuilder:
                 if iter_num == 1:
                     dt_str = ' [? s/iter]'
                 else:
-                    dt_str = ' [{:.1f} s/iter]'.format(dt)
-
-                print('PROGRESS: iteration {0:d} (of max {1}){2}'
-                      .format(iter_num, self.maxiters, dt_str), end='\r')
+                    dt_str = f' [{dt:.1f} s/iter]'
+                print(f'PROGRESS: iteration {iter_num:d} (of max '
+                      f'{self.maxiters}){dt_str}', end='\r')
 
             # build/improve the ePSF
             epsf = self._build_epsf_step(stars, epsf=epsf)
@@ -883,7 +878,7 @@ def _interpolate_missing_data(data, mask, method='cubic'):
         An array containing the 2D image.
 
     mask : 2D bool `~numpy.ndarray`
-        A 2D booleen mask array with the same shape as the input
+        A 2D boolean mask array with the same shape as the input
         ``data``, where a `True` value indicates the corresponding
         element of ``data`` is masked.  The masked data points are
         those that will be interpolated.
@@ -902,7 +897,6 @@ def _interpolate_missing_data(data, mask, method='cubic'):
     data_interp : 2D `~numpy.ndarray`
         The interpolated 2D image.
     """
-
     from scipy import interpolate
 
     data_interp = np.array(data, copy=True)
