@@ -98,13 +98,11 @@ class EPSFStar:
         Array representation of the mask data array (e.g., for
         matplotlib).
         """
-
         return self._data
 
     @property
     def data(self):
         """The 2D cutout image."""
-
         return self._data
 
     @property
@@ -113,7 +111,6 @@ class EPSFStar:
         A `~numpy.ndarray` of the ``(x, y)`` position of the star's
         center with respect to the input cutout ``data`` array.
         """
-
         return self._cutout_center
 
     @cutout_center.setter
@@ -133,7 +130,6 @@ class EPSFStar:
         A `~numpy.ndarray` of the ``(x, y)`` position of the star's
         center in the original (large) image (not the cutout image).
         """
-
         return self.cutout_center + self.origin
 
     @lazyproperty
@@ -142,7 +138,6 @@ class EPSFStar:
         A tuple of two slices representing the cutout region with
         respect to the original (large) image.
         """
-
         return (slice(self.origin[1], self.origin[1] + self.shape[1]),
                 slice(self.origin[0], self.origin[0] + self.shape[0]))
 
@@ -152,7 +147,6 @@ class EPSFStar:
         The minimal `~photutils.aperture.BoundingBox` for the cutout
         region with respect to the original (large) image.
         """
-
         return BoundingBox(self.slices[1].start, self.slices[1].stop,
                            self.slices[0].start, self.slices[0].stop)
 
@@ -164,7 +158,6 @@ class EPSFStar:
         Missing data is filled in by interpolation to better estimate
         the total flux.
         """
-
         from .epsf import _interpolate_missing_data
 
         if np.any(self.mask):
@@ -194,7 +187,6 @@ class EPSFStar:
         data : `~numpy.ndarray`
             A 2D array of the registered/scaled ePSF.
         """
-
         yy, xx = np.indices(self.shape, dtype=float)
         xx = xx - self.cutout_center[0]
         yy = yy - self.cutout_center[1]
@@ -216,7 +208,6 @@ class EPSFStar:
         data : `~numpy.ndarray`
             A 2D array of the residual image.
         """
-
         return self.data - self.register_epsf(epsf)
 
     @lazyproperty
@@ -225,7 +216,6 @@ class EPSFStar:
         1D arrays of x and y indices of unmasked pixels in the cutout
         reference frame.
         """
-
         yidx, xidx = np.indices(self._data.shape)
         return xidx[~self.mask].ravel(), yidx[~self.mask].ravel()
 
@@ -235,7 +225,6 @@ class EPSFStar:
         1D arrays of x indices of unmasked pixels in the cutout
         reference frame.
         """
-
         return self._xy_idx[0]
 
     @lazyproperty
@@ -244,7 +233,6 @@ class EPSFStar:
         1D arrays of y indices of unmasked pixels in the cutout
         reference frame.
         """
-
         return self._xy_idx[1]
 
     @property
@@ -253,7 +241,6 @@ class EPSFStar:
         1D array of x indices of unmasked pixels, with respect to the
         star center, in the cutout reference frame.
         """
-
         return self._xy_idx[0] - self.cutout_center[0]
 
     @property
@@ -262,13 +249,11 @@ class EPSFStar:
         1D array of y indices of unmasked pixels, with respect to the
         star center, in the cutout reference frame.
         """
-
         return self._xy_idx[1] - self.cutout_center[1]
 
     @lazyproperty
     def _data_values(self):
         """1D array of unmasked cutout data values."""
-
         return self.data[~self.mask].ravel()
 
     @lazyproperty
@@ -277,7 +262,6 @@ class EPSFStar:
         1D array of unmasked cutout data values, normalized by the
         star's total flux.
         """
-
         return self._data_values / self.flux
 
     @lazyproperty
@@ -285,7 +269,6 @@ class EPSFStar:
         """
         1D array of unmasked weight values.
         """
-
         return self.weights[~self.mask].ravel()
 
 
@@ -312,7 +295,7 @@ class EPSFStars:
         return len(self._data)
 
     def __getitem__(self, index):
-        return self._data[index]
+        return self.__class__(self._data[index])
 
     def __delitem__(self, index):
         del self._data[index]
@@ -321,12 +304,23 @@ class EPSFStars:
         for i in self._data:
             yield i
 
+    # explicit set/getstate to avoid infinite recursion
+    # from pickler using __getattr__
+    def __getstate__(self):
+        return self.__dict__
+
+    def __setstate__(self, d):
+        self.__dict__ = d
+
     def __getattr__(self, attr):
         if attr in ['cutout_center', 'center', 'flux',
                     '_excluded_from_fit']:
-            return np.array([getattr(star, attr) for star in self._data])
+            result = np.array([getattr(star, attr) for star in self._data])
         else:
-            return [getattr(star, attr) for star in self._data]
+            result = [getattr(star, attr) for star in self._data]
+        if len(self._data) == 1:
+            result = result[0]
+        return result
 
     def _getattr_flat(self, attr):
         values = []
@@ -349,7 +343,6 @@ class EPSFStars:
         Note that when `EPSFStars` contains any `LinkedEPSFStar`, the
         ``cutout_center`` attribute will be a nested 3D array.
         """
-
         return self._getattr_flat('cutout_center')
 
     @property
@@ -363,7 +356,6 @@ class EPSFStars:
         Note that when `EPSFStars` contains any `LinkedEPSFStar`, the
         ``center`` attribute will be a nested 3D array.
         """
-
         return self._getattr_flat('center')
 
     @lazyproperty
@@ -373,7 +365,6 @@ class EPSFStars:
         including those that comprise linked stars (i.e.,
         `LinkedEPSFStar`), as a flat list.
         """
-
         stars = []
         for item in self._data:
             if isinstance(item, LinkedEPSFStar):
@@ -390,7 +381,6 @@ class EPSFStars:
         not been excluded from fitting, including those that comprise
         linked stars (i.e., `LinkedEPSFStar`), as a flat list.
         """
-
         stars = []
         for star in self.all_stars:
             if star._excluded_from_fit:
@@ -407,7 +397,6 @@ class EPSFStars:
 
         A linked star is counted only once.
         """
-
         return len(self._data)
 
     @lazyproperty
@@ -417,7 +406,6 @@ class EPSFStars:
         stars within `LinkedEPSFStar`.  Each linked star is included in
         the count.
         """
-
         return len(self.all_stars)
 
     @property
@@ -428,16 +416,14 @@ class EPSFStars:
         fitting.  Each non-excluded linked star is included in the
         count.
         """
-
         return len(self.all_good_stars)
 
     @lazyproperty
     def _max_shape(self):
         """
-        The maximum x and y shapes of all the `EPSFStar`\\s (including
-        linked stars).
+        The maximum x and y shapes of all the `EPSFStar` objects
+        (including linked stars).
         """
-
         return np.max([star.shape for star in self.all_stars],
                       axis=0)
 
@@ -480,7 +466,6 @@ class LinkedEPSFStar(EPSFStars):
         The single sky coordinate is calculated as the mean of sky
         coordinates of the linked stars.
         """
-
         if len(self._data) < 2:  # no linked stars
             return
 
@@ -598,7 +583,6 @@ def extract_stars(data, catalogs, size=(11, 11)):
     stars : `EPSFStars` instance
         A `EPSFStars` instance containing the extracted stars.
     """
-
     if isinstance(data, NDData):
         data = [data]
 
@@ -654,7 +638,7 @@ def extract_stars(data, catalogs, size=(11, 11)):
 
     min_size = 3
     if size[0] < min_size or size[1] < min_size:
-        raise ValueError('size must be >= {} for x and y'.format(min_size))
+        raise ValueError(f'size must be >= {min_size} for x and y')
 
     if len(catalogs) == 1:  # may included linked stars
         use_xy = True
@@ -718,7 +702,7 @@ def _extract_stars(data, catalog, size=(11, 11), use_xy=True):
         the stars then the `~astropy.nddata.NDData` object must have a
         valid ``wcs`` attribute.
 
-    catalogs : `~astropy.table.Table`
+    catalog : `~astropy.table.Table`
         A single catalog of sources to be extracted from the input
         ``data``.  The center of each source can be defined either in
         pixel coordinates (in ``x`` and ``y`` columns) or sky
@@ -746,7 +730,6 @@ def _extract_stars(data, catalog, size=(11, 11), use_xy=True):
     stars : list of `EPSFStar` objects
         A list of `EPSFStar` instances containing the extracted stars.
     """
-
     # Force size to odd numbers such that there is always a central pixel with
     # even spacing either side of the pixel.
     if np.isscalar(size):
