@@ -35,7 +35,6 @@ class GroupStarsBase(metaclass=abc.ABCMeta):
             whose unique values represent groups of mutually overlapping
             stars.
         """
-
         return self.group_stars(starlist)
 
     @abc.abstractmethod
@@ -57,7 +56,6 @@ class GroupStarsBase(metaclass=abc.ABCMeta):
             whose unique values represent groups of mutually overlapping
             stars.
         """
-
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
 
@@ -104,12 +102,12 @@ class DAOGroup(GroupStarsBase):
     @crit_separation.setter
     def crit_separation(self, crit_separation):
         if not isinstance(crit_separation, (float, int)):
-            raise ValueError('crit_separation is expected to be either '
-                             'float or int. Received {}.'
-                             .format(type(crit_separation)))
+            raise ValueError('crit_separation is expected to be either float'
+                             f'or int. Received {type(crit_separation)}.')
+
         elif crit_separation < 0.0:
             raise ValueError('crit_separation is expected to be a positive '
-                             'real number. Got {}'.format(crit_separation))
+                             f'real number. Got {crit_separation}.')
         else:
             self._crit_separation = crit_separation
 
@@ -124,9 +122,8 @@ class DAOGroup(GroupStarsBase):
                                                   dtype=int)))
 
         if not np.array_equal(cstarlist['id'], np.arange(len(cstarlist)) + 1):
-            raise ValueError('id colum must be an integer-valued ' +
-                             'sequence starting from 1. ' +
-                             'Got {}'.format(cstarlist['id']))
+            raise ValueError('id column must be an integer-valued sequence '
+                             f'starting from 1. Got {cstarlist["id"]}')
 
         n = 1
         while (cstarlist['group_id'] == 0).sum() > 0:
@@ -159,6 +156,7 @@ class DAOGroup(GroupStarsBase):
         star : `~astropy.table.Row`
             Star which will be either the head of a cluster or an
             isolated one.
+
         starlist : `~astropy.table.Table`
             List of star positions. Columns named as ``x_0`` and
             ``y_0``, which corresponds to the centroid coordinates of
@@ -166,10 +164,10 @@ class DAOGroup(GroupStarsBase):
 
         Returns
         -------
-        Array containing the ids of those stars which are at a distance less
-        than ``crit_separation`` from ``star``.
+        result : `~numpy.ndarray`
+            Array containing the ids of those stars which are at a
+            distance less than ``crit_separation`` from ``star``.
         """
-
         star_distance = np.hypot(star['x_0'] - starlist['x_0'],
                                  star['y_0'] - starlist['y_0'])
         distance_criteria = star_distance < self.crit_separation
@@ -234,9 +232,8 @@ class DBSCANGroup(GroupStarsBase):
                                         data=np.arange(len(cstarlist)) + 1))
 
         if not np.array_equal(cstarlist['id'], np.arange(len(cstarlist)) + 1):
-            raise ValueError('id colum must be an integer-valued ' +
-                             'sequence starting from 1. ' +
-                             'Got {}'.format(cstarlist['id']))
+            raise ValueError('id column must be an integer-valued sequence '
+                             'starting from 1. Got {cstarlist["id"]}')
 
         pos_stars = np.transpose((cstarlist['x_0'], cstarlist['y_0']))
         dbscan = DBSCAN(eps=self.crit_separation,
