@@ -11,12 +11,7 @@ import pytest
 
 from ..fourier import create_matching_kernel, resize_psf
 from ..windows import SplitCosineBellWindow
-
-try:
-    import scipy  # noqa
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+from ....utils._optional_deps import HAS_SCIPY  # noqa
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
