@@ -1,11 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
-Window (or tapering) functions for matching PSFs using Fourier methods.
+This module provides window (or tapering) functions for matching PSFs
+using Fourier methods.
 """
 
 import numpy as np
 
-
 __all__ = ['SplitCosineBellWindow', 'HanningWindow', 'TukeyWindow',
            'CosineBellWindow', 'TopHatWindow']
 
@@ -23,10 +23,9 @@ def _radial_distance(shape):
     Returns
     -------
     result : `~numpy.ndarray`
-        An array containing the Euclidian radial distances from the
+        An array containing the Euclidean radial distances from the
         array center.
     """
-
     if len(shape) != 2:
         raise ValueError('shape must have only 2 elements')
     position = (np.asarray(shape) - 1) / 2.
@@ -55,7 +54,7 @@ class SplitCosineBellWindow:
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import SplitCosineBellWindow
+        from photutils.psf import SplitCosineBellWindow
         taper = SplitCosineBellWindow(alpha=0.4, beta=0.3)
         data = taper((101, 101))
         plt.imshow(data, cmap='viridis', origin='lower')
@@ -67,7 +66,7 @@ class SplitCosineBellWindow:
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import SplitCosineBellWindow
+        from photutils.psf import SplitCosineBellWindow
         taper = SplitCosineBellWindow(alpha=0.4, beta=0.3)
         data = taper((101, 101))
         plt.plot(data[50, :])
@@ -91,7 +90,6 @@ class SplitCosineBellWindow:
         result : `~numpy.ndarray`
             A 2D array containing the cosine bell values.
         """
-
         radial_dist = _radial_distance(shape)
         npts = (np.array(shape).min() - 1.) / 2.
         r_inner = self.beta * npts
@@ -124,7 +122,7 @@ class HanningWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import HanningWindow
+        from photutils.psf import HanningWindow
         taper = HanningWindow()
         data = taper((101, 101))
         plt.imshow(data, cmap='viridis', origin='lower')
@@ -136,15 +134,14 @@ class HanningWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import HanningWindow
+        from photutils.psf import HanningWindow
         taper = HanningWindow()
         data = taper((101, 101))
         plt.plot(data[50, :])
     """
 
     def __init__(self):
-        self.alpha = 1.0
-        self.beta = 0.0
+        super().__init__(alpha=1.0, beta=0.0)
 
 
 class TukeyWindow(SplitCosineBellWindow):
@@ -167,7 +164,7 @@ class TukeyWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import TukeyWindow
+        from photutils.psf import TukeyWindow
         taper = TukeyWindow(alpha=0.4)
         data = taper((101, 101))
         plt.imshow(data, cmap='viridis', origin='lower')
@@ -179,7 +176,7 @@ class TukeyWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import TukeyWindow
+        from photutils.psf import TukeyWindow
         taper = TukeyWindow(alpha=0.4)
         data = taper((101, 101))
         plt.plot(data[50, :])
@@ -187,8 +184,7 @@ class TukeyWindow(SplitCosineBellWindow):
     """
 
     def __init__(self, alpha):
-        self.alpha = alpha
-        self.beta = 1. - self.alpha
+        super().__init__(alpha=alpha, beta=1.0 - alpha)
 
 
 class CosineBellWindow(SplitCosineBellWindow):
@@ -206,7 +202,7 @@ class CosineBellWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import CosineBellWindow
+        from photutils.psf import CosineBellWindow
         taper = CosineBellWindow(alpha=0.3)
         data = taper((101, 101))
         plt.imshow(data, cmap='viridis', origin='lower')
@@ -218,15 +214,14 @@ class CosineBellWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import CosineBellWindow
+        from photutils.psf import CosineBellWindow
         taper = CosineBellWindow(alpha=0.3)
         data = taper((101, 101))
         plt.plot(data[50, :])
     """
 
     def __init__(self, alpha):
-        self.alpha = alpha
-        self.beta = 0.0
+        super().__init__(alpha=alpha, beta=0.0)
 
 
 class TopHatWindow(SplitCosineBellWindow):
@@ -245,7 +240,7 @@ class TopHatWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import TopHatWindow
+        from photutils.psf import TopHatWindow
         taper = TopHatWindow(beta=0.4)
         data = taper((101, 101))
         plt.imshow(data, cmap='viridis', origin='lower',
@@ -258,12 +253,11 @@ class TopHatWindow(SplitCosineBellWindow):
         :include-source:
 
         import matplotlib.pyplot as plt
-        from photutils import TopHatWindow
+        from photutils.psf import TopHatWindow
         taper = TopHatWindow(beta=0.4)
         data = taper((101, 101))
         plt.plot(data[50, :])
     """
 
     def __init__(self, beta):
-        self.alpha = 0.0
-        self.beta = beta
+        super().__init__(alpha=0.0, beta=beta)
