@@ -12,6 +12,8 @@ from astropy.nddata import NDData
 from astropy.utils.exceptions import AstropyWarning
 import numpy as np
 
+from ..aperture import CircularAperture
+
 __all__ = ['NonNormalizable', 'FittableImageModel', 'EPSFModel',
            'GriddedPSFModel', 'IntegratedGaussianPRF', 'PRFAdapter']
 
@@ -24,7 +26,7 @@ class NonNormalizable(AstropyWarning):
 
 
 class FittableImageModel(Fittable2DModel):
-    """
+    r"""
     A fittable 2D model of an image allowing for image intensity scaling
     and image translations.
 
@@ -70,7 +72,7 @@ class FittableImageModel(Fittable2DModel):
         is computed so that
 
         .. math::
-            N \\cdot C \\cdot \\sum\\limits_{i,j} D_{i,j} = 1,
+            N \cdot C \cdot \sum\limits_{i,j} D_{i,j} = 1,
 
         where *N* is the normalization constant, *C* is correction
         factor given by the parameter ``normalization_correction``, and
@@ -106,7 +108,7 @@ class FittableImageModel(Fittable2DModel):
         the `compute_interpolator` method.  See `compute_interpolator`
         for more details.
 
-    oversampling : float or tuple of two floats, optional
+    oversampling : int or tuple of two int, optional
         The oversampling factor(s) of the model in the ``x`` and ``y``
         directions.  If ``oversampling`` is a scalar it will be treated
         as being the same in both x and y; otherwise a tuple of two
@@ -138,7 +140,7 @@ class FittableImageModel(Fittable2DModel):
                              "positive.")
         self._normalization_correction = normalization_correction
 
-        self._data = np.array(data, copy=True, dtype=np.float64)
+        self._data = np.array(data, copy=True, dtype=float)
 
         if not np.all(np.isfinite(self._data)):
             raise ValueError("All elements of input 'data' must be finite.")
@@ -177,38 +179,36 @@ class FittableImageModel(Fittable2DModel):
         computed as the *sum of all pixel values*.
 
         .. note::
-            This function is intended to be overriden in a subclass if
+            This function is intended to be overridden in a subclass if
             one desires to change the way the normalization factor is
             computed.
-
         """
-        return np.sum(self._data, dtype=np.float64)
+        return np.sum(self._data, dtype=float)
 
     def _compute_normalization(self, normalize):
-        """
+        r"""
         Helper function that computes (corrected) normalization factor
         of the original image data. This quantity is computed as the
         inverse "raw image norm" (or total "flux" of model's image)
         corrected by the ``normalization_correction``:
 
         .. math::
-            N = 1/(\\Phi * C),
+            N = 1/(\Phi * C),
 
-        where :math:`\\Phi` is the "total flux" of model's image as
+        where :math:`\Phi` is the "total flux" of model's image as
         computed by `_compute_raw_image_norm` and *C* is the
-        normalization correction factor. :math:`\\Phi` is computed only
+        normalization correction factor. :math:`\Phi` is computed only
         once if it has not been previously computed. Otherwise, the
-        existing (stored) value of :math:`\\Phi` is not modified as
+        existing (stored) value of :math:`\Phi` is not modified as
         :py:class:`FittableImageModel` does not allow image data to be
         modified after the object is created.
 
         .. note::
             Normally, this function should not be called by the
-            end-user. It is intended to be overriden in a subclass if
+            end-user. It is intended to be overridden in a subclass if
             one desires to change the way the normalization factor is
             computed.
         """
-
         self._normalization_constant = 1.0 / self._normalization_correction
 
         if normalize:
@@ -234,34 +234,39 @@ class FittableImageModel(Fittable2DModel):
     @property
     def oversampling(self):
         """
-        The factor by which the stored image is oversampled.  I.e., an
-        input to this model is multipled by this factor to yield the
+        The factor by which the stored image is oversampled.
+
+        An input to this model is multiplied by this factor to yield the
         index into the stored image.
         """
-
         return self._oversampling
 
     def _set_oversampling(self, value):
-        """
-        This is a private method because it's used in the initializer by
-        the ``oversampling``
-        """
+        value = np.atleast_1d(value)
 
-        try:
-            value = np.atleast_1d(value).astype(float)
-            if len(value) == 1:
-                value = np.repeat(value, 2)
-        except ValueError:
-            raise ValueError('Oversampling factors must be float')
+        if np.any(~np.isfinite(value)):
+            raise ValueError('Oversampling factor must be a finite value')
 
         if np.any(value <= 0):
-            raise ValueError('Oversampling factors must be greater than 0')
+            raise ValueError('Oversampling factor must be greater than 0')
+
+        if len(value) == 1:
+            value = np.repeat(value, 2)
+        if len(value) != 2:
+            raise ValueError('Oversampling factor must have 1 or 2 '
+                             'elements')
+        if value.ndim != 1:
+            raise ValueError('Oversampling factor must be 1D')
+
+        value_int = value.astype(int)
+        if np.any(value_int != value):  # e.g., 2.0 is OK, 2.1 is not
+            raise ValueError('Oversampling elements must be integers')
 
         self._oversampling = value
 
     @property
     def data(self):
-        """ Get original image data. """
+        """Get original image data."""
         return self._data
 
     @property
@@ -271,7 +276,7 @@ class FittableImageModel(Fittable2DModel):
 
     @property
     def normalization_constant(self):
-        """ Get normalization constant. """
+        """Get normalization constant."""
         return self._normalization_constant
 
     @property
@@ -279,12 +284,11 @@ class FittableImageModel(Fittable2DModel):
         """
         Get normalization status. Possible status values are:
 
-        - 0: **Performed**. Model has been successfuly normalized at
+        - 0: **Performed**. Model has been successfully normalized at
              user's request.
         - 1: **Failed**. Attempt to normalize has failed.
         - 2: **NotRequested**. User did not request model to be normalized.
         """
-
         return self._normalization_status
 
     @property
@@ -298,7 +302,6 @@ class FittableImageModel(Fittable2DModel):
             to some target image before, then it will remain a good fit
             after correction factor change.
         """
-
         return self._normalization_correction
 
     @normalization_correction.setter
@@ -317,7 +320,6 @@ class FittableImageModel(Fittable2DModel):
         """
         A tuple of dimensions of the data array in numpy style (ny, nx).
         """
-
         return self._shape
 
     @property
@@ -345,7 +347,6 @@ class FittableImageModel(Fittable2DModel):
             Modifying ``origin`` will not adjust (modify) model's
             parameters ``x_0`` and ``y_0``.
         """
-
         return (self._x_origin, self._y_origin)
 
     @origin.setter
@@ -377,7 +378,6 @@ class FittableImageModel(Fittable2DModel):
         then values outside of the domain of definition are the ones
         returned by the interpolator.
         """
-
         return self._fill_value
 
     @fill_value.setter
@@ -389,7 +389,6 @@ class FittableImageModel(Fittable2DModel):
         This function should be called in a subclass whenever model's
         interpolator is (re-)computed.
         """
-
         self._interpolator_kwargs = copy.deepcopy(kwargs)
 
     @property
@@ -398,19 +397,18 @@ class FittableImageModel(Fittable2DModel):
         Get current interpolator's arguments used when interpolator was
         created.
         """
-
         return self._interpolator_kwargs
 
     def compute_interpolator(self, **kwargs):
         """
         Compute/define the interpolating spline.
 
-        This function can be overriden in a subclass to define custom
+        This function can be overridden in a subclass to define custom
         interpolators.
 
         Parameters
         ----------
-        kwargs : dict, optional
+        **kwargs : dict, optional
             Additional optional keyword arguments:
 
             - **degree** : int, tuple, optional
@@ -428,8 +426,8 @@ class FittableImageModel(Fittable2DModel):
         -----
         * When subclassing :py:class:`FittableImageModel` for the
           purpose of overriding :py:func:`compute_interpolator`, the
-          :py:func:`evaluate` may need to overriden as well depending on
-          the behavior of the new interpolator. In addition, for
+          :py:func:`evaluate` may need to overridden as well depending
+          on the behavior of the new interpolator. In addition, for
           improved future compatibility, make sure that the overriding
           method stores keyword arguments ``kwargs`` by calling
           ``_store_interpolator_kwargs`` method.
@@ -439,7 +437,6 @@ class FittableImageModel(Fittable2DModel):
           decrease code performance due to the need to recompute
           interpolator.
         """
-
         from scipy.interpolate import RectBivariateSpline
 
         if 'degree' in kwargs:
@@ -459,8 +456,8 @@ class FittableImageModel(Fittable2DModel):
 
         smoothness = kwargs.get('s', 0)
 
-        x = np.arange(self._nx, dtype=np.float)
-        y = np.arange(self._ny, dtype=np.float)
+        x = np.arange(self._nx, dtype=float)
+        y = np.arange(self._ny, dtype=float)
         self.interpolator = RectBivariateSpline(
             x, y, self._data.T, kx=degx, ky=degy, s=smoothness
         )
@@ -476,10 +473,9 @@ class FittableImageModel(Fittable2DModel):
         ----------
         use_oversampling : bool, optional
             Whether to use the oversampling factor to calculate the
-            model pixel indices.  The default is `True`, which means the
-            input indices will be multipled by this factor.
+            model pixel indices. The default is `True`, which means the
+            input indices will be multiplied by this factor.
         """
-
         if use_oversampling:
             xi = self._oversampling[0] * (np.asarray(x) - x_0)
             yi = self._oversampling[1] * (np.asarray(y) - y_0)
@@ -487,6 +483,8 @@ class FittableImageModel(Fittable2DModel):
             xi = np.asarray(x) - x_0
             yi = np.asarray(y) - y_0
 
+        xi = xi.astype(float)
+        yi = yi.astype(float)
         xi += self._x_origin
         yi += self._y_origin
 
@@ -507,6 +505,12 @@ class EPSFModel(FittableImageModel):
     """
     A class that models an effective PSF (ePSF).
 
+    The EPSFModel is normalized such that the sum of the PSF over the
+    (undersampled) pixels within the the input ``norm_radius`` is 1.0.
+    This means that when the EPSF is fit to stars, the resulting flux
+    corresponds to aperture photometry within a circular aperture of
+    radius ``norm_radius``.
+
     While this class is a subclass of `FittableImageModel`, it is very
     similar.  The primary differences/motivation are a few additional
     parameters necessary specifically for ePSFs.
@@ -557,41 +561,16 @@ class EPSFModel(FittableImageModel):
 
     def _compute_raw_image_norm(self):
         """
-        Helper function that computes the normalization of input image
-        data.  This quantity is computed as the sum of all undersampled
-        integer pixel values within radius pixels of the center of the
-        ePSF.
+        Compute the normalization of input image data as the flux
+        within a given radius.
         """
-
-        # First need the indices of each axis at the oversampled
-        # resolution; if oversampling = 4 then x = [0, 0.25, 0.5, 0.75, ...]
-        x = np.arange(self._nx, dtype=np.float64) / self.oversampling[0]
-        y = np.arange(self._ny, dtype=np.float64) / self.oversampling[1]
-
-        # Take indices where the undersampled grid is an integer --
-        # i.e., the actual undersampled grid -- and find the cut where
-        # sqrt(dx**2 + dy**2) <= radius
-        x_0, y_0 = int((self._nx - 1) / 2), int((self._ny - 1) / 2)
-
-        # However, as we are in units of the undersampled grid, we must
-        # convert to undersampled units by the same factor of oversampling
-        x_0 /= self.oversampling[0]
-        y_0 /= self.oversampling[1]
-
-        # When checking if the index is at the center of a pixel, we
-        # check such that the index number is half that of the
-        # oversampling -- if we oversample by a factor 4 then the middle
-        # pixel of the 0th large pixel is 2 ([0, 1, 2, 3, 4]). For this to
-        # work we require oversampling to be an even number; otherwise,
-        # the ``middle'' pixel will be halfway between two oversampled
-        # pixels.
-        over_index_middle = 1 / 2
-        cut = (((x.reshape(1, -1) - x_0)**2 + (y.reshape(-1, 1) - y_0)**2 <=
-                self._norm_radius**2)
-               & (x.reshape(1, -1) % 1.0 == over_index_middle)
-               & (y.reshape(-1, 1) % 1.0 == over_index_middle))
-
-        return np.sum(self._data[cut], dtype=np.float64)
+        xypos = (self._nx / 2., self._ny / 2.)
+        # TODO: generalize "radius" (ellipse?) is oversampling is
+        # different along x/y axes
+        radius = self._norm_radius * self.oversampling[0]
+        aper = CircularAperture(xypos, r=radius)
+        flux, _ = aper.do_photometry(self._data, method='exact')
+        return flux[0] / np.product(self.oversampling)
 
     def _compute_normalization(self):
         """
@@ -600,7 +579,6 @@ class EPSFModel(FittableImageModel):
         sum over the inner N (default=5.5) pixels of the non-oversampled
         image. Will re-normalize the data to the value calculated.
         """
-
         if self._img_norm is None:
             if np.sum(self._data) == 0:
                 self._img_norm = 1
@@ -617,24 +595,6 @@ class EPSFModel(FittableImageModel):
                           "normalization constant. Normalization "
                           "constant will be set to 1.", NonNormalizable)
 
-    def _set_oversampling(self, value):
-        try:
-            value = np.atleast_1d(value).astype(int)
-            if len(value) == 1:
-                value = np.repeat(value, 2)
-            # We need oversampling to be a factor of 2 for ``middle of
-            # pixel'' in the undersampled regime to have a pixel placed at
-            # it in the oversampled regime.
-            if np.any(value % 2 != 0) and np.logical_not(np.all(value == 1)):
-                raise ValueError('Oversampling factor must be a multiple of '
-                                 'two')
-        except ValueError:
-            raise ValueError('Oversampling factor must be a scalar')
-        if np.any(value <= 0):
-            raise ValueError('Oversampling factor must be greater than 0')
-
-        self._oversampling = value
-
     def normalized_data(self):
         """
         Overloaded dummy function that also returns self._data, as the
@@ -642,7 +602,6 @@ class EPSFModel(FittableImageModel):
         and as such self._data will sum, accounting for
         under/oversampled pixels, to 1/self._normalization_correction.
         """
-
         return self._data
 
     @FittableImageModel.origin.setter
@@ -660,12 +619,12 @@ class EPSFModel(FittableImageModel):
         """
         Compute/define the interpolating spline.
 
-        This function can be overriden in a subclass to define custom
+        This function can be overridden in a subclass to define custom
         interpolators.
 
         Parameters
         ----------
-        kwargs : dict, optional
+        **kwargs : dict, optional
             Additional optional keyword arguments:
 
             - **degree** : int, tuple, optional
@@ -683,8 +642,8 @@ class EPSFModel(FittableImageModel):
         -----
         * When subclassing :py:class:`FittableImageModel` for the
           purpose of overriding :py:func:`compute_interpolator`, the
-          :py:func:`evaluate` may need to overriden as well depending on
-          the behavior of the new interpolator. In addition, for
+          :py:func:`evaluate` may need to overridden as well depending
+          on the behavior of the new interpolator. In addition, for
           improved future compatibility, make sure that the overriding
           method stores keyword arguments ``kwargs`` by calling
           ``_store_interpolator_kwargs`` method.
@@ -694,7 +653,6 @@ class EPSFModel(FittableImageModel):
           decrease code performance due to the need to recompute
           interpolator.
         """
-
         from scipy.interpolate import RectBivariateSpline
 
         if 'degree' in kwargs:
@@ -719,8 +677,8 @@ class EPSFModel(FittableImageModel):
 
         # Interpolator must be set to interpolate on the undersampled
         # pixel grid, going from 0 to len(undersampled_grid)
-        x = np.arange(self._nx, dtype=np.float) / self.oversampling[0]
-        y = np.arange(self._ny, dtype=np.float) / self.oversampling[1]
+        x = np.arange(self._nx, dtype=float) / self.oversampling[0]
+        y = np.arange(self._ny, dtype=float) / self.oversampling[1]
         self.interpolator = RectBivariateSpline(
             x, y, self._data.T, kx=degx, ky=degy, s=smoothness)
 
@@ -731,7 +689,6 @@ class EPSFModel(FittableImageModel):
         Evaluate the model on some input variables and provided model
         parameters.
         """
-
         xi = np.asarray(x) - x_0 + self._x_origin
         yi = np.asarray(y) - y_0 + self._y_origin
 
@@ -806,7 +763,7 @@ class GriddedPSFModel(Fittable2DModel):
         if not np.isscalar(data.meta['oversampling']):
             raise ValueError('oversampling must be a scalar value')
 
-        self.data = np.array(data.data, copy=True, dtype=np.float)
+        self.data = np.array(data.data, copy=True, dtype=float)
         self.meta = data.meta
         self.grid_xypos = data.meta['grid_xypos']
         self.oversampling = data.meta['oversampling']
@@ -848,7 +805,6 @@ class GriddedPSFModel(Fittable2DModel):
         index : int
             The index of the lower bound.
         """
-
         idx = np.searchsorted(data, x)
         if idx == 0:
             idx0 = 0
@@ -874,7 +830,6 @@ class GriddedPSFModel(Fittable2DModel):
         indices : list of int
             A list of indices of the bounding grid points.
         """
-
         if not np.isscalar(x) or not np.isscalar(y):  # pragma: no cover
             raise TypeError('x and y must be scalars')
 
@@ -906,9 +861,9 @@ class GriddedPSFModel(Fittable2DModel):
         xyref : list of 4 (x, y) pairs
             A list of 4 ``(x, y)`` pairs that form a rectangle.
 
-        refdata : 3D `~numpy.ndarray`
-            A 3D `~numpy.ndarray` of shape ``(4, nx, ny)``.  The first
-            axis corresponds to ``xyref``, i.e. ``refdata[0, :, :]`` is
+        zref : 3D `~numpy.ndarray`
+            A 3D `~numpy.ndarray` of shape ``(4, nx, ny)``. The first
+            axis corresponds to ``xyref``, i.e., ``refdata[0, :, :]`` is
             the 2D array located at ``xyref[0]``.
 
         xi, yi : float
@@ -921,7 +876,6 @@ class GriddedPSFModel(Fittable2DModel):
         result : 2D `~numpy.ndarray`
             The 2D interpolated array.
         """
-
         if len(xyref) != 4:
             raise ValueError('xyref must contain only 4 (x, y) pairs')
 
@@ -953,11 +907,10 @@ class GriddedPSFModel(Fittable2DModel):
 
         return np.sum(data * weights[:, None, None], axis=0) / norm
 
-    def evaluate(self, x, y, flux, x_0, y_0):
+    def _compute_local_model(self, x_0, y_0):
         """
-        Evaluate the `GriddedPSFModel` for the input parameters.
+        Return `FittableImageModel` for interpolated PSF at some (x_0, y_0).
         """
-
         # NOTE: this is needed because the PSF photometry routines input
         # length-1 values instead of scalars.  TODO: fix the photometry
         # routines.
@@ -982,11 +935,20 @@ class GriddedPSFModel(Fittable2DModel):
 
             self._psf_interp = self._bilinear_interp(xyref, psfs, x_0, y_0)
 
-        # now evaluate the PSF at the (x_0, y_0) subpixel position on
-        # the input (x, y) values
+        # Construct the model using the interpolated supersampled data
         psfmodel = FittableImageModel(self._psf_interp,
                                       oversampling=self.oversampling)
+        return psfmodel
 
+    def evaluate(self, x, y, flux, x_0, y_0):
+        """
+        Evaluate the `GriddedPSFModel` for the input parameters.
+        """
+        # Get the local PSF at the (x_0,y_0)
+        psfmodel = self._compute_local_model(x_0, y_0)
+
+        # now evaluate the PSF at the (x_0, y_0) subpixel position on
+        # the input (x, y) values
         return psfmodel.evaluate(x, y, flux, x_0, y_0)
 
 
@@ -998,9 +960,9 @@ class IntegratedGaussianPRF(Fittable2DModel):
     PSF (see :ref:`psf-terminology` for more about the terminology used
     here.)
 
-    This model is a Gaussian *integrated* over an area of ``1`` (in
-    units of the model input coordinates, e.g. 1 pixel).  This is in
-    contrast to the apparently similar
+    This model is a Gaussian *integrated* over an area of
+    ``1`` (in units of the model input coordinates, e.g., 1
+    pixel). This is in contrast to the apparently similar
     `astropy.modeling.functional_models.Gaussian2D`, which is the value
     of a 2D Gaussian *at* the input coordinates, with no integration.
     So this model is equivalent to assuming the PSF is Gaussian at a
@@ -1048,7 +1010,6 @@ class IntegratedGaussianPRF(Fittable2DModel):
     sigma = Parameter(default=1, fixed=True)
 
     _erf = None
-    fit_deriv = None
 
     @property
     def bounding_box(self):
@@ -1068,7 +1029,6 @@ class IntegratedGaussianPRF(Fittable2DModel):
 
     def evaluate(self, x, y, flux, x_0, y_0, sigma):
         """Model function Gaussian PSF model."""
-
         return (flux / 4 *
                 ((self._erf((x - x_0 + 0.5) / (np.sqrt(2) * sigma)) -
                   self._erf((x - x_0 - 0.5) / (np.sqrt(2) * sigma))) *
@@ -1145,7 +1105,6 @@ class PRFAdapter(Fittable2DModel):
 
     def evaluate(self, x, y, flux, x_0, y_0):
         """The evaluation function for PRFAdapter."""
-
         if self.xname is None:
             dx = x - x_0
         else:
