@@ -8,7 +8,7 @@ import warnings
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata.utils import overlap_slices, NoOverlapError
 from astropy.stats import SigmaClip, gaussian_sigma_to_fwhm
-from astropy.table import Column, Table, hstack, vstack
+from astropy.table import Column, QTable, hstack, vstack
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
@@ -19,6 +19,7 @@ from ..aperture import CircularAperture, aperture_photometry
 from ..background import MMMBackground
 from ..detection import DAOStarFinder
 from ..utils.exceptions import NoDetectionsWarning
+from ..utils._misc import _get_version_info
 
 __all__ = ['BasicPSFPhotometry', 'IterativelySubtractedPSFPhotometry',
            'DAOPhotPSFPhotometry']
@@ -40,16 +41,16 @@ class BasicPSFPhotometry:
     Parameters
     ----------
     group_maker : callable or `~photutils.psf.GroupStarsBase`
-        ``group_maker`` should be able to decide whether a given star
-        overlaps with any other and label them as beloging to the same
-        group.  ``group_maker`` receives as input an
+        ``group_maker`` should be able to decide whether a given
+        star overlaps with any other and label them as belonging
+        to the same group. ``group_maker`` receives as input an
         `~astropy.table.Table` object with columns named as ``id``,
         ``x_0``, ``y_0``, in which ``x_0`` and ``y_0`` have the same
-        meaning of ``xcentroid`` and ``ycentroid``.  This callable must
+        meaning of ``xcentroid`` and ``ycentroid``. This callable must
         return an `~astropy.table.Table` with columns ``id``, ``x_0``,
-        ``y_0``, and ``group_id``. The column ``group_id`` should cotain
-        integers starting from ``1`` that indicate which group a given
-        source belongs to. See, e.g., `~photutils.psf.DAOGroup`.
+        ``y_0``, and ``group_id``. The column ``group_id`` should
+        contain integers starting from ``1`` that indicate which group a
+        given source belongs to. See, e.g., `~photutils.psf.DAOGroup`.
     bkg_estimator : callable, instance of any \
             `~photutils.background.BackgroundBase` subclass, or None
         ``bkg_estimator`` should be able to compute either a scalar
@@ -158,13 +159,13 @@ class BasicPSFPhotometry:
                     self._fitshape = tuple(value)
                 else:
                     raise ValueError('fitshape must be odd integer-valued, '
-                                     'received fitshape = {}'.format(value))
+                                     f'received fitshape={value}')
             else:
                 raise ValueError('fitshape must have positive elements, '
-                                 'received fitshape = {}'.format(value))
+                                 f'received fitshape={value}')
         else:
             raise ValueError('fitshape must have two dimensions, '
-                             'received fitshape = {}'.format(value))
+                             f'received fitshape={value}')
 
     @property
     def aperture_radius(self):
@@ -181,7 +182,7 @@ class BasicPSFPhotometry:
 
     def get_residual_image(self):
         """
-        Returns an image that is the result of the subtraction between
+        Return an image that is the result of the subtraction between
         the original image and the fitted sources.
 
         Returns
@@ -189,15 +190,41 @@ class BasicPSFPhotometry:
         residual_image : 2D array-like, `~astropy.io.fits.ImageHDU`, \
             `~astropy.io.fits.HDUList`
         """
-
         return self._residual_image
 
+    def set_aperture_radius(self):
+        """
+        Set the fallback aperture radius for initial flux calculations
+        in cases where no flux is supplied for a given star.
+        """
+        if hasattr(self.psf_model, 'fwhm'):
+            self.aperture_radius = self.psf_model.fwhm.value
+        elif hasattr(self.psf_model, 'sigma'):
+            self.aperture_radius = (self.psf_model.sigma.value *
+                                    gaussian_sigma_to_fwhm)
+        # If PSF model doesn't have FWHM or sigma value -- as it
+        # is not a Gaussian; most likely because it's an ePSF --
+        # then we fall back on fitting a circle of the average
+        # size of the fitting box. As ``fitshape`` is the width
+        # of the box, we need (width-1)/2 as the radius.
+        else:
+            self.aperture_radius = float(np.amin((np.asanyarray(
+                                         self.fitshape) - 1) / 2))
+            warnings.warn('aperture_radius is None and could not '
+                          'be determined by psf_model. Setting '
+                          'radius to the smallest fitshape size. '
+                          'This aperture radius will be used if '
+                          'initial fluxes require computing for any '
+                          'input stars. If fitshape is significantly '
+                          'larger than the psf_model core lengthscale, '
+                          'consider supplying a specific aperture_radius.',
+                          AstropyUserWarning)
+
     def __call__(self, image, init_guesses=None):
         """
-        Performs PSF photometry. See `do_photometry` for more details
+        Perform PSF photometry. See `do_photometry` for more details
         including the `__call__` signature.
         """
-
         return self.do_photometry(image, init_guesses)
 
     def do_photometry(self, image, init_guesses=None):
@@ -246,41 +273,13 @@ class BasicPSFPhotometry:
             covariance matrix. If ``param_cov`` is not present,
             uncertanties are not reported.
         """
-
         if self.bkg_estimator is not None:
             image = image - self.bkg_estimator(image)
 
         if self.aperture_radius is None:
-            if hasattr(self.psf_model, 'fwhm'):
-                self.aperture_radius = self.psf_model.fwhm.value
-            elif hasattr(self.psf_model, 'sigma'):
-                self.aperture_radius = (self.psf_model.sigma.value *
-                                        gaussian_sigma_to_fwhm)
-
-        if self.aperture_radius is None:
-            if init_guesses is None:
-                raise ValueError('aperture_radius was not input and could '
-                                 'not be determined by the input psf_model '
-                                 '(e.g., an EPSFModel).  For tabular PSF '
-                                 'models, you must input the aperture_radius '
-                                 'keyword.  For analytical PSF models, you '
-                                 'must either input the aperture_radius '
-                                 'keyword or define a fwhm or sigma '
-                                 'attribute on your input psf_model.')
-
-            if (init_guesses is not None and
-                    'flux_0' not in init_guesses.colnames):
-                raise ValueError('init_guesses were input, but the "flux_0" '
-                                 'column was not present.  Initial fluxes '
-                                 'cannot be calculated because '
-                                 'aperture_radius must was not input and '
-                                 'could not be determined by the input '
-                                 'psf_model (e.g., an EPSFModel).  For '
-                                 'analytical PSF models, you must either '
-                                 'input the aperture_radius keyword or '
-                                 'define a fwhm or sigma attribute on your '
-                                 'input psf_model.')
+            self.set_aperture_radius()
 
+        skip_group_maker = False
         if init_guesses is not None:
             # make sure the code does not modify user's input
             init_guesses = init_guesses.copy()
@@ -290,7 +289,14 @@ class BasicPSFPhotometry:
                               'than None, which is ambiguous. finder is '
                               'going to be ignored.', AstropyUserWarning)
 
-            if 'flux_0' not in init_guesses.colnames:
+            colnames = init_guesses.colnames
+            if 'group_id' in colnames:
+                warnings.warn('init_guesses contains a "group_id" column. '
+                              'The group_maker step will be skipped.',
+                              AstropyUserWarning)
+                skip_group_maker = True
+
+            if 'flux_0' not in colnames:
                 positions = np.transpose((init_guesses['x_0'],
                                           init_guesses['y_0']))
                 apertures = CircularAperture(positions,
@@ -321,16 +327,16 @@ class BasicPSFPhotometry:
                 sources['aperture_flux'] = aperture_photometry(
                     image, apertures)['aperture_sum']
 
-                # init_guesses should be the initial 3 required parameters --
-                # x, y, flux -- and then concatentated with any additional
-                # sources, if there are any
-                init_guesses = Table(names=['x_0', 'y_0', 'flux_0'],
-                                     data=[sources['xcentroid'],
-                                           sources['ycentroid'],
-                                           sources['aperture_flux']])
+                # init_guesses should be the initial 3 required
+                # parameters (x, y, flux) and then concatenated with any
+                # additional sources, if there are any
+                init_guesses = QTable(names=['x_0', 'y_0', 'flux_0'],
+                                      data=[sources['xcentroid'],
+                                            sources['ycentroid'],
+                                            sources['aperture_flux']])
 
                 # Currently only needed for the finder, as group_maker and
-                # nstar return the original Table with new columns, unlike
+                # nstar return the original table with new columns, unlike
                 # finder
                 self._get_additional_columns(sources, init_guesses)
 
@@ -340,13 +346,28 @@ class BasicPSFPhotometry:
                 init_guesses[p0] = (len(init_guesses) *
                                     [getattr(self.psf_model, param).value])
 
-        star_groups = self.group_maker(init_guesses)
+        if skip_group_maker:
+            star_groups = init_guesses
+        else:
+            star_groups = self.group_maker(init_guesses)
+
         output_tab, self._residual_image = self.nstar(image, star_groups)
-
         star_groups = star_groups.group_by('group_id')
-        output_tab = hstack([star_groups, output_tab])
 
-        return output_tab
+        if hasattr(output_tab, 'update'):  # requires Astropy >= 5.0
+            star_groups.update(output_tab)
+        else:
+            common_cols = set(star_groups.colnames).intersection(
+                output_tab.colnames)
+            for name, col in output_tab.items():
+                if name in common_cols:
+                    star_groups.replace_column(name, col, copy=True)
+                else:
+                    star_groups.add_column(col, name=name, copy=True)
+
+        star_groups.meta = {'version': _get_version_info()}
+
+        return star_groups
 
     def nstar(self, image, star_groups):
         """
@@ -359,6 +380,7 @@ class BasicPSFPhotometry:
         ----------
         image : numpy.ndarray
             Background-subtracted image.
+
         star_groups : `~astropy.table.Table`
             This table must contain the following columns: ``id``,
             ``group_id``, ``x_0``, ``y_0``, ``flux_0``.  ``x_0`` and
@@ -370,17 +392,17 @@ class BasicPSFPhotometry:
 
         Returns
         -------
-        result_tab : `~astropy.table.Table`
+        result_tab : `~astropy.table.QTable`
             Astropy table that contains photometry results.
+
         image : numpy.ndarray
             Residual image.
         """
-
-        result_tab = Table()
+        result_tab = QTable()
         for param_tab_name in self._pars_to_output.keys():
             result_tab.add_column(Column(name=param_tab_name))
 
-        unc_tab = Table()
+        unc_tab = QTable()
         for param, isfixed in self.psf_model.fixed.items():
             if not isfixed:
                 unc_tab.add_column(Column(name=param + "_unc"))
@@ -403,7 +425,7 @@ class BasicPSFPhotometry:
             fit_model = self.fitter(group_psf, x[usepixel], y[usepixel],
                                     image[usepixel])
             param_table = self._model_params2table(fit_model,
-                                                   len(star_groups.groups[n]))
+                                                   star_groups.groups[n])
             result_tab = vstack([result_tab, param_table])
 
             param_cov = self.fitter.fit_info.get('param_cov', None)
@@ -428,9 +450,7 @@ class BasicPSFPhotometry:
         """
         Function to parse additional columns from ``in_table`` and add them to
         ``out_table``.
-
         """
-
         if self._extra_output_cols is not None:
             for col_name in self._extra_output_cols:
                 if col_name in in_table.colnames:
@@ -449,7 +469,6 @@ class BasicPSFPhotometry:
         * ``pars_to_output`` : Dict which maps the names of the fitted
           parameters to the actual name of the parameter in the model.
         """
-
         xname, yname, fluxname = _extract_psf_fitting_names(self.psf_model)
         self._pars_to_set = {'x_0': xname, 'y_0': yname, 'flux_0': fluxname}
         self._pars_to_output = {'x_fit': xname, 'y_fit': yname,
@@ -474,12 +493,11 @@ class BasicPSFPhotometry:
 
         Returns
         -------
-        unc_tab : `~astropy.table.Table`
-            Table which contains uncertainties on the fitted parameters.
+        unc_tab : `~astropy.table.QTable`
+            A table which contains uncertainties on the fitted parameters.
             The uncertainties are reported as one standard deviation.
         """
-
-        unc_tab = Table()
+        unc_tab = QTable()
         for param_name in self.psf_model.param_names:
             if not self.psf_model.fixed[param_name]:
                 unc_tab.add_column(Column(name=param_name + "_unc",
@@ -494,7 +512,7 @@ class BasicPSFPhotometry:
 
         return unc_tab
 
-    def _model_params2table(self, fit_model, star_group_size):
+    def _model_params2table(self, fit_model, star_group):
         """
         Place fitted parameters into an astropy table.
 
@@ -505,27 +523,37 @@ class BasicPSFPhotometry:
             in this package like `~photutils.psf.sandbox.DiscretePRF`,
             `~photutils.psf.IntegratedGaussianPRF`, or any other
             suitable 2D model.
-        star_group_size : int
-            Number of stars in the given group.
+
+        star_group : `~astropy.table.Table`
+            the star group instance.
 
         Returns
         -------
-        param_tab : `~astropy.table.Table`
-            Table that contains the fitted parameters.
+        param_tab : `~astropy.table.QTable`
+            A table that contains the fitted parameters.
         """
-
-        param_tab = Table()
+        param_tab = QTable()
 
         for param_tab_name in self._pars_to_output.keys():
             param_tab.add_column(Column(name=param_tab_name,
-                                        data=np.empty(star_group_size)))
+                                        data=np.empty(len(star_group))))
 
-        if star_group_size > 1:
-            for i in range(star_group_size):
+        if len(star_group) > 1:
+            for i in range(len(star_group)):
                 for param_tab_name, param_name in self._pars_to_output.items():
-                    param_tab[param_tab_name][i] = getattr(fit_model,
-                                                           param_name +
-                                                           '_' + str(i)).value
+                    # get sub_model corresponding to star with index i as name
+                    # name was set in utils.get_grouped_psf_model()
+                    # we can't use model['name'] here as that only
+                    # searches leaves and we might want a intermediate
+                    # node of the tree
+                    sub_models = [model for model
+                                  in fit_model.traverse_postorder() if model.name == i]
+                    if len(sub_models) != 1:
+                        raise ValueError('sub_models must have a length of 1')
+                    sub_model = sub_models[0]
+
+                    param_tab[param_tab_name][i] = getattr(sub_model,
+                                                           param_name).value
         else:
             for param_tab_name, param_name in self._pars_to_output.items():
                 param_tab[param_tab_name] = getattr(fit_model,
@@ -545,16 +573,16 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
     Parameters
     ----------
     group_maker : callable or `~photutils.psf.GroupStarsBase`
-        ``group_maker`` should be able to decide whether a given star
-        overlaps with any other and label them as beloging to the same
-        group.  ``group_maker`` receives as input an
+        ``group_maker`` should be able to decide whether a given
+        star overlaps with any other and label them as belonging
+        to the same group. ``group_maker`` receives as input an
         `~astropy.table.Table` object with columns named as ``id``,
         ``x_0``, ``y_0``, in which ``x_0`` and ``y_0`` have the same
-        meaning of ``xcentroid`` and ``ycentroid``.  This callable must
+        meaning of ``xcentroid`` and ``ycentroid``. This callable must
         return an `~astropy.table.Table` with columns ``id``, ``x_0``,
-        ``y_0``, and ``group_id``. The column ``group_id`` should cotain
-        integers starting from ``1`` that indicate which group a given
-        source belongs to. See, e.g., `~photutils.psf.DAOGroup`.
+        ``y_0``, and ``group_id``. The column ``group_id`` should
+        contain integers starting from ``1`` that indicate which group a
+        given source belongs to. See, e.g., `~photutils.psf.DAOGroup`.
     bkg_estimator : callable, instance of any \
             `~photutils.background.BackgroundBase` subclass, or None
         ``bkg_estimator`` should be able to compute either a scalar
@@ -702,7 +730,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         Returns
         -------
         output_table : `~astropy.table.Table` or None
-            Table with the photometry results, i.e., centroids and
+            A table with the photometry results, i.e., centroids and
             fluxes estimations and the initial estimates used to start
             the fitting process. Uncertainties on the fitted parameters
             are reported as columns called ``<paramname>_unc`` provided
@@ -710,7 +738,6 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             ``fit_info`` with the key ``param_cov``, which contains the
             covariance matrix.
         """
-
         if init_guesses is not None:
             table = super().do_photometry(image, init_guesses)
             table['iter_detected'] = np.ones(table['x_fit'].shape, dtype=int)
@@ -726,14 +753,13 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                 self._residual_image = image
 
             if self.aperture_radius is None:
-                if hasattr(self.psf_model, 'fwhm'):
-                    self.aperture_radius = self.psf_model.fwhm.value
-                elif hasattr(self.psf_model, 'sigma'):
-                    self.aperture_radius = (self.psf_model.sigma.value *
-                                            gaussian_sigma_to_fwhm)
+                self.set_aperture_radius()
 
             output_table = self._do_photometry()
-        return output_table
+
+        output_table.meta = {'version': _get_version_info()}
+
+        return QTable(output_table)
 
     def _do_photometry(self, n_start=1):
         """
@@ -753,8 +779,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             fluxes estimations and the initial estimates used to start
             the fitting process.
         """
-
-        output_table = Table()
+        output_table = QTable()
         self._define_fit_param_names()
 
         for (init_parname, fit_parname) in zip(self._pars_to_set.keys(),
@@ -774,10 +799,10 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             sources['aperture_flux'] = aperture_photometry(
                 self._residual_image, apertures)['aperture_sum']
 
-            init_guess_tab = Table(names=['id', 'x_0', 'y_0', 'flux_0'],
-                                   data=[sources['id'], sources['xcentroid'],
-                                         sources['ycentroid'],
-                                         sources['aperture_flux']])
+            init_guess_tab = QTable(names=['id', 'x_0', 'y_0', 'flux_0'],
+                                    data=[sources['id'], sources['xcentroid'],
+                                          sources['ycentroid'],
+                                          sources['aperture_flux']])
             self._get_additional_columns(sources, init_guess_tab)
 
             for param_tab_name, param_name in self._pars_to_set.items():
