@@ -11,7 +11,7 @@ from astropy.nddata.utils import extract_array, subpixel_indices
 from astropy.table import Table
 import numpy as np
 
-from ..utils import mask_to_mirrored_num
+from ..segmentation._utils import mask_to_mirrored_value
 
 __all__ = ['DiscretePRF', 'Reproject']
 
@@ -96,7 +96,6 @@ class DiscretePRF(Fittable2DModel):
     @property
     def prf_shape(self):
         """Shape of the PRF image."""
-
         return self._prf_array.shape[-2:]
 
     def evaluate(self, x, y, flux, x_0, y_0):
@@ -111,16 +110,19 @@ class DiscretePRF(Fittable2DModel):
         ----------
         x : float
             x coordinate array in pixel coordinates.
+
         y : float
             y coordinate array in pixel coordinates.
+
         flux : float
             Model flux.
+
         x_0 : float
             x position of the center of the PRF.
+
         y_0 : float
             y position of the center of the PRF.
         """
-
         # Convert x and y to index arrays
         x = (x - x_0 + 0.5 + self.prf_shape[1] // 2).astype('int')
         y = (y - y_0 + 0.5 + self.prf_shape[0] // 2).astype('int')
@@ -167,24 +169,31 @@ class DiscretePRF(Fittable2DModel):
         ----------
         imdata : array
             Data array with the image to extract the PRF from
+
         positions : List or array or `~astropy.table.Table`
             List of pixel coordinate source positions to use in creating
             the PRF.  If this is a `~astropy.table.Table` it must have
             columns called ``x_0`` and ``y_0``.
+
         size : odd int
             Size of the quadratic PRF image in pixels.
+
         mask : bool array, optional
             Boolean array to mask out bad values.
+
         fluxes : array, optional
             Object fluxes to normalize extracted PRFs. If not given (or
             None), the flux is estimated from an aperture of the same
             size as the PRF image.
+
         mode : {'mean', 'median'}
             One of the following modes to combine the extracted PRFs:
                 * 'mean':  Take the pixelwise mean of the extracted PRFs.
                 * 'median':  Take the pixelwise median of the extracted PRFs.
+
         subsampling : int
             Factor of subsampling of the PRF (default = 1).
+
         fix_nan : bool
             Fix NaN values in the data by replacing it with the
             mirrored value. Assuming that the PRF is symmetrical.
@@ -194,13 +203,12 @@ class DiscretePRF(Fittable2DModel):
         prf : `photutils.psf.sandbox.DiscretePRF`
             Discrete PRF model estimated from data.
         """
-
         # Check input array type and dimension.
         if np.iscomplexobj(imdata):
             raise TypeError('Complex type not supported')
         if imdata.ndim != 2:
-            raise ValueError('{0}-d array not supported. '
-                             'Only 2-d arrays supported.'.format(imdata.ndim))
+            raise ValueError(f'{imdata.ndim}-d array not supported. '
+                             'Only 2-d arrays supported.')
         if size % 2 == 0:
             raise TypeError("Size must be odd.")
 
@@ -272,7 +280,7 @@ class DiscretePRF(Fittable2DModel):
                                         prf_nan[size // 2, size // 2]):
                                     continue
                                 else:
-                                    extracted_prf = mask_to_mirrored_num(
+                                    extracted_prf = mask_to_mirrored_value(
                                         extracted_prf, prf_nan,
                                         (size // 2, size // 2))
                         # Normalize and add extracted PRF to data cube
@@ -319,17 +327,19 @@ class Reproject:
         Parameters
         ----------
         wcs1, wcs2 : WCS objects
-            World coordinate system (WCS) transformations that support
-            the `astropy shared interface for WCS
-            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_ (e.g.
-            `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+            World coordinate system (WCS) transformations that
+            support the `astropy shared interface for WCS
+            <https://docs.astropy.org/en/stable/wcs/wcsapi.html>`_
+            (e.g., `astropy.wcs.WCS`, `gwcs.wcs.WCS`).
+
+        x, y : float or array-like of float
+            The input pixel coordinates.
 
         Returns
         -------
         x, y:  float or array-like of float
-            The pixel coordinates.
+            The reprojected pixel coordinates.
         """
-
         try:
             skycoord = wcs1.pixel_to_world(x, y)
             return wcs2.world_to_pixel(skycoord)
@@ -344,7 +354,7 @@ class Reproject:
 
         Parameters
         ----------
-        x, y:  float or array-like of float
+        x, y : float or array-like of float
             The zero-index pixel coordinates in the original
             (unrectified) image.
 
@@ -353,7 +363,6 @@ class Reproject:
         x, y:  float or array-like
             The zero-index pixel coordinates in the rectified image.
         """
-
         return self._reproject(self.wcs_original, self.wcs_rectified, x, y)
 
     def to_original(self, x, y):
@@ -363,7 +372,7 @@ class Reproject:
 
         Parameters
         ----------
-        x, y:  float or array-like of float
+        x, y : float or array-like of float
             The zero-index pixel coordinates in the rectified image.
 
         Returns
@@ -372,5 +381,4 @@ class Reproject:
             The zero-index pixel coordinates in the original
             (unrectified) image.
         """
-
         return self._reproject(self.wcs_rectified, self.wcs_original, x, y)
