@@ -9,12 +9,7 @@ from numpy.testing import assert_almost_equal
 import pytest
 
 from ..groupstars import DAOGroup, DBSCANGroup
-
-try:
-    import sklearn.cluster  # noqa
-    HAS_SKLEARN = True
-except ImportError:
-    HAS_SKLEARN = False
+from ...utils._optional_deps import HAS_SKLEARN  # noqa
 
 
 def assert_table_almost_equal(table1, table2):
@@ -54,10 +49,10 @@ class TestDAOGROUP:
                         -np.sqrt(2)/4])
         x_1 = x_0 + 2.0
         first_group = Table([x_0, y_0, np.arange(len(x_0)) + 1,
-                            np.ones(len(x_0), dtype=np.int)],
+                            np.ones(len(x_0), dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         second_group = Table([x_1, y_0, len(x_0) + np.arange(len(x_0)) + 1,
-                              2*np.ones(len(x_0), dtype=np.int)],
+                              2*np.ones(len(x_0), dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         starlist = vstack([first_group, second_group])
         daogroup = DAOGroup(crit_separation=0.6)
@@ -85,10 +80,10 @@ class TestDAOGROUP:
         """
 
         first_group = Table([np.zeros(5), np.linspace(0, 1, 5),
-                             np.arange(5) + 1, np.ones(5, dtype=np.int)],
+                             np.arange(5) + 1, np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         second_group = Table([np.zeros(5), np.linspace(2, 3, 5),
-                              6 + np.arange(5), 2*np.ones(5, dtype=np.int)],
+                              6 + np.arange(5), 2*np.ones(5, dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         starlist = vstack([first_group, second_group])
         daogroup = DAOGroup(crit_separation=0.3)
@@ -116,10 +111,10 @@ class TestDAOGROUP:
         """
 
         first_group = Table([np.linspace(0, 1, 5), np.zeros(5),
-                             np.arange(5) + 1, np.ones(5, dtype=np.int)],
+                             np.arange(5) + 1, np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         second_group = Table([np.linspace(2, 3, 5), np.zeros(5),
-                              6 + np.arange(5), 2*np.ones(5, dtype=np.int)],
+                              6 + np.arange(5), 2*np.ones(5, dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         starlist = vstack([first_group, second_group])
         daogroup = DAOGroup(crit_separation=0.3)
@@ -154,7 +149,7 @@ class TestDAOGROUP:
         xx = np.hstack((x, x))
         yy = np.hstack((y, -y))
         starlist = Table([xx, yy, np.arange(10) + 1,
-                          np.ones(10, dtype=np.int)],
+                          np.ones(10, dtype=int)],
                          names=('x_0', 'y_0', 'id', 'group_id'))
         daogroup = DAOGroup(crit_separation=2.5)
         test_starlist = daogroup(starlist['x_0', 'y_0', 'id'])
@@ -181,16 +176,16 @@ class TestDAOGROUP:
         """
 
         first_group = Table([1.5*np.ones(5), np.linspace(0, 1, 5),
-                             np.arange(5) + 1, np.ones(5, dtype=np.int)],
+                             np.arange(5) + 1, np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         second_group = Table([1.5*np.ones(5), np.linspace(2, 3, 5),
-                              6 + np.arange(5), 2*np.ones(5, dtype=np.int)],
+                              6 + np.arange(5), 2*np.ones(5, dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         third_group = Table([np.linspace(0, 1, 5), 1.5*np.ones(5),
-                             11 + np.arange(5), 3*np.ones(5, dtype=np.int)],
+                             11 + np.arange(5), 3*np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         fourth_group = Table([np.linspace(2, 3, 5), 1.5*np.ones(5),
-                              16 + np.arange(5), 4*np.ones(5, dtype=np.int)],
+                              16 + np.arange(5), 4*np.ones(5, dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         starlist = vstack([first_group, second_group, third_group,
                            fourth_group])
@@ -225,13 +220,13 @@ class TestDAOGROUP:
         x_1 = x_0 + 2.0
         x_2 = x_0 + 4.0
         first_group = Table([x_0, y_0, np.arange(5) + 1,
-                             np.ones(5, dtype=np.int)],
+                             np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         second_group = Table([x_1, y_0, 6 + np.arange(5),
-                              2*np.ones(5, dtype=np.int)],
+                              2*np.ones(5, dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         third_group = Table([x_2, y_0, 11 + np.arange(5),
-                             3*np.ones(5, dtype=np.int)],
+                             3*np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         starlist = vstack([first_group, second_group, third_group])
         daogroup = DAOGroup(crit_separation=0.6)
@@ -287,10 +282,10 @@ class TestDBSCANGroup:
                         -np.sqrt(2)/4])
         x_1 = x_0 + 2.0
         first_group = Table([x_0, y_0, np.arange(len(x_0)) + 1,
-                            np.ones(len(x_0), dtype=np.int)],
+                            np.ones(len(x_0), dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         second_group = Table([x_1, y_0, len(x_0) + np.arange(len(x_0)) + 1,
-                              2*np.ones(len(x_0), dtype=np.int)],
+                              2*np.ones(len(x_0), dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         starlist = vstack([first_group, second_group])
         dbscan = DBSCANGroup(crit_separation=0.6)
@@ -299,16 +294,16 @@ class TestDBSCANGroup:
 
     def test_group_stars_two(object):
         first_group = Table([1.5*np.ones(5), np.linspace(0, 1, 5),
-                             np.arange(5) + 1, np.ones(5, dtype=np.int)],
+                             np.arange(5) + 1, np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         second_group = Table([1.5*np.ones(5), np.linspace(2, 3, 5),
-                              6 + np.arange(5), 2*np.ones(5, dtype=np.int)],
+                              6 + np.arange(5), 2*np.ones(5, dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         third_group = Table([np.linspace(0, 1, 5), 1.5*np.ones(5),
-                             11 + np.arange(5), 3*np.ones(5, dtype=np.int)],
+                             11 + np.arange(5), 3*np.ones(5, dtype=int)],
                             names=('x_0', 'y_0', 'id', 'group_id'))
         fourth_group = Table([np.linspace(2, 3, 5), 1.5*np.ones(5),
-                              16 + np.arange(5), 4*np.ones(5, dtype=np.int)],
+                              16 + np.arange(5), 4*np.ones(5, dtype=int)],
                              names=('x_0', 'y_0', 'id', 'group_id'))
         starlist = vstack([first_group, second_group, third_group,
                            fourth_group])
