@@ -7,20 +7,14 @@ from itertools import product
 
 from astropy.modeling.models import Gaussian2D, Moffat2D
 from astropy.nddata import NDData
-import astropy.units as u
 import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
 from ..models import (FittableImageModel, GriddedPSFModel,
                       IntegratedGaussianPRF, PRFAdapter)
-from ...segmentation import detect_sources, source_properties
-
-try:
-    import scipy  # noqa
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+from ...segmentation import detect_sources, SourceCatalog
+from ...utils._optional_deps import HAS_SCIPY  # noqa
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -29,7 +23,7 @@ class TestFittableImageModel:
         self.gm = Gaussian2D(x_stddev=3, y_stddev=3)
 
     def test_fittable_image_model(self):
-        xx, yy = np.mgrid[-2:3, -2:3]
+        yy, xx = np.mgrid[-2:3, -2:3]
         model_nonorm = FittableImageModel(self.gm(xx, yy))
 
         assert_allclose(model_nonorm(0, 0), self.gm(0, 0))
@@ -54,7 +48,7 @@ class TestFittableImageModel:
 
     def test_fittable_image_model_oversampling(self):
         oversamp = 3  # oversampling factor
-        xx, yy = np.mgrid[-3:3.00001:(1/oversamp), -3:3.00001:(1/oversamp)]
+        yy, xx = np.mgrid[-3:3.00001:(1/oversamp), -3:3.00001:(1/oversamp)]
 
         im = self.gm(xx, yy)
         assert im.shape[0] > 7
@@ -83,7 +77,7 @@ class TestFittableImageModel:
         gm = Gaussian2D(x_stddev=2, y_stddev=3)
 
         oversamp = 3
-        xx, yy = np.mgrid[-3:3.00001:(1/oversamp), -3:3.00001:(1/oversamp)]
+        yy, xx = np.mgrid[-3:3.00001:(1 / oversamp), -3:3.00001:(1 / oversamp)]
 
         model_oversampled = FittableImageModel(gm(xx, yy),
                                                oversampling=oversamp)
@@ -103,7 +97,7 @@ class TestFittableImageModel:
 
     def test_oversampling_inputs(self):
         data = np.arange(30).reshape(5, 6)
-        for oversampling in [4, (3, 3), (3, 4), '1', ('1', '2')]:
+        for oversampling in [4, (3, 3), (3, 4)]:
             fim = FittableImageModel(data, oversampling=oversampling)
             if not hasattr(oversampling, '__len__'):
                 _oversamp = float(oversampling)
@@ -111,9 +105,10 @@ class TestFittableImageModel:
                 _oversamp = tuple(float(o) for o in oversampling)
             assert np.all(fim._oversampling == _oversamp)
 
-        for oversampling in ['a', ('b', 2), (-1, 3), -1]:
+        for oversampling in [-1, [-2, 4], (1, 4, 8), ((1, 2), (3, 4)),
+                             np.ones((2, 2, 2)), 2.1, np.nan, (1, np.inf)]:
             with pytest.raises(ValueError):
-                fim = FittableImageModel(data, oversampling=oversampling)
+                FittableImageModel(data, oversampling=oversampling)
 
 
 class TestGriddedPSFModel:
@@ -254,17 +249,17 @@ class TestGriddedPSFModel:
 
         shape = (200, 200)
         data = np.zeros(shape)
-        eval_xshape = np.int(np.ceil(self.psfmodel.data.shape[2] /
-                                     self.psfmodel.oversampling))
-        eval_yshape = np.int(np.ceil(self.psfmodel.data.shape[1] /
-                                     self.psfmodel.oversampling))
+        eval_xshape = (np.ceil(self.psfmodel.data.shape[2] /
+                               self.psfmodel.oversampling)).astype(int)
+        eval_yshape = (np.ceil(self.psfmodel.data.shape[1] /
+                               self.psfmodel.oversampling)).astype(int)
 
         xx = [40, 50, 160, 160]
         yy = [60, 150, 50, 140]
         zz = [100, 100, 100, 100]
         for xxi, yyi, zzi in zip(xx, yy, zz):
-            x0 = np.int(np.floor(xxi - (eval_xshape - 1) / 2.))
-            y0 = np.int(np.floor(yyi - (eval_yshape - 1) / 2.))
+            x0 = np.floor(xxi - (eval_xshape - 1) / 2.).astype(int)
+            y0 = np.floor(yyi - (eval_yshape - 1) / 2.).astype(int)
             x1 = x0 + eval_xshape
             y1 = y0 + eval_yshape
 
@@ -282,12 +277,12 @@ class TestGriddedPSFModel:
                                                  y_0=yyi)
 
         segm = detect_sources(data, 0., 5)
-        props = source_properties(data, segm)
-        orients = props.orientation.to(u.deg)
-        assert_allclose(orients[1].value, 50., rtol=1.e-5)
-        assert_allclose(orients[2].value, -80., rtol=1.e-5)
-        assert 88.3 < orients[0].value < 88.4
-        assert 64. < orients[3].value < 64.2
+        cat = SourceCatalog(data, segm)
+        orients = cat.orientation.value
+        assert_allclose(orients[1], 50., rtol=1.e-5)
+        assert_allclose(orients[2], -80., rtol=1.e-5)
+        assert 88.3 < orients[0] < 88.4
+        assert 64. < orients[3] < 64.2
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -345,7 +340,7 @@ class TestPRFAdapter:
         dict(xname='x_0', yname='y_0', fluxname=None, renormalize_psf=True),
         dict(xname='x_0', yname='y_0', fluxname=None, renormalize_psf=False),
         dict(xname=None, yname=None, fluxname=None, renormalize_psf=False)
-        ])
+    ])
     def test_prfadapter_integrates(self, adapterkwargs):
         from scipy.integrate import dblquad
 
