@@ -24,12 +24,7 @@ from ..utils import prepare_psf_model
 from ...background import MMMBackground, StdBackgroundRMS
 from ...datasets import make_gaussian_prf_sources_image, make_noise_image
 from ...detection import DAOStarFinder
-
-try:
-    import scipy  # noqa
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+from ...utils._optional_deps import HAS_SCIPY  # noqa
 
 
 def make_psf_photometry_objs(std=1, sigma_psf=1):
@@ -485,25 +480,82 @@ def test_psf_boundary():
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
-def test_aperture_radius_value_error():
+def test_default_aperture_radius():
     """
-    Test that a ValueError is raised for tabular PSF models when
-    aperture_radius is not defined.
+    Test psf_photometry with non-Gaussian model, such that it raises a
+    warning about aperture_radius.
     """
+    def tophatfinder(image):
+        """ Simple top hat finder function for use with a top hat PRF"""
+        fluxes = np.unique(image[image > 1])
+        table = Table(names=['id', 'xcentroid', 'ycentroid', 'flux'],
+                      dtype=[int, float, float, float])
+        for n, f in enumerate(fluxes):
+            ys, xs = np.where(image == f)
+            x = np.mean(xs)
+            y = np.mean(ys)
+            table.add_row([int(n+1), x, y, f*9])
+        table.sort(['flux'])
 
-    prf = DiscretePRF(test_psf, subsampling=1)
+        return table
 
+    prf = np.zeros((7, 7), float)
+    prf[2:5, 2:5] = 1/9
+    prf = FittableImageModel(prf)
+
+    img = np.zeros((50, 50), float)
+    x0 = [38, 20, 35]
+    y0 = [20, 5, 40]
+    f0 = [50, 100, 200]
+    for x, y, f in zip(x0, y0, f0):
+        img[y-1:y+2, x-1:x+2] = f/9
+
+    intab = Table(data=[[37, 19.6, 34.9], [19.6, 4.5, 40.1]],
+                  names=['x_0', 'y_0'])
+
+    basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
+                                    bkg_estimator=None, psf_model=prf,
+                                    fitshape=7, finder=tophatfinder)
+    # Test for init_guesses is None
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                                                'could not be determined'):
+        results = basic_phot(image=img)
+    assert_allclose(results['flux_fit'], f0, rtol=0.05)
+
+    # Have to reset the object or it saves any updates, and we wish to
+    # re-verify the aperture_radius assignment
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
                                     bkg_estimator=None, psf_model=prf,
                                     fitshape=7)
 
-    with pytest.raises(ValueError):
-        basic_phot(image=image)
+    # Test for init_guesses is not None, but lacks a flux_0 column
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                                                'could not be determined'):
+        results = basic_phot(image=img, init_guesses=intab)
+    assert_allclose(results['flux_fit'], f0, rtol=0.05)
 
-    # with initial guesses, but without a "flux_0" column
-    intab = Table(data=[[1], [1]], names=['x_0', 'y_0'])
-    with pytest.raises(ValueError):
-        basic_phot(image=image, init_guesses=intab)
+    iter_phot = IterativelySubtractedPSFPhotometry(finder=tophatfinder,
+                                                   group_maker=DAOGroup(2),
+                                                   bkg_estimator=None,
+                                                   psf_model=prf,
+                                                   fitshape=7, niters=2)
+    # Test for init_guesses is not None, but lacks a flux_0 column
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                                                'could not be determined'):
+        results = iter_phot(image=img, init_guesses=intab)
+    assert_allclose(results['flux_fit'], f0, rtol=0.05)
+
+    iter_phot = IterativelySubtractedPSFPhotometry(finder=tophatfinder,
+                                                   group_maker=DAOGroup(2),
+                                                   bkg_estimator=None,
+                                                   psf_model=prf,
+                                                   fitshape=7, niters=2)
+
+    # Test for init_guesses is None
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                                                'could not be determined'):
+        results = iter_phot(image=img)
+    assert_allclose(results['flux_fit'], f0, rtol=0.05)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -654,6 +706,54 @@ def test_psf_extra_output_cols(sigma_psf, sources):
             assert(np.all(~np.isnan(phot_results['sharpness'])))
 
 
+@pytest.fixture(params=[2, 3])
+def overlap_image(request):
+
+    if request.param == 2:
+        close_tab = Table([[50., 53.], [50., 50.], [25., 25.]], names=['x_0', 'y_0', 'flux_0'])
+    elif request.param == 3:
+        close_tab = Table([[50., 55., 50.], [50., 50., 55.], [25., 25., 25.]],
+                          names=['x_0', 'y_0', 'flux_0'])
+    else:
+        raise ValueError
+
+    # Add sources to test image
+    close_image = np.zeros((IMAGE_SIZE, IMAGE_SIZE))
+    for x, y, flux in close_tab:
+        close_model = Gaussian2D(flux / (2 * np.pi * GAUSSIAN_WIDTH ** 2),
+                                 x, y, GAUSSIAN_WIDTH, GAUSSIAN_WIDTH)
+        close_image += discretize_model(close_model, (0, IMAGE_SIZE), (0, IMAGE_SIZE),
+                                        mode='oversample')
+    return close_image
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_psf_fitting_group(overlap_image):
+    """ Test psf_photometry when two input stars are close and need to be fit together """
+    from photutils.background import MADStdBackgroundRMS
+
+    # There are a few models here that fail, be it something
+    # created by EPSFBuilder or simpler the Moffat2D one
+    # unprepared_psf = Moffat2D(amplitude=1, gamma=2, alpha=2.8, x_0=0, y_0=0)
+    # psf = prepare_psf_model(unprepared_psf, xname='x_0', yname='y_0', fluxname=None)
+    psf = prepare_psf_model(Gaussian2D(), renormalize_psf=False)
+
+    psf.fwhm = Parameter('fwhm', 'this is not the way to add this I think')
+    psf.fwhm.value = 10
+
+    separation_crit = 10
+
+    # choose low threshold and fwhm to find stars no matter what
+    basic_phot = BasicPSFPhotometry(finder=DAOStarFinder(1, 1),
+                                    group_maker=DAOGroup(separation_crit),
+                                    bkg_estimator=MADStdBackgroundRMS(),
+                                    fitter=LevMarLSQFitter(),
+                                    psf_model=psf,
+                                    fitshape=31)
+    # this should not raise AttributeError: Attribute "offset_0_0" not found
+    basic_phot(image=overlap_image)
+
+
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_finder_return_none():
     """
@@ -716,3 +816,25 @@ def test_psf_photometry_uncertainties():
     columns = ('flux_unc', 'x_0_unc', 'y_0_unc')
     for column in columns:
         assert column not in phot_tbl.colnames
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_re_use_result_as_initial_guess():
+
+    img_shape = (32, 32)
+    # generate image with read-out noise (Gaussian) and
+    # background noise (Poisson)
+    image = (make_gaussian_prf_sources_image(img_shape, sources1) +
+             make_noise_image(img_shape, distribution='poisson', mean=6.,
+                              seed=0) +
+             make_noise_image(img_shape, distribution='gaussian', mean=0.,
+                              stddev=2., seed=0))
+
+    _, _, dao_phot_obj = make_psf_photometry_objs()
+
+    result_table = dao_phot_obj(image)
+    result_table['x'] = result_table['x_fit']
+    result_table['y'] = result_table['y_fit']
+    result_table['flux'] = result_table['flux_fit']
+    second_result = dao_phot_obj(image, result_table)
+    assert second_result
