@@ -3,74 +3,98 @@
 This module provides utilities for PSF-fitting photometry.
 """
 
-from astropy.table import Table
-from astropy.modeling import models
+from astropy.table import QTable
+from astropy.modeling.models import Const2D, Identity, Shift
 from astropy.nddata.utils import add_array, extract_array
 import numpy as np
 
 __all__ = ['prepare_psf_model', 'get_grouped_psf_model', 'subtract_psf']
 
 
+class _InverseShift(Shift):
+    @staticmethod
+    def evaluate(x, offset):
+        return x - offset
+
+    @staticmethod
+    def fit_deriv(x, *params):
+        """
+        One dimensional Shift model derivative with respect to parameter.
+        """
+        d_offset = -np.ones_like(x)
+        return [d_offset]
+
+
 def prepare_psf_model(psfmodel, xname=None, yname=None, fluxname=None,
                       renormalize_psf=True):
     """
     Convert a 2D PSF model to one suitable for use with
     `BasicPSFPhotometry` or its subclasses.
 
-    The resulting model may be a composite model, but should have only
-    the x, y, and flux related parameters un-fixed.
+    .. note::
+
+        This function is needed only in special cases where the PSF
+        model does not have ``x_0``, ``y_0``, and ``flux`` model
+        parameters. In particular, it is not needed for any of the PSF
+        models provided by photutils (e.g., `~photutils.psf.EPSFModel`,
+        `~photutils.psf.IntegratedGaussianPRF`,
+        `~photutils.psf.FittableImageModel`,
+        `~photutils.psf.GriddedPSFModel`, etc).
 
     Parameters
     ----------
-    psfmodel : a 2D model
+    psfmodel : `~astropy.modeling.Fittable2DModel`
         The model to assume as representative of the PSF.
-    xname : str or None
+
+    xname : `str` or `None`, optional
         The name of the ``psfmodel`` parameter that corresponds to the
-        x-axis center of the PSF.  If None, the model will be assumed to
-        be centered at x=0, and a new parameter will be added for the
+        x-axis center of the PSF. If `None`, the model will be assumed
+        to be centered at x=0, and a new parameter will be added for the
         offset.
-    yname : str or None
+
+    yname : `str` or `None`, optional
         The name of the ``psfmodel`` parameter that corresponds to the
-        y-axis center of the PSF.  If None, the model will be assumed to
-        be centered at y=0, and a new parameter will be added for the
+        y-axis center of the PSF. If `None`, the model will be assumed
+        to be centered at y=0, and a new parameter will be added for the
         offset.
-    fluxname : str or None
+
+    fluxname : `str` or `None`, optional
         The name of the ``psfmodel`` parameter that corresponds to the
-        total flux of the star.  If None, a scaling factor will be added
-        to the model.
-    renormalize_psf : bool
-        If True, the model will be integrated from -inf to inf and
-        re-scaled so that the total integrates to 1.  Note that this
+        total flux of the star. If `None`, a scaling factor will be
+        added to the model.
+
+    renormalize_psf : bool, optional
+        If `True`, the model will be integrated from -inf to inf and
+        rescaled so that the total integrates to 1. Note that this
         renormalization only occurs *once*, so if the total flux of
         ``psfmodel`` depends on position, this will *not* be correct.
 
     Returns
     -------
-    outmod : a model
+    result : `~astropy.modeling.Fittable2DModel`
         A new model ready to be passed into `BasicPSFPhotometry` or its
         subclasses.
     """
-
     if xname is None:
-        xinmod = models.Shift(0, name='x_offset')
+        xinmod = _InverseShift(0, name='x_offset')
         xname = 'offset_0'
     else:
-        xinmod = models.Identity(1)
+        xinmod = Identity(1)
         xname = xname + '_2'
     xinmod.fittable = True
 
     if yname is None:
-        yinmod = models.Shift(0, name='y_offset')
+        yinmod = _InverseShift(0, name='y_offset')
         yname = 'offset_1'
     else:
-        yinmod = models.Identity(1)
+        yinmod = Identity(1)
         yname = yname + '_2'
     yinmod.fittable = True
 
-    outmod = (xinmod & yinmod) | psfmodel
+    outmod = (xinmod & yinmod) | psfmodel.copy()
 
     if fluxname is None:
-        outmod = outmod * models.Const2D(1, name='flux_scaling')
+        outmod = outmod * Const2D(1, name='flux_scaling')
         fluxname = 'amplitude_3'
     else:
         fluxname = fluxname + '_2'
@@ -81,7 +105,7 @@ def prepare_psf_model(psfmodel, xname=None, yname=None, fluxname=None,
 
         integrand = integrate.dblquad(psfmodel, -np.inf, np.inf,
                                       lambda x: -np.inf, lambda x: np.inf)[0]
-        normmod = models.Const2D(1./integrand, name='renormalize_scaling')
+        normmod = Const2D(1./integrand, name='renormalize_scaling')
         outmod = outmod * normmod
 
     # final setup of the output model - fix all the non-offset/scale
@@ -115,21 +139,28 @@ def get_grouped_psf_model(template_psf_model, star_group, pars_to_set):
     template_psf_model : `astropy.modeling.Fittable2DModel` instance
         The model to use for *individual* objects.  Must have parameters named
         ``x_0``, ``y_0``, and ``flux``.
+
     star_group : `~astropy.table.Table`
         Table of stars for which the compound PSF will be constructed.  It
         must have columns named ``x_0``, ``y_0``, and ``flux_0``.
 
+    pars_to_set : `dict`
+        A dictionary of parameter names and values to set.
+
     Returns
     -------
     group_psf
         An `astropy.modeling` ``CompoundModel`` instance which is a sum of the
         given PSF models.
     """
-
     group_psf = None
 
-    for star in star_group:
+    for index, star in enumerate(star_group):
         psf_to_add = template_psf_model.copy()
+        # we 'tag' the model here so that later we don't have to rely
+        # on possibly mangled names of the compound model to find
+        # the parameters again
+        psf_to_add.name = index
         for param_tab_name, param_name in pars_to_set.items():
             setattr(psf_to_add, param_name, star[param_tab_name])
 
@@ -137,7 +168,7 @@ def get_grouped_psf_model(template_psf_model, star_group, pars_to_set):
             # this is the first one only
             group_psf = psf_to_add
         else:
-            group_psf += psf_to_add
+            group_psf = group_psf + psf_to_add
 
     return group_psf
 
@@ -147,7 +178,6 @@ def _extract_psf_fitting_names(psf):
     Determine the names of the x coordinate, y coordinate, and flux from
     a model.  Returns (xname, yname, fluxname)
     """
-
     if hasattr(psf, 'xname'):
         xname = psf.xname
     elif 'x_0' in psf.param_names:
@@ -179,7 +209,6 @@ def _call_fitter(fitter, psf, x, y, data, weights):
     Not all fitters have to support a weight array. This function
     includes the weight in the fitter call only if really needed.
     """
-
     if np.all(weights == 1.):
         return fitter(psf, x, y, data)
     else:
@@ -194,12 +223,15 @@ def subtract_psf(data, psf, posflux, subshape=None):
     ----------
     data : `~astropy.nddata.NDData` or array (must be 2D)
         Image data.
+
     psf : `astropy.modeling.Fittable2DModel` instance
-        PSF/PRF model to be substracted from the data.
+        PSF/PRF model to be subtracted from the data.
+
     posflux : Array-like of shape (3, N) or `~astropy.table.Table`
         Positions and fluxes for the objects to subtract.  If an array,
         it is interpreted as ``(x, y, flux)``  If a table, the columns
         'x_fit', 'y_fit', and 'flux_fit' must be present.
+
     subshape : length-2 or None
         The shape of the region around the center of the location to
         subtract the PSF from.  If None, subtract from the whole image.
@@ -209,10 +241,9 @@ def subtract_psf(data, psf, posflux, subshape=None):
     subdata : same shape and type as ``data``
         The image with the PSF subtracted
     """
-
     if data.ndim != 2:
-        raise ValueError('{0}-d array not supported. Only 2-d arrays can be '
-                         'passed to subtract_psf.'.format(data.ndim))
+        raise ValueError(f'{data.ndim}-d array not supported. Only 2-d '
+                         'arrays can be passed to subtract_psf.')
 
     #  translate array input into table
     if hasattr(posflux, 'colnames'):
@@ -223,9 +254,9 @@ def subtract_psf(data, psf, posflux, subshape=None):
         if 'flux_fit' not in posflux.colnames:
             raise ValueError('Input table does not have flux_fit')
     else:
-        posflux = Table(names=['x_fit', 'y_fit', 'flux_fit'], data=posflux)
+        posflux = QTable(names=['x_fit', 'y_fit', 'flux_fit'], data=posflux)
 
-    # Set up contstants across the loop
+    # Set up constants across the loop
     psf = psf.copy()
     xname, yname, fluxname = _extract_psf_fitting_names(psf)
     indices = np.indices(data.shape)
