@@ -6,33 +6,124 @@ Tests for the detect module.
 from astropy.convolution import Gaussian2DKernel
 from astropy.stats import gaussian_fwhm_to_sigma
 from astropy.tests.helper import catch_warnings
-from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 from numpy.testing import assert_allclose, assert_array_equal
 import pytest
 
 from ...utils.exceptions import NoDetectionsWarning
-from ..detect import detect_sources, make_source_mask
+from ..detect import detect_threshold, detect_sources, make_source_mask
 from ...datasets import make_4gaussians_image
+from ...utils._optional_deps import HAS_SCIPY  # noqa
 
-try:
-    import scipy  # noqa
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+
+DATA = np.array([[0, 1, 0], [0, 2, 0], [0, 0, 0]]).astype(float)
+REF1 = np.array([[0, 0, 0], [0, 1, 0], [0, 0, 0]])
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+class TestDetectThreshold:
+    def test_nsigma(self):
+        """Test basic nsigma."""
+
+        threshold = detect_threshold(DATA, nsigma=0.1)
+        ref = 0.4 * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_nsigma_zero(self):
+        """Test nsigma=0."""
+
+        threshold = detect_threshold(DATA, nsigma=0.0)
+        ref = (1. / 3.) * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_background(self):
+        threshold = detect_threshold(DATA, nsigma=1.0, background=1)
+        ref = (5. / 3.) * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_background_image(self):
+        background = np.ones((3, 3))
+        threshold = detect_threshold(DATA, nsigma=1.0, background=background)
+        ref = (5. / 3.) * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_background_badshape(self):
+        wrong_shape = np.zeros((2, 2))
+        with pytest.raises(ValueError):
+            detect_threshold(DATA, nsigma=2., background=wrong_shape)
+
+    def test_error(self):
+        threshold = detect_threshold(DATA, nsigma=1.0, error=1)
+        ref = (4. / 3.) * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_error_image(self):
+        error = np.ones((3, 3))
+        threshold = detect_threshold(DATA, nsigma=1.0, error=error)
+        ref = (4. / 3.) * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_error_badshape(self):
+        wrong_shape = np.zeros((2, 2))
+        with pytest.raises(ValueError):
+            detect_threshold(DATA, nsigma=2., error=wrong_shape)
+
+    def test_background_error(self):
+        threshold = detect_threshold(DATA, nsigma=2.0, background=10.,
+                                     error=1.)
+        ref = 12. * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_background_error_images(self):
+        background = np.ones((3, 3)) * 10.
+        error = np.ones((3, 3))
+        threshold = detect_threshold(DATA, nsigma=2.0, background=background,
+                                     error=error)
+        ref = 12. * np.ones((3, 3))
+        assert_allclose(threshold, ref)
+
+    def test_mask_value(self):
+        """Test detection with mask_value."""
+
+        threshold = detect_threshold(DATA, nsigma=1.0, mask_value=0.0)
+        ref = 2. * np.ones((3, 3))
+        assert_array_equal(threshold, ref)
+
+    def test_image_mask(self):
+        """
+        Test detection with image_mask.
+        Set sigma=10 and iters=1 to prevent sigma clipping after
+        applying the mask.
+        """
+
+        mask = REF1.astype(bool)
+        threshold = detect_threshold(DATA, nsigma=1., error=0, mask=mask,
+                                     sigclip_sigma=10, sigclip_iters=1)
+        ref = (1. / 8.) * np.ones((3, 3))
+        assert_array_equal(threshold, ref)
+
+    def test_image_mask_override(self):
+        """Test that image_mask overrides mask_value."""
+
+        mask = REF1.astype(bool)
+        threshold = detect_threshold(DATA, nsigma=0.1, error=0, mask_value=0.0,
+                                     mask=mask, sigclip_sigma=10,
+                                     sigclip_iters=1)
+        ref = np.ones((3, 3))
+        assert_array_equal(threshold, ref)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
 class TestDetectSources:
     def setup_class(self):
         self.data = np.array([[0, 1, 0], [0, 2, 0],
-                              [0, 0, 0]]).astype(np.float)
+                              [0, 0, 0]]).astype(float)
         self.refdata = np.array([[0, 1, 0], [0, 1, 0], [0, 0, 0]])
 
         fwhm2sigma = 1.0 / (2.0 * np.sqrt(2.0 * np.log(2.0)))
-        filter_kernel = Gaussian2DKernel(2. * fwhm2sigma, x_size=3, y_size=3)
-        filter_kernel.normalize()
-        self.filter_kernel = filter_kernel
+        kernel = Gaussian2DKernel(2. * fwhm2sigma, x_size=3, y_size=3)
+        kernel.normalize()
+        self.kernel = kernel
 
     def test_detection(self):
         """Test basic detection."""
@@ -112,15 +203,14 @@ class TestDetectSources:
         segm = detect_sources(data, threshold=0.9, npixels=1, connectivity=4)
         assert_array_equal(segm.data, ref)
 
-    def test_basic_filter_kernel(self):
-        """Test detection with filter_kernel."""
+    def test_basic_kernel(self):
+        """Test detection with kernel."""
 
         kernel = np.ones((3, 3)) / 9.
         threshold = 0.3
         expected = np.ones((3, 3))
         expected[2] = 0
-        segm = detect_sources(self.data, threshold, npixels=1,
-                              filter_kernel=kernel)
+        segm = detect_sources(self.data, threshold, npixels=1, kernel=kernel)
         assert_array_equal(segm.data, expected)
 
     def test_npixels_nonint(self):
@@ -141,24 +231,15 @@ class TestDetectSources:
         with pytest.raises(ValueError):
             detect_sources(self.data, threshold=1, npixels=1, connectivity=10)
 
-    def test_filter_kernel_array(self):
+    def test_kernel_array(self):
         segm = detect_sources(self.data, 0.1, npixels=1,
-                              filter_kernel=self.filter_kernel.array)
+                              kernel=self.kernel.array)
         assert_array_equal(segm.data, np.ones((3, 3)))
 
-    def test_filter_kernel(self):
-        segm = detect_sources(self.data, 0.1, npixels=1,
-                              filter_kernel=self.filter_kernel)
+    def test_kernel(self):
+        segm = detect_sources(self.data, 0.1, npixels=1, kernel=self.kernel)
         assert_array_equal(segm.data, np.ones((3, 3)))
 
-    def test_unnormalized_filter_kernel(self):
-        with catch_warnings(AstropyUserWarning) as warning_lines:
-            detect_sources(self.data, 0.1, npixels=1,
-                           filter_kernel=self.filter_kernel*10.)
-            assert warning_lines[0].category == AstropyUserWarning
-            assert ('The kernel is not normalized.'
-                    in str(warning_lines[0].message))
-
     def test_mask(self):
         data = np.zeros((11, 11))
         data[3:8, 3:8] = 5.
@@ -188,9 +269,11 @@ class TestMakeSourceMask:
                                  filter_size=3)
         sigma = 2 * gaussian_fwhm_to_sigma
         kernel = Gaussian2DKernel(sigma, x_size=3, y_size=3)
-        mask2 = make_source_mask(self.data, 5, 10, filter_kernel=kernel)
+        mask2 = make_source_mask(self.data, 5, 10, kernel=kernel)
         assert_allclose(mask1, mask2)
 
     def test_no_detections(self):
-        mask = make_source_mask(self.data, 100, 100)
-        assert np.count_nonzero(mask) == 0
+        with catch_warnings(NoDetectionsWarning) as warning_lines:
+            mask = make_source_mask(self.data, 100, 100)
+            assert np.count_nonzero(mask) == 0
+            assert warning_lines[0].category == NoDetectionsWarning
