@@ -3,11 +3,7 @@
 This subpackage provides general-purpose utility functions.
 """
 
-from .check_random_state import *  # noqa
 from .colormaps import *  # noqa
-from .convolution import *  # noqa
 from .errors import *  # noqa
 from .exceptions import *  # noqa
 from .interpolation import *  # noqa
-from .misc import *  # noqa
-from .stats import *  # noqa
