@@ -11,7 +11,7 @@ __all__ = ['calc_total_error']
 
 
 def calc_total_error(data, bkg_error, effective_gain):
-    """
+    r"""
     Calculate a total error array, combining a background-only error
     array with the Poisson noise of sources.
 
@@ -59,34 +59,34 @@ def calc_total_error(data, bkg_error, effective_gain):
     photons) is:
 
     .. math::
-        \\sigma_{\\mathrm{src}}  = \\sqrt{g_{\\mathrm{eff}} I}
+        \sigma_{\mathrm{src}}  = \sqrt{g_{\mathrm{eff}} I}
 
-    where :math:`g_{\\mathrm{eff}}` is the effective gain
+    where :math:`g_{\mathrm{eff}}` is the effective gain
     (``effective_gain``; image or scalar) and :math:`I` is the ``data``
     image.
 
     The total error is the combination of the background-only error and
     the source Poisson error.  The total error array
-    :math:`\\sigma_{\\mathrm{tot}}` in countable units (e.g., electrons
+    :math:`\sigma_{\mathrm{tot}}` in countable units (e.g., electrons
     or photons) is therefore:
 
     .. math::
-        \\sigma_{\\mathrm{tot}}  = \\sqrt{g_{\\mathrm{eff}}^2
-        \\sigma_{\\mathrm{bkg}}^2 + g_{\\mathrm{eff}} I}
+        \sigma_{\mathrm{tot}}  = \sqrt{g_{\mathrm{eff}}^2
+        \sigma_{\mathrm{bkg}}^2 + g_{\mathrm{eff}} I}
 
-    where :math:`\\sigma_{\\mathrm{bkg}}` is the background-only error
+    where :math:`\sigma_{\mathrm{bkg}}` is the background-only error
     image (``bkg_error``).
 
     Converting back to the input ``data`` units gives:
 
     .. math::
-        \\sigma_{\\mathrm{tot}}  = \\frac{1}{g_{\\mathrm{eff}}}
-        \\sqrt{g_{\\mathrm{eff}}^2
-        \\sigma_{\\mathrm{bkg}}^2 + g_{\\mathrm{eff}} I}
+        \sigma_{\mathrm{tot}}  = \frac{1}{g_{\mathrm{eff}}}
+        \sqrt{g_{\mathrm{eff}}^2
+        \sigma_{\mathrm{bkg}}^2 + g_{\mathrm{eff}} I}
 
     .. math::
-        \\sigma_{\\mathrm{tot}} = \\sqrt{\\sigma_{\\mathrm{bkg}}^2 +
-                  \\frac{I}{g_{\\mathrm{eff}}}}
+        \sigma_{\mathrm{tot}} = \sqrt{\sigma_{\mathrm{bkg}}^2 +
+                  \frac{I}{g_{\mathrm{eff}}}}
 
     ``effective_gain`` can either be a scalar value or a 2D image with
     the same shape as the ``data``.  A 2D ``effective_gain`` image is
@@ -97,24 +97,24 @@ def calc_total_error(data, bkg_error, effective_gain):
 
     The Poisson noise component is not included in the output total
     error for pixels where ``data`` (:math:`I_i)` is negative.  For such
-    pixels, :math:`\\sigma_{\\mathrm{tot}, i} = \\sigma_{\\mathrm{bkg},
+    pixels, :math:`\sigma_{\mathrm{tot}, i} = \sigma_{\mathrm{bkg},
     i}`.
 
     The Poisson noise component is also not included in the output total
-    error for pixels where the effective gain (:math:`g_{\\mathrm{eff},
-    i}`) is zero.  For such pixels, :math:`\\sigma_{\\mathrm{tot}, i} =
-    \\sigma_{\\mathrm{bkg}, i}`.
+    error for pixels where the effective gain (:math:`g_{\mathrm{eff},
+    i}`) is zero.  For such pixels, :math:`\sigma_{\mathrm{tot}, i} =
+    \sigma_{\mathrm{bkg}, i}`.
 
     To replicate `SourceExtractor`_ errors when it is configured to
     consider weight maps as gain maps (i.e., 'WEIGHT_GAIN=Y'; which is
     the default), one should input an ``effective_gain`` calculated as:
 
-    .. math:: g_{\\mathrm{eff}}^{\\prime} = g_{\\mathrm{eff}} \\left(
-       \\frac{\\mathrm{RMS_{\\mathrm{median}}^2}}{\\sigma_{\\mathrm{bkg}}^2} \\right)
+    .. math:: g_{\mathrm{eff}}^{\prime} = g_{\mathrm{eff}} \left(
+       \frac{\mathrm{RMS_{\mathrm{median}}^2}}{\sigma_{\mathrm{bkg}}^2} \right)
 
-    where :math:`g_{\\mathrm{eff}}` is the effective gain,
-    :math:`\\sigma_{\\mathrm{bkg}}` are the background-only errors,
-    and :math:`\\mathrm{RMS_{\\mathrm{median}}}` is the median
+    where :math:`g_{\mathrm{eff}}` is the effective gain,
+    :math:`\sigma_{\mathrm{bkg}}` are the background-only errors,
+    and :math:`\mathrm{RMS_{\mathrm{median}}}` is the median
     value of the low-resolution background RMS map generated by
     `SourceExtractor`_. When running `SourceExtractor`_, this
     value is printed to stdout as "(M+D) RMS: <value>". If you are
@@ -125,14 +125,13 @@ def calc_total_error(data, bkg_error, effective_gain):
 
     In that case the total error is:
 
-    .. math:: \\sigma_{\\mathrm{tot}} = \\sqrt{\\sigma_{\\mathrm{bkg}}^2 +
-        \\left(\\frac{I}{g_{\\mathrm{eff}}}\\right)
-        \\left(\\frac{\\sigma_{\\mathrm{bkg}}^2}
-        {\\mathrm{RMS_{\\mathrm{median}}^2}}\\right)}
+    .. math:: \sigma_{\mathrm{tot}} = \sqrt{\sigma_{\mathrm{bkg}}^2 +
+        \left(\frac{I}{g_{\mathrm{eff}}}\right)
+        \left(\frac{\sigma_{\mathrm{bkg}}^2}
+        {\mathrm{RMS_{\mathrm{median}}^2}}\right)}
 
     .. _SourceExtractor: https://sextractor.readthedocs.io/en/latest/
     """
-
     data = np.asanyarray(data)
     bkg_error = np.asanyarray(bkg_error)
 
