@@ -119,10 +119,14 @@ class ShepardIDWInterpolator:
     def __init__(self, coordinates, values, weights=None, leafsize=10):
         from scipy.spatial import cKDTree
 
-        coordinates = np.atleast_2d(coordinates)
-        if coordinates.shape[0] == 1:
-            coordinates = np.transpose(coordinates)
-        if coordinates.ndim != 2:
+        coordinates = np.asarray(coordinates)
+        if coordinates.ndim == 0:  # scalar coordinate
+            coordinates = np.atleast_2d(coordinates)
+
+        if coordinates.ndim == 1:
+            coordinates = np.transpose(np.atleast_2d(coordinates))
+
+        if coordinates.ndim > 2:
             coordinates = np.reshape(coordinates, (-1, coordinates.shape[-1]))
 
         values = np.asanyarray(values).ravel()
@@ -211,7 +215,6 @@ class ShepardIDWInterpolator:
             ``values`` parameter used during the initialization of the
             interpolator.
         """
-
         n_neighbors = int(n_neighbors)
         if n_neighbors < 1:
             raise ValueError('n_neighbors must be a positive integer')
@@ -281,69 +284,3 @@ class ShepardIDWInterpolator:
             return interp_values[0]
         else:
             return interp_values
-
-
-def _mask_to_mirrored_num(image, mask_image, center_position, bbox=None):
-    """
-    Replace masked pixels with the value of the pixel mirrored across a
-    given ``center_position``. If the mirror pixel is unavailable (i.e.,
-    itself masked or outside of the image), then the masked pixel value
-    is set to zero.
-
-    Parameters
-    ----------
-    image : `numpy.ndarray`, 2D
-        The 2D array of the image.
-
-    mask_image : array-like, bool
-        A boolean mask with the same shape as ``image``, where a `True`
-        value indicates the corresponding element of ``image`` is
-        considered bad.
-
-    center_position : 2-tuple
-        (x, y) center coordinates around which masked pixels will be
-        mirrored.
-
-    bbox : list, tuple, `numpy.ndarray`, optional
-        The bounding box (x_min, x_max, y_min, y_max) over which to
-        replace masked pixels.
-
-    Returns
-    -------
-    result : `numpy.ndarray`, 2D
-        A 2D array with replaced masked pixels.
-    """
-
-    if bbox is None:
-        ny, nx = image.shape
-        bbox = [0, nx, 0, ny]
-    subdata = np.copy(image[bbox[2]:bbox[3]+1, bbox[0]:bbox[1]+1])
-    submask = mask_image[bbox[2]:bbox[3]+1, bbox[0]:bbox[1]+1]
-    y_masked, x_masked = np.nonzero(submask)
-    x_mirror = (2 * (center_position[0] - bbox[0]) -
-                x_masked + 0.5).astype('int32')
-    y_mirror = (2 * (center_position[1] - bbox[2]) -
-                y_masked + 0.5).astype('int32')
-
-    # Reset mirrored pixels that go out of the image.
-    outofimage = ((x_mirror < 0) | (y_mirror < 0) |
-                  (x_mirror >= subdata.shape[1]) |
-                  (y_mirror >= subdata.shape[0]))
-    if outofimage.any():
-        x_mirror[outofimage] = x_masked[outofimage].astype('int32')
-        y_mirror[outofimage] = y_masked[outofimage].astype('int32')
-
-    subdata[y_masked, x_masked] = subdata[y_mirror, x_mirror]
-
-    # Set pixels that mirrored to another masked pixel to zero.
-    # This will also set to zero any pixels that mirrored out of
-    # the image.
-    mirror_is_masked = submask[y_mirror, x_mirror]
-    x_bad = x_masked[mirror_is_masked]
-    y_bad = y_masked[mirror_is_masked]
-    subdata[y_bad, x_bad] = 0.0
-
-    outimage = np.copy(image)
-    outimage[bbox[2]:bbox[3]+1, bbox[0]:bbox[1]+1] = subdata
-
-    return outimage
